/*!
 * Mercury Editor is a CoffeeScript and jQuery based WYSIWYG editor.  Documentation and other useful information can be
 * found at https://github.com/jejacks0n/mercury
 *
 *= require_self
 *
 * Minimum jQuery requirements are 1.7
 *= require mercury/dependencies/jquery-1.7
 *
 * You can include the Rails jQuery ujs script here to get some nicer behaviors in modals, panels and lightviews when
 * using :remote => true within the contents rendered in them.
 * require jquery_ujs
 *
 * Add any requires for the support libraries that integrate nicely with Mercury Editor.
 * require mercury/support/history
 *
 * Require Mercury Editor itself.
 *= require mercury/mercury
 *
 * Require any localizations you wish to support
 * Example: es.locale, or fr.locale -- regional dialects are in each language file so never en_US for instance.
 * require mercury/locales/swedish_chef.locale
 *
 * Add all requires for plugins that extend or change the behavior of Mercury Editor.
 * require mercury/plugins/save_as_xml/plugin.js
 *
 * Require any files you want to use that either extend, or change the default Mercury behavior.
 * require mercury_overrides
 */
window.Mercury = {

  // # Mercury Configuration
  config: {
    // ## Toolbars
    //
    // This is where you can customize the toolbars by adding or removing buttons, or changing them and their
    // behaviors.  Any top level object put here will create a new toolbar.  Buttons are simply nested inside the
    // toolbars, along with button groups.
    //
    // Some toolbars are custom (the snippets toolbar for instance), and to denote that use _custom: true.  You can then
    // build the toolbar yourself with it's own behavior.
    //
    // Buttons can be grouped, and a button group is simply a way to wrap buttons for styling -- they can also handle
    // enabling or disabling all the buttons within it by using a context.  The table button group is a good example of
    // this.
    //
    // It's important to note that each of the button names (keys), in each toolbar object must be unique, regardless of
    // if it's in a button group, or nested, etc.  This is because styling is applied to them by name, and because their
    // name is used in the event that's fired when you click on them.
    //
    // Button format: `[label, description, {type: action, type: action, etc}]`
    //
    // ### The available button types are:
    //
    // - toggle:    toggles on or off when clicked, otherwise behaves like a button
    // - modal:     opens a modal window, expects the action to be one of:
    //   1. a string url
    //   2. a function that returns a string url
    // - lightview: opens a lightview window (like modal, but different UI), expects the action to be one of:
    //   1. a string url
    //   2. a function that returns a string url
    // - panel:     opens a panel dialog, expects the action to be one of:
    //   1. a string url
    //   2. a function that returns a string url
    // - palette:   opens a palette window, expects the action to be one of:
    //   1. a string url
    //   2. a function that returns a string url
    // - select:    opens a pulldown style window, expects the action to be one of:
    //   1. a string url
    //   2. a function that returns a string url
    // - context:   calls a callback function, expects the action to be:
    //   1. a function that returns a boolean to highlight the button
    //   note: if a function isn't provided, the key will be passed to the contextHandler, in which case a default
    //         context will be used (for more info read the Contexts section below)
    // - mode:      toggle a given mode in the editor, expects the action to be:
    //   1. a string, denoting the name of the mode
    //   note: it's assumed that when a specific mode is turned on, all other modes will be turned off, which happens
    //         automatically, thus putting the editor into a specific "state"
    // - regions:   allows buttons to be enabled/disabled based on what region type has focus, expects:
    //   1. an array of region types (eg. ['full', 'markdown'])
    // - preload:   allows some dialog views to be loaded when the button is created instead of on first open, expects:
    //   1. a boolean true / false
    //   note: this is only used by panels, selects, and palettes
    //
    // Separators are any "button" that's not an array, and are expected to be a string.  You can use two different
    // separator styles: line ('-'), and spacer (' ').
    //
    // ### Adding Contexts
    //
    // Contexts are used callback functions used for highlighting and disabling/enabling buttons and buttongroups.  When
    // the cursor enters an element within an html region for instance we want to disable or highlight buttons based on
    // the properties of the given node.  You can see examples of contexts in, and add your own to:
    // `Mercury.Toolbar.Button.contexts` and `Mercury.Toolbar.ButtonGroup.contexts`
    toolbars: {
      primary: {
        save:                  ['Save', 'Save this page'],
        preview:               ['Preview', 'Preview this page', { toggle: true, mode: true }],
        sep1:                  ' ',
        undoredo:              {
          undo:                ['Undo', 'Undo your last action'],
          redo:                ['Redo', 'Redo your last action'],
          sep:                 ' '
          },
        insertLink:            ['Link', 'Insert Link', { modal: '/mercury/modals/link.html', regions: ['full', 'markdown'] }],
        insertMedia:           ['Media', 'Insert Media (images and videos)', { modal: '/mercury/modals/media.html', regions: ['full', 'markdown'] }],
        insertTable:           ['Table', 'Insert Table', { modal: '/mercury/modals/table.html', regions: ['full', 'markdown'] }],
        insertCharacter:       ['Character', 'Special Characters', { modal: '/mercury/modals/character.html', regions: ['full', 'markdown'] }],
        snippetPanel:          ['Snippet', 'Snippet Panel', { panel: '/mercury/panels/snippets.html' }],
        sep2:                  ' ',
        historyPanel:          ['History', 'Page Version History', { panel: '/mercury/panels/history.html' }],
        sep3:                  ' ',
        notesPanel:            ['Notes', 'Page Notes', { panel: '/mercury/panels/notes.html' }]
        },

      editable: {
        _regions:              ['full', 'markdown'],
        predefined:            {
          style:               ['Style', null, { select: '/mercury/selects/style.html', preload: true }],
          sep1:                ' ',
          formatblock:         ['Block Format', null, { select: '/mercury/selects/formatblock.html', preload: true }],
          sep2:                '-'
          },
        colors:                {
          backColor:           ['Background Color', null, { palette: '/mercury/palettes/backcolor.html', context: true, preload: true, regions: ['full'] }],
          sep1:                ' ',
          foreColor:           ['Text Color', null, { palette: '/mercury/palettes/forecolor.html', context: true, preload: true, regions: ['full'] }],
          sep2:                '-'
          },
        decoration:            {
          bold:                ['Bold', null, { context: true }],
          italic:              ['Italicize', null, { context: true }],
          overline:            ['Overline', null, { context: true, regions: ['full'] }],
          strikethrough:       ['Strikethrough', null, { context: true, regions: ['full'] }],
          underline:           ['Underline', null, { context: true, regions: ['full'] }],
          sep:                 '-'
          },
        script:                {
          subscript:           ['Subscript', null, { context: true }],
          superscript:         ['Superscript', null, { context: true }],
          sep: '-'
          },
        justify:               {
          justifyLeft:         ['Align Left', null, { context: true, regions: ['full'] }],
          justifyCenter:       ['Center', null, { context: true, regions: ['full'] }],
          justifyRight:        ['Align Right', null, { context: true, regions: ['full'] }],
          justifyFull:         ['Justify Full', null, { context: true, regions: ['full'] }],
          sep:                 '-'
          },
        list:                  {
          insertUnorderedList: ['Unordered List', null, { context: true }],
          insertOrderedList:   ['Numbered List', null, { context: true }],
          sep:                 '-'
          },
        indent:                {
          outdent:             ['Decrease Indentation'],
          indent:              ['Increase Indentation'],
          sep:                 '-'
          },
        table:                 {
          _context:            true,
          insertRowBefore:     ['Insert Table Row', 'Insert a table row before the cursor', { regions: ['full'] }],
          insertRowAfter:      ['Insert Table Row', 'Insert a table row after the cursor', { regions: ['full'] }],
          deleteRow:           ['Delete Table Row', 'Delete this table row', { regions: ['full'] }],
          insertColumnBefore:  ['Insert Table Column', 'Insert a table column before the cursor', { regions: ['full'] }],
          insertColumnAfter:   ['Insert Table Column', 'Insert a table column after the cursor', { regions: ['full'] }],
          deleteColumn:        ['Delete Table Column', 'Delete this table column', { regions: ['full'] }],
          sep1:                ' ',
          increaseColspan:     ['Increase Cell Columns', 'Increase the cells colspan'],
          decreaseColspan:     ['Decrease Cell Columns', 'Decrease the cells colspan and add a new cell'],
          increaseRowspan:     ['Increase Cell Rows', 'Increase the cells rowspan'],
          decreaseRowspan:     ['Decrease Cell Rows', 'Decrease the cells rowspan and add a new cell'],
          sep2:                '-'
          },
        rules:                 {
          horizontalRule:      ['Horizontal Rule', 'Insert a horizontal rule'],
          sep1:                '-'
          },
        formatting:            {
          removeFormatting:    ['Remove Formatting', 'Remove formatting for the selection', { regions: ['full'] }],
          sep2:                ' '
          },
        editors:               {
          htmlEditor:          ['Edit HTML', 'Edit the HTML content', { regions: ['full'] }]
          }
        },

      snippets: {
        _custom:               true,
        actions:               {
          editSnippet:         ['Edit Snippet Settings'],
          sep1:                ' ',
          removeSnippet:       ['Remove Snippet']
          }
        }
      },


    // ## Region Options
    //
    // You can customize some aspects of how regions are found, identified, and saved.
    //
    // attribute: Mercury identifies editable regions by a data-mercury attribute.  This attribute has to be added in
    // your HTML in advance, and is the only real code/naming exposed in the implementation of Mercury.  To allow this
    // to be as configurable as possible, you can set the name of this attribute.  If you change this, you should adjust
    // the injected styles as well.
    //
    // identifier: This is used as a unique identifier for any given region (and thus should be unique to the page).
    // By default this is the id attribute but can be changed to a data attribute should you want to use something
    // custom instead.
    //
    // dataAttributes: The dataAttributes is an array of data attributes that will be serialized and returned to the
    // server upon saving.  These attributes, when applied to a Mercury region element, will be automatically serialized
    // and submitted with the AJAX request sent when a page is saved.  These are expected to be HTML5 data attributes,
    // and 'data-' will automatically be prepended to each item in this directive. (ex. ['scope', 'version'])
    //
    // determineType: This function is called after checking the data-type attribute for the correct field type. Use
    // it if you want to dynamically set the type based on inspection of the region.
    regions: {
      attribute: 'data-mercury',
      identifier: 'id',
      dataAttributes: []
      // determineType: function(region){},
      },


    // ## Snippet Options / Preview
    //
    // When a user drags a snippet onto the page they'll be prompted to enter options for the given snippet.  The server
    // is expected to respond with a form.  Once the user submits this form, an Ajax request is sent to the server with
    // the options provided; this preview request is expected to respond with the rendered markup for the snippet.
    //
    // method: The HTTP method used when submitting both the options and the preview.  We use POST by default because a
    // snippet options form may contain large text inputs and we don't want that to be truncated when sent to the
    // server.
    //
    // optionsUrl: The url that the options form will be loaded from.
    //
    // previewUrl: The url that the options will be submitted to, and will return the rendered snippet markup.
    //
    // **Note:** `:name` will be replaced with the snippet name in the urls (eg. /mercury/snippets/example/options.html)
    snippets: {
      method: 'POST',
      optionsUrl: '/mercury/snippets/:name/options.html',
      previewUrl: '/mercury/snippets/:name/preview.html'
      },


    // ## Image Uploading
    //
    // If you drag images from your desktop into regions that support it, it will be uploaded to the server and inserted
    // into the region.  You can disable or enable this feature, the accepted mime-types, file size restrictions, and
    // other things related to uploading.
    //
    // **Note:** Image uploading is only supported in some region types, and some browsers.
    //
    // enabled: You can set this to true, or false if you want to disable the feature entirely.
    //
    // allowedMimeTypes: You can restrict the types of files that can be uploaded by providing a list of allowed mime
    // types.
    //
    // maxFileSize: You can restrict large files by setting the maxFileSize (in bytes).
    //
    // inputName: When uploading, a form is generated and submitted to the server via Ajax.  If your server would prefer
    // a different name for how the image comes through, you can change the inputName.
    //
    // url: The url that the image upload will be submitted to.
    //
    // handler: You can use false to let Mercury handle it for you, or you can provide a handler function that can
    // modify the response from the server.  This can be useful if your server doesn't respond the way Mercury expects.
    // The handler function should take the response from the server and return an object that matches:
    // `{image: {url: '[your provided url]'}`
    uploading: {
      enabled: true,
      allowedMimeTypes: ['image/jpeg', 'image/gif', 'image/png'],
      maxFileSize: 1235242880,
      inputName: 'image[image]',
      url: '/mercury/images',
      handler: false
      },


    // ## Localization / I18n
    //
    // Include the .locale files you want to support when loading Mercury.  The files are always named by the language,
    // and not the regional dialect (eg. en.locale.js) because the regional dialects are nested within the primary
    // locale files.
    //
    // The client locale will be used first, and if no proper locale file is found for their language then the fallback
    // preferredLocale configuration will be used.  If one isn't provided, and the client locale isn't included, the
    // strings will remain untranslated.
    //
    // enabled: Set to false to disable, true to enable.
    //
    // preferredLocale: If a client doesn't support the locales you've included, this is used as a fallback.
    localization: {
      enabled: false,
      preferredLocale: 'swedish_chef-BORK'
      },


    // ## Behaviors
    //
    // Behaviors are used to change the default behaviors of a given region type when a given button is clicked.  For
    // example, you may prefer to add HR tags using an HR wrapped within a div with a classname (for styling).  You
    // can add your own complex behaviors here and they'll be shared across all regions.
    //
    // If you want to add behaviors to specific region types, you can mix them into the actions property of any region
    // type.
    //
    //     Mercury.Regions.Full.actions.htmlEditor = function() {}
    //
    // You can see how the behavior matches up directly with the button names.  It's also important to note that the
    // callback functions are executed within the scope of the given region, so you have access to all it's methods.
    behaviors: {
      //foreColor: function(selection, options) { selection.wrap('<span style="color:' + options.value.toHex() + '">', true) },
      htmlEditor: function() { Mercury.modal('/mercury/modals/htmleditor.html', { title: 'HTML Editor', fullHeight: true, handler: 'htmlEditor' }); }
      },


    // ## Global Behaviors
    //
    // Global behaviors are much like behaviors, but are more "global".  Things like save, exit, etc. can be included
    // here.  They'll only be called once, and execute within the scope of whatever editor is instantiated (eg.
    // PageEditor).
    //
    // An example of changing how saving works:
    //
    //     save: function() {
    //       var data = top.JSON.stringify(this.serialize(), null, '  ');
    //       var content = '<textarea style="width:500px;height:200px" wrap="off">' + data + '</textarea>';
    //       Mercury.modal(null, {title: 'Saving', closeButton: true, content: content})
    //     }
    //
    // This is a nice way to add functionality, when the behaviors aren't region specific.  These can be triggered by a
    // button, or manually with `Mercury.trigger('action', {action: 'barrelRoll'})`
    globalBehaviors: {
      exit: function() { window.location.href = this.iframeSrc() },
      barrelRoll: function() { $('body').css({webkitTransform: 'rotate(360deg)'}) }
      },


    // ## Ajax and CSRF Headers
    //
    // Some server frameworks require that you provide a specific header for Ajax requests.  The values for these CSRF
    // tokens are typically stored in the rendered DOM.  By default, Mercury will look for the Rails specific meta tag,
    // and provide the X-CSRF-Token header on Ajax requests, but you can modify this configuration if the system you're
    // using doesn't follow the same standard.
    csrfSelector: 'meta[name="csrf-token"]',
    csrfHeader: 'X-CSRF-Token',


    // ## Editor URLs
    //
    // When loading a given page, you may want to tweak this regex.  It's to allow the url to differ from the page
    // you're editing, and the url at which you access it.
    editorUrlRegEx: /([http|https]:\/\/.[^\/]*)\/editor\/?(.*)/i,


    // ## Hijacking Links & Forms
    //
    // Mercury will hijack links and forms that don't have a target set, or the target is set to _self and will set it
    // to _parent.  This is because the target must be set properly for Mercury to not get in the way of some
    // functionality, like proper page loads on form submissions etc.  Mercury doesn't do this to links or forms that
    // are within editable regions because it doesn't want to impact the html that's saved.  With that being explained,
    // you can add classes to links or forms that you don't want this behavior added to.  Let's say you have links that
    // open a lightbox style window, and you don't want the targets of these to be set to _parent.  You can add classes
    // to this array, and they will be ignored when the hijacking is applied.
    nonHijackableClasses: [],


    // ## Pasting & Sanitizing
    //
    // When pasting content into Mercury it may sometimes contain HTML tags and attributes.  This markup is used to
    // style the content and makes the pasted content look (and behave) the same as the original content.  This can be a
    // desired feature or an annoyance, so you can enable various sanitizing methods to clean the content when it's
    // pasted.
    //
    // sanitize: Can be any of the following:
    // - false: no sanitizing is done, the content is pasted the exact same as it was copied by the user
    // - 'whitelist': content is cleaned using the settings specified in the tag white list (described below)
    // - 'text': all html is stripped before pasting, leaving only the raw text
    //
    // whitelist: The white list allows you to specify tags and attributes that are allowed when pasting content.  Each
    // item in this object should contain the allowed tag, and an array of attributes that are allowed on that tag.  If
    // the allowed attributes array is empty, all attributes will be removed.  If a tag is not present in this list, it
    // will be removed, but without removing any of the text or tags inside it.
    //
    // **Note:** Content is *always* sanitized if looks like it's from MS Word or similar editors regardless of this
    // configuration.
    pasting: {
      sanitize: 'whitelist',
      whitelist: {
        h1:     [],
        h2:     [],
        h3:     [],
        h4:     [],
        h5:     [],
        h6:     [],
        table:  [],
        thead:  [],
        tbody:  [],
        tfoot:  [],
        tr:     [],
        th:     ['colspan', 'rowspan'],
        td:     ['colspan', 'rowspan'],
        div:    ['class'],
        span:   ['class'],
        ul:     [],
        ol:     [],
        li:     [],
        b:      [],
        strong: [],
        i:      [],
        em:     [],
        u:      [],
        strike: [],
        br:     [],
        p:      [],
        hr:     [],
        a:      ['href', 'target', 'title', 'name'],
        img:    ['src', 'title', 'alt']
        }
      },


    // ## Injected Styles
    //
    // Mercury tries to stay as much out of your code as possible, but because regions appear within your document we
    // need to include a few styles to indicate regions, as well as the different states of them (eg. focused).  These
    // styles are injected into your document, and as simple as they might be, you may want to change them.
    injectedStyles: '' +
      '[data-mercury]       { min-height: 10px; outline: 1px dotted #09F } ' +
      '[data-mercury]:focus { outline: none; -webkit-box-shadow: 0 0 10px #09F, 0 0 1px #045; box-shadow: 0 0 10px #09F, 0 0 1px #045 }' +
      '[data-mercury].focus { outline: none; -webkit-box-shadow: 0 0 10px #09F, 0 0 1px #045; box-shadow: 0 0 10px #09F, 0 0 1px #045 }' +
      '[data-mercury]:after { content: "."; display: block; visibility: hidden; clear: both; height: 0; overflow: hidden; }' +
      '[data-mercury] table { border: 1px dotted red; min-width: 6px; }' +
      '[data-mercury] th    { border: 1px dotted red; min-width: 6px; }' +
      '[data-mercury] td    { border: 1px dotted red; min-width: 6px; }' +
      '[data-mercury] .mercury-textarea       { border: 0; box-sizing: border-box; -moz-box-sizing: border-box; -webkit-box-sizing: border-box; resize: none; }' +
      '[data-mercury] .mercury-textarea:focus { outline: none; -webkit-box-shadow: none; -moz-box-shadow: none; box-shadow: none; }'
  },

  // ## Silent Mode
  //
  // Turning silent mode on will disable asking about unsaved changes before leaving the page.
  silent: false,

  // ## Debug Mode
  //
  // Turning debug mode on will log events and other various things (using console.debug if available).
  debug: false

};
/*!
 * jQuery JavaScript Library v1.7
 * http://jquery.com/
 *
 * Copyright 2011, John Resig
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 * Copyright 2011, The Dojo Foundation
 * Released under the MIT, BSD, and GPL Licenses.
 *
 * Date: Thu Nov 3 16:18:21 2011 -0400
 */
(function(a,b){function h(a){var b=g[a]={},c,d;a=a.split(/\s+/);for(c=0,d=a.length;c<d;c++)b[a[c]]=!0;return b}function l(a,c,d){if(d===b&&a.nodeType===1){var e="data-"+c.replace(k,"-$1").toLowerCase();d=a.getAttribute(e);if(typeof d=="string"){try{d=d==="true"?!0:d==="false"?!1:d==="null"?null:f.isNumeric(d)?parseFloat(d):j.test(d)?f.parseJSON(d):d}catch(g){}f.data(a,c,d)}else d=b}return d}function m(a){for(var b in a){if(b==="data"&&f.isEmptyObject(a[b]))continue;if(b!=="toJSON")return!1}return!0}function n(a,b,c){var d=b+"defer",e=b+"queue",g=b+"mark",h=f._data(a,d);h&&(c==="queue"||!f._data(a,e))&&(c==="mark"||!f._data(a,g))&&setTimeout(function(){!f._data(a,e)&&!f._data(a,g)&&(f.removeData(a,d,!0),h.fire())},0)}function M(){return!1}function N(){return!0}function V(a){return!a||!a.parentNode||a.parentNode.nodeType===11}function W(a,b,c){b=b||0;if(f.isFunction(b))return f.grep(a,function(a,d){var e=!!b.call(a,d,a);return e===c});if(b.nodeType)return f.grep(a,function(a,d){return a===b===c});if(typeof b=="string"){var d=f.grep(a,function(a){return a.nodeType===1});if(R.test(b))return f.filter(b,d,!c);b=f.filter(b,d)}return f.grep(a,function(a,d){return f.inArray(a,b)>=0===c})}function X(a){var b=Y.split(" "),c=a.createDocumentFragment();if(c.createElement)while(b.length)c.createElement(b.pop());return c}function lb(a,b){return f.nodeName(a,"table")?a.getElementsByTagName("tbody")[0]||a.appendChild(a.ownerDocument.createElement("tbody")):a}function mb(a,b){if(b.nodeType!==1||!f.hasData(a))return;var c,d,e,g=f._data(a),h=f._data(b,g),i=g.events;if(i){delete h.handle,h.events={};for(c in i)for(d=0,e=i[c].length;d<e;d++)f.event.add(b,c+(i[c][d].namespace?".":"")+i[c][d].namespace,i[c][d],i[c][d].data)}h.data&&(h.data=f.extend({},h.data))}function nb(a,b){var c;if(b.nodeType!==1)return;b.clearAttributes&&b.clearAttributes(),b.mergeAttributes&&b.mergeAttributes(a),c=b.nodeName.toLowerCase();if(c==="object")b.outerHTML=a.outerHTML;else if(c!=="input"||a.type!=="checkbox"&&a.type!=="radio"){if(c==="option")b.selected=a.defaultSelected;else if(c==="input"||c==="textarea")b.defaultValue=a.defaultValue}else a.checked&&(b.defaultChecked=b.checked=a.checked),b.value!==a.value&&(b.value=a.value);b.removeAttribute(f.expando)}function ob(a){return typeof a.getElementsByTagName!="undefined"?a.getElementsByTagName("*"):typeof a.querySelectorAll!="undefined"?a.querySelectorAll("*"):[]}function pb(a){if(a.type==="checkbox"||a.type==="radio")a.defaultChecked=a.checked}function qb(a){var b=(a.nodeName||"").toLowerCase();b==="input"?pb(a):b!=="script"&&typeof a.getElementsByTagName!="undefined"&&f.grep(a.getElementsByTagName("input"),pb)}function rb(a,b){b.src?f.ajax({url:b.src,async:!1,dataType:"script"}):f.globalEval((b.text||b.textContent||b.innerHTML||"").replace(ib,"/*$0*/")),b.parentNode&&b.parentNode.removeChild(b)}function Eb(a,b,c){var d=b==="width"?a.offsetWidth:a.offsetHeight,e=b==="width"?zb:Ab;if(d>0)return c!=="border"&&f.each(e,function(){c||(d-=parseFloat(f.css(a,"padding"+this))||0),c==="margin"?d+=parseFloat(f.css(a,c+this))||0:d-=parseFloat(f.css(a,"border"+this+"Width"))||0}),d+"px";d=Bb(a,b,b);if(d<0||d==null)d=a.style[b]||0;return d=parseFloat(d)||0,c&&f.each(e,function(){d+=parseFloat(f.css(a,"padding"+this))||0,c!=="padding"&&(d+=parseFloat(f.css(a,"border"+this+"Width"))||0),c==="margin"&&(d+=parseFloat(f.css(a,c+this))||0)}),d+"px"}function _b(a){return function(b,c){typeof b!="string"&&(c=b,b="*");if(f.isFunction(c)){var d=b.toLowerCase().split(Rb),e=0,g=d.length,h,i,j;for(;e<g;e++)h=d[e],j=/^\+/.test(h),j&&(h=h.substr(1)||"*"),i=a[h]=a[h]||[],i[j?"unshift":"push"](c)}}}function ac(a,c,d,e,f,g){f=f||c.dataTypes[0],g=g||{},g[f]=!0;var h=a[f],i=0,j=h?h.length:0,k=a===Vb,l;for(;i<j&&(k||!l);i++)l=h[i](c,d,e),typeof l=="string"&&(!k||g[l]?l=b:(c.dataTypes.unshift(l),l=ac(a,c,d,e,l,g)));return(k||!l)&&!g["*"]&&(l=ac(a,c,d,e,"*",g)),l}function bc(a,c){var d,e,g=f.ajaxSettings.flatOptions||{};for(d in c)c[d]!==b&&((g[d]?a:e||(e={}))[d]=c[d]);e&&f.extend(!0,a,e)}function cc(a,b,c,d){if(f.isArray(b))f.each(b,function(b,e){c||Gb.test(a)?d(a,e):cc(a+"["+(typeof e=="object"||f.isArray(e)?b:"")+"]",e,c,d)});else if(!c&&b!=null&&typeof b=="object")for(var e in b)cc(a+"["+e+"]",b[e],c,d);else d(a,b)}function dc(a,c,d){var e=a.contents,f=a.dataTypes,g=a.responseFields,h,i,j,k;for(i in g)i in d&&(c[g[i]]=d[i]);while(f[0]==="*")f.shift(),h===b&&(h=a.mimeType||c.getResponseHeader("content-type"));if(h)for(i in e)if(e[i]&&e[i].test(h)){f.unshift(i);break}if(f[0]in d)j=f[0];else{for(i in d){if(!f[0]||a.converters[i+" "+f[0]]){j=i;break}k||(k=i)}j=j||k}if(j)return j!==f[0]&&f.unshift(j),d[j]}function ec(a,c){a.dataFilter&&(c=a.dataFilter(c,a.dataType));var d=a.dataTypes,e={},g,h,i=d.length,j,k=d[0],l,m,n,o,p;for(g=1;g<i;g++){if(g===1)for(h in a.converters)typeof h=="string"&&(e[h.toLowerCase()]=a.converters[h]);l=k,k=d[g];if(k==="*")k=l;else if(l!=="*"&&l!==k){m=l+" "+k,n=e[m]||e["* "+k];if(!n){p=b;for(o in e){j=o.split(" ");if(j[0]===l||j[0]==="*"){p=e[j[1]+" "+k];if(p){o=e[o],o===!0?n=p:p===!0&&(n=o);break}}}}!n&&!p&&f.error("No conversion from "+m.replace(" "," to ")),n!==!0&&(c=n?n(c):p(o(c)))}}return c}function kc(){try{return new a.XMLHttpRequest}catch(b){}}function lc(){try{return new a.ActiveXObject("Microsoft.XMLHTTP")}catch(b){}}function uc(){return setTimeout(vc,0),tc=f.now()}function vc(){tc=b}function wc(a,b){var c={};return f.each(sc.concat.apply([],sc.slice(0,b)),function(){c[this]=a}),c}function xc(a){if(!mc[a]){var b=c.body,d=f("<"+a+">").appendTo(b),e=d.css("display");d.remove();if(e==="none"||e===""){nc||(nc=c.createElement("iframe"),nc.frameBorder=nc.width=nc.height=0),b.appendChild(nc);if(!oc||!nc.createElement)oc=(nc.contentWindow||nc.contentDocument).document,oc.write((c.compatMode==="CSS1Compat"?"<!doctype html>":"")+"<html><body>"),oc.close();d=oc.createElement(a),oc.body.appendChild(d),e=f.css(d,"display"),b.removeChild(nc)}mc[a]=e}return mc[a]}function Ac(a){return f.isWindow(a)?a:a.nodeType===9?a.defaultView||a.parentWindow:!1}var c=a.document,d=a.navigator,e=a.location,f=function(){function K(){if(e.isReady)return;try{c.documentElement.doScroll("left")}catch(a){setTimeout(K,1);return}e.ready()}var e=function(a,b){return new e.fn.init(a,b,h)},f=a.jQuery,g=a.$,h,i=/^(?:[^#<]*(<[\w\W]+>)[^>]*$|#([\w\-]*)$)/,j=/\S/,k=/^\s+/,l=/\s+$/,m=/\d/,n=/^<(\w+)\s*\/?>(?:<\/\1>)?$/,o=/^[\],:{}\s]*$/,p=/\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g,q=/"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g,r=/(?:^|:|,)(?:\s*\[)+/g,s=/(webkit)[ \/]([\w.]+)/,t=/(opera)(?:.*version)?[ \/]([\w.]+)/,u=/(msie) ([\w.]+)/,v=/(mozilla)(?:.*? rv:([\w.]+))?/,w=/-([a-z]|[0-9])/ig,x=/^-ms-/,y=function(a,b){return(b+"").toUpperCase()},z=d.userAgent,A,B,C,D=Object.prototype.toString,E=Object.prototype.hasOwnProperty,F=Array.prototype.push,G=Array.prototype.slice,H=String.prototype.trim,I=Array.prototype.indexOf,J={};return e.fn=e.prototype={constructor:e,init:function(a,d,f){var g,h,j,k;if(!a)return this;if(a.nodeType)return this.context=this[0]=a,this.length=1,this;if(a==="body"&&!d&&c.body)return this.context=c,this[0]=c.body,this.selector=a,this.length=1,this;if(typeof a=="string"){a.charAt(0)==="<"&&a.charAt(a.length-1)===">"&&a.length>=3?g=[null,a,null]:g=i.exec(a);if(g&&(g[1]||!d)){if(g[1])return d=d instanceof e?d[0]:d,k=d?d.ownerDocument||d:c,j=n.exec(a),j?e.isPlainObject(d)?(a=[c.createElement(j[1])],e.fn.attr.call(a,d,!0)):a=[k.createElement(j[1])]:(j=e.buildFragment([g[1]],[k]),a=(j.cacheable?e.clone(j.fragment):j.fragment).childNodes),e.merge(this,a);h=c.getElementById(g[2]);if(h&&h.parentNode){if(h.id!==g[2])return f.find(a);this.length=1,this[0]=h}return this.context=c,this.selector=a,this}return!d||d.jquery?(d||f).find(a):this.constructor(d).find(a)}return e.isFunction(a)?f.ready(a):(a.selector!==b&&(this.selector=a.selector,this.context=a.context),e.makeArray(a,this))},selector:"",jquery:"1.7",length:0,size:function(){return this.length},toArray:function(){return G.call(this,0)},get:function(a){return a==null?this.toArray():a<0?this[this.length+a]:this[a]},pushStack:function(a,b,c){var d=this.constructor();return e.isArray(a)?F.apply(d,a):e.merge(d,a),d.prevObject=this,d.context=this.context,b==="find"?d.selector=this.selector+(this.selector?" ":"")+c:b&&(d.selector=this.selector+"."+b+"("+c+")"),d},each:function(a,b){return e.each(this,a,b)},ready:function(a){return e.bindReady(),B.add(a),this},eq:function(a){return a===-1?this.slice(a):this.slice(a,+a+1)},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},slice:function(){return this.pushStack(G.apply(this,arguments),"slice",G.call(arguments).join(","))},map:function(a){return this.pushStack(e.map(this,function(b,c){return a.call(b,c,b)}))},end:function(){return this.prevObject||this.constructor(null)},push:F,sort:[].sort,splice:[].splice},e.fn.init.prototype=e.fn,e.extend=e.fn.extend=function(){var a,c,d,f,g,h,i=arguments[0]||{},j=1,k=arguments.length,l=!1;typeof i=="boolean"&&(l=i,i=arguments[1]||{},j=2),typeof i!="object"&&!e.isFunction(i)&&(i={}),k===j&&(i=this,--j);for(;j<k;j++)if((a=arguments[j])!=null)for(c in a){d=i[c],f=a[c];if(i===f)continue;l&&f&&(e.isPlainObject(f)||(g=e.isArray(f)))?(g?(g=!1,h=d&&e.isArray(d)?d:[]):h=d&&e.isPlainObject(d)?d:{},i[c]=e.extend(l,h,f)):f!==b&&(i[c]=f)}return i},e.extend({noConflict:function(b){return a.$===e&&(a.$=g),b&&a.jQuery===e&&(a.jQuery=f),e},isReady:!1,readyWait:1,holdReady:function(a){a?e.readyWait++:e.ready(!0)},ready:function(a){if(a===!0&&!--e.readyWait||a!==!0&&!e.isReady){if(!c.body)return setTimeout(e.ready,1);e.isReady=!0;if(a!==!0&&--e.readyWait>0)return;B.fireWith(c,[e]),e.fn.trigger&&e(c).trigger("ready").unbind("ready")}},bindReady:function(){if(B)return;B=e.Callbacks("once memory");if(c.readyState==="complete")return setTimeout(e.ready,1);if(c.addEventListener)c.addEventListener("DOMContentLoaded",C,!1),a.addEventListener("load",e.ready,!1);else if(c.attachEvent){c.attachEvent("onreadystatechange",C),a.attachEvent("onload",e.ready);var b=!1;try{b=a.frameElement==null}catch(d){}c.documentElement.doScroll&&b&&K()}},isFunction:function(a){return e.type(a)==="function"},isArray:Array.isArray||function(a){return e.type(a)==="array"},isWindow:function(a){return a&&typeof a=="object"&&"setInterval"in a},isNumeric:function(a){return a!=null&&m.test(a)&&!isNaN(a)},type:function(a){return a==null?String(a):J[D.call(a)]||"object"},isPlainObject:function(a){if(!a||e.type(a)!=="object"||a.nodeType||e.isWindow(a))return!1;try{if(a.constructor&&!E.call(a,"constructor")&&!E.call(a.constructor.prototype,"isPrototypeOf"))return!1}catch(c){return!1}var d;for(d in a);return d===b||E.call(a,d)},isEmptyObject:function(a){for(var b in a)return!1;return!0},error:function(a){throw a},parseJSON:function(b){if(typeof b!="string"||!b)return null;b=e.trim(b);if(a.JSON&&a.JSON.parse)return a.JSON.parse(b);if(o.test(b.replace(p,"@").replace(q,"]").replace(r,"")))return(new Function("return "+b))();e.error("Invalid JSON: "+b)},parseXML:function(c){var d,f;try{a.DOMParser?(f=new DOMParser,d=f.parseFromString(c,"text/xml")):(d=new ActiveXObject("Microsoft.XMLDOM"),d.async="false",d.loadXML(c))}catch(g){d=b}return(!d||!d.documentElement||d.getElementsByTagName("parsererror").length)&&e.error("Invalid XML: "+c),d},noop:function(){},globalEval:function(b){b&&j.test(b)&&(a.execScript||function(b){a.eval.call(a,b)})(b)},camelCase:function(a){return a.replace(x,"ms-").replace(w,y)},nodeName:function(a,b){return a.nodeName&&a.nodeName.toUpperCase()===b.toUpperCase()},each:function(a,c,d){var f,g=0,h=a.length,i=h===b||e.isFunction(a);if(d){if(i){for(f in a)if(c.apply(a[f],d)===!1)break}else for(;g<h;)if(c.apply(a[g++],d)===!1)break}else if(i){for(f in a)if(c.call(a[f],f,a[f])===!1)break}else for(;g<h;)if(c.call(a[g],g,a[g++])===!1)break;return a},trim:H?function(a){return a==null?"":H.call(a)}:function(a){return a==null?"":a.toString().replace(k,"").replace(l,"")},makeArray:function(a,b){var c=b||[];if(a!=null){var d=e.type(a);a.length==null||d==="string"||d==="function"||d==="regexp"||e.isWindow(a)?F.call(c,a):e.merge(c,a)}return c},inArray:function(a,b,c){var d;if(b){if(I)return I.call(b,a,c);d=b.length,c=c?c<0?Math.max(0,d+c):c:0;for(;c<d;c++)if(c in b&&b[c]===a)return c}return-1},merge:function(a,c){var d=a.length,e=0;if(typeof c.length=="number")for(var f=c.length;e<f;e++)a[d++]=c[e];else while(c[e]!==b)a[d++]=c[e++];return a.length=d,a},grep:function(a,b,c){var d=[],e;c=!!c;for(var f=0,g=a.length;f<g;f++)e=!!b(a[f],f),c!==e&&d.push(a[f]);return d},map:function(a,c,d){var f,g,h=[],i=0,j=a.length,k=a instanceof e||j!==b&&typeof j=="number"&&(j>0&&a[0]&&a[j-1]||j===0||e.isArray(a));if(k)for(;i<j;i++)f=c(a[i],i,d),f!=null&&(h[h.length]=f);else for(g in a)f=c(a[g],g,d),f!=null&&(h[h.length]=f);return h.concat.apply([],h)},guid:1,proxy:function(a,c){if(typeof c=="string"){var d=a[c];c=a,a=d}if(!e.isFunction(a))return b;var f=G.call(arguments,2),g=function(){return a.apply(c,f.concat(G.call(arguments)))};return g.guid=a.guid=a.guid||g.guid||e.guid++,g},access:function(a,c,d,f,g,h){var i=a.length;if(typeof c=="object"){for(var j in c)e.access(a,j,c[j],f,g,d);return a}if(d!==b){f=!h&&f&&e.isFunction(d);for(var k=0;k<i;k++)g(a[k],c,f?d.call(a[k],k,g(a[k],c)):d,h);return a}return i?g(a[0],c):b},now:function(){return(new Date).getTime()},uaMatch:function(a){a=a.toLowerCase();var b=s.exec(a)||t.exec(a)||u.exec(a)||a.indexOf("compatible")<0&&v.exec(a)||[];return{browser:b[1]||"",version:b[2]||"0"}},sub:function(){function a(b,c){return new a.fn.init(b,c)}e.extend(!0,a,this),a.superclass=this,a.fn=a.prototype=this(),a.fn.constructor=a,a.sub=this.sub,a.fn.init=function(d,f){return f&&f instanceof e&&!(f instanceof a)&&(f=a(f)),e.fn.init.call(this,d,f,b)},a.fn.init.prototype=a.fn;var b=a(c);return a},browser:{}}),e.each("Boolean Number String Function Array Date RegExp Object".split(" "),function(a,b){J["[object "+b+"]"]=b.toLowerCase()}),A=e.uaMatch(z),A.browser&&(e.browser[A.browser]=!0,e.browser.version=A.version),e.browser.webkit&&(e.browser.safari=!0),j.test(" ")&&(k=/^[\s\xA0]+/,l=/[\s\xA0]+$/),h=e(c),c.addEventListener?C=function(){c.removeEventListener("DOMContentLoaded",C,!1),e.ready()}:c.attachEvent&&(C=function(){c.readyState==="complete"&&(c.detachEvent("onreadystatechange",C),e.ready())}),typeof define=="function"&&define.amd&&define.amd.jQuery&&define("jquery",[],function(){return e}),e}(),g={};f.Callbacks=function(a){a=a?g[a]||h(a):{};var c=[],d=[],e,i,j,k,l,m=function(b){var d,e,g,h,i;for(d=0,e=b.length;d<e;d++)g=b[d],h=f.type(g),h==="array"?m(g):h==="function"&&(!a.unique||!o.has(g))&&c.push(g)},n=function(b,f){f=f||[],e=!a.memory||[b,f],i=!0,l=j||0,j=0,k=c.length;for(;c&&l<k;l++)if(c[l].apply(b,f)===!1&&a.stopOnFalse){e=!0;break}i=!1,c&&(a.once?e===!0?o.disable():c=[]:d&&d.length&&(e=d.shift(),o.fireWith(e[0],e[1])))},o={add:function(){if(c){var a=c.length;m(arguments),i?k=c.length:e&&e!==!0&&(j=a,n(e[0],e[1]))}return this},remove:function(){if(c){var b=arguments,d=0,e=b.length;for(;d<e;d++)for(var f=0;f<c.length;f++)if(b[d]===c[f]){i&&f<=k&&(k--,f<=l&&l--),c.splice(f--,1);if(a.unique)break}}return this},has:function(a){if(c){var b=0,d=c.length;for(;b<d;b++)if(a===c[b])return!0}return!1},empty:function(){return c=[],this},disable:function(){return c=d=e=b,this},disabled:function(){return!c},lock:function(){return d=b,(!e||e===!0)&&o.disable(),this},locked:function(){return!d},fireWith:function(b,c){return d&&(i?a.once||d.push([b,c]):(!a.once||!e)&&n(b,c)),this},fire:function(){return o.fireWith(this,arguments),this},fired:function(){return!!e}};return o};var i=[].slice;f.extend({Deferred:function(a){var b=f.Callbacks("once memory"),c=f.Callbacks("once memory"),d=f.Callbacks("memory"),e="pending",g={resolve:b,reject:c,notify:d},h={done:b.add,fail:c.add,progress:d.add,state:function(){return e},isResolved:b.fired,isRejected:c.fired,then:function(a,b,c){return i.done(a).fail(b).progress(c),this},always:function(){return i.done.apply(i,arguments).fail.apply(i,arguments)},pipe:function(a,b,c){return f.Deferred(function(d){f.each({done:[a,"resolve"],fail:[b,"reject"],progress:[c,"notify"]},function(a,b){var c=b[0],e=b[1],g;f.isFunction(c)?i[a](function(){g=c.apply(this,arguments),g&&f.isFunction(g.promise)?g.promise().then(d.resolve,d.reject,d.notify):d[e+"With"](this===i?d:this,[g])}):i[a](d[e])})}).promise()},promise:function(a){if(a==null)a=h;else for(var b in h)a[b]=h[b];return a}},i=h.promise({}),j;for(j in g)i[j]=g[j].fire,i[j+"With"]=g[j].fireWith;return i.done(function(){e="resolved"},c.disable,d.lock).fail(function(){e="rejected"},b.disable,d.lock),a&&a.call(i,i),i},when:function(a){function l(a){return function(c){b[a]=arguments.length>1?i.call(arguments,0):c,--g||j.resolveWith(j,b)}}function m(a){return function(b){e[a]=arguments.length>1?i.call(arguments,0):b,j.notifyWith(k,e)}}var b=i.call(arguments,0),c=0,d=b.length,e=new Array(d),g=d,h=d,j=d<=1&&a&&f.isFunction(a.promise)?a:f.Deferred(),k=j.promise();if(d>1){for(;c<d;c++)b[c]&&b[c].promise&&f.isFunction(b[c].promise)?b[c].promise().then(l(c),j.reject,m(c)):--g;g||j.resolveWith(j,b)}else j!==a&&j.resolveWith(j,d?[a]:[]);return k}}),f.support=function(){var a=c.createElement("div"),b=c.documentElement,d,e,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u;a.setAttribute("className","t"),a.innerHTML="   <link/><table></table><a href='/a' style='top:1px;float:left;opacity:.55;'>a</a><input type='checkbox'/><nav></nav>",d=a.getElementsByTagName("*"),e=a.getElementsByTagName("a")[0];if(!d||!d.length||!e)return{};g=c.createElement("select"),h=g.appendChild(c.createElement("option")),i=a.getElementsByTagName("input")[0],k={leadingWhitespace:a.firstChild.nodeType===3,tbody:!a.getElementsByTagName("tbody").length,htmlSerialize:!!a.getElementsByTagName("link").length,style:/top/.test(e.getAttribute("style")),hrefNormalized:e.getAttribute("href")==="/a",opacity:/^0.55/.test(e.style.opacity),cssFloat:!!e.style.cssFloat,unknownElems:!!a.getElementsByTagName("nav").length,checkOn:i.value==="on",optSelected:h.selected,getSetAttribute:a.className!=="t",enctype:!!c.createElement("form").enctype,submitBubbles:!0,changeBubbles:!0,focusinBubbles:!1,deleteExpando:!0,noCloneEvent:!0,inlineBlockNeedsLayout:!1,shrinkWrapBlocks:!1,reliableMarginRight:!0},i.checked=!0,k.noCloneChecked=i.cloneNode(!0).checked,g.disabled=!0,k.optDisabled=!h.disabled;try{delete a.test}catch(v){k.deleteExpando=!1}!a.addEventListener&&a.attachEvent&&a.fireEvent&&(a.attachEvent("onclick",function(){k.noCloneEvent=!1}),a.cloneNode(!0).fireEvent("onclick")),i=c.createElement("input"),i.value="t",i.setAttribute("type","radio"),k.radioValue=i.value==="t",i.setAttribute("checked","checked"),a.appendChild(i),l=c.createDocumentFragment(),l.appendChild(a.lastChild),k.checkClone=l.cloneNode(!0).cloneNode(!0).lastChild.checked,a.innerHTML="",a.style.width=a.style.paddingLeft="1px",m=c.getElementsByTagName("body")[0],o=c.createElement(m?"div":"body"),p={visibility:"hidden",width:0,height:0,border:0,margin:0,background:"none"},m&&f.extend(p,{position:"absolute",left:"-999px",top:"-999px"});for(t in p)o.style[t]=p[t];o.appendChild(a),n=m||b,n.insertBefore(o,n.firstChild),k.appendChecked=i.checked,k.boxModel=a.offsetWidth===2,"zoom"in a.style&&(a.style.display="inline",a.style.zoom=1,k.inlineBlockNeedsLayout=a.offsetWidth===2,a.style.display="",a.innerHTML="<div style='width:4px;'></div>",k.shrinkWrapBlocks=a.offsetWidth!==2),a.innerHTML="<table><tr><td style='padding:0;border:0;display:none'></td><td>t</td></tr></table>",q=a.getElementsByTagName("td"),u=q[0].offsetHeight===0,q[0].style.display="",q[1].style.display="none",k.reliableHiddenOffsets=u&&q[0].offsetHeight===0,a.innerHTML="",c.defaultView&&c.defaultView.getComputedStyle&&(j=c.createElement("div"),j.style.width="0",j.style.marginRight="0",a.appendChild(j),k.reliableMarginRight=(parseInt((c.defaultView.getComputedStyle(j,null)||{marginRight:0}).marginRight,10)||0)===0);if(a.attachEvent)for(t in{submit:1,change:1,focusin:1})s="on"+t,u=s in a,u||(a.setAttribute(s,"return;"),u=typeof a[s]=="function"),k[t+"Bubbles"]=u;return f(function(){var a,b,d,e,g,h,i=1,j="position:absolute;top:0;left:0;width:1px;height:1px;margin:0;",l="visibility:hidden;border:0;",n="style='"+j+"border:5px solid #000;padding:0;'",p="<div "+n+"><div></div></div>"+"<table "+n+" cellpadding='0' cellspacing='0'>"+"<tr><td></td></tr></table>";m=c.getElementsByTagName("body")[0];if(!m)return;a=c.createElement("div"),a.style.cssText=l+"width:0;height:0;position:static;top:0;margin-top:"+i+"px",m.insertBefore(a,m.firstChild),o=c.createElement("div"),o.style.cssText=j+l,o.innerHTML=p,a.appendChild(o),b=o.firstChild,d=b.firstChild,g=b.nextSibling.firstChild.firstChild,h={doesNotAddBorder:d.offsetTop!==5,doesAddBorderForTableAndCells:g.offsetTop===5},d.style.position="fixed",d.style.top="20px",h.fixedPosition=d.offsetTop===20||d.offsetTop===15,d.style.position=d.style.top="",b.style.overflow="hidden",b.style.position="relative",h.subtractsBorderForOverflowNotVisible=d.offsetTop===-5,h.doesNotIncludeMarginInBodyOffset=m.offsetTop!==i,m.removeChild(a),o=a=null,f.extend(k,h)}),o.innerHTML="",n.removeChild(o),o=l=g=h=m=j=a=i=null,k}(),f.boxModel=f.support.boxModel;var j=/^(?:\{.*\}|\[.*\])$/,k=/([A-Z])/g;f.extend({cache:{},uuid:0,expando:"jQuery"+(f.fn.jquery+Math.random()).replace(/\D/g,""),noData:{embed:!0,object:"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000",applet:!0},hasData:function(a){return a=a.nodeType?f.cache[a[f.expando]]:a[f.expando],!!a&&!m(a)},data:function(a,c,d,e){if(!f.acceptData(a))return;var g,h,i,j=f.expando,k=typeof c=="string",l=a.nodeType,m=l?f.cache:a,n=l?a[f.expando]:a[f.expando]&&f.expando,o=c==="events";if((!n||!m[n]||!o&&!e&&!m[n].data)&&k&&d===b)return;n||(l?a[f.expando]=n=++f.uuid:n=f.expando),m[n]||(m[n]={},l||(m[n].toJSON=f.noop));if(typeof c=="object"||typeof c=="function")e?m[n]=f.extend(m[n],c):m[n].data=f.extend(m[n].data,c);return g=h=m[n],e||(h.data||(h.data={}),h=h.data),d!==b&&(h[f.camelCase(c)]=d),o&&!h[c]?g.events:(k?(i=h[c],i==null&&(i=h[f.camelCase(c)])):i=h,i)},removeData:function(a,b,c){if(!f.acceptData(a))return;var d,e,g,h=f.expando,i=a.nodeType,j=i?f.cache:a,k=i?a[f.expando]:f.expando;if(!j[k])return;if(b){d=c?j[k]:j[k].data;if(d){f.isArray(b)?b=b:b in d?b=[b]:(b=f.camelCase(b),b in d?b=[b]:b=b.split(" "));for(e=0,g=b.length;e<g;e++)delete d[b[e]];if(!(c?m:f.isEmptyObject)(d))return}}if(!c){delete j[k].data;if(!m(j[k]))return}f.support.deleteExpando||!j.setInterval?delete j[k]:j[k]=null,i&&(f.support.deleteExpando?delete a[f.expando]:a.removeAttribute?a.removeAttribute(f.expando):a[f.expando]=null)},_data:function(a,b,c){return f.data(a,b,c,!0)},acceptData:function(a){if(a.nodeName){var b=f.noData[a.nodeName.toLowerCase()];if(b)return b!==!0&&a.getAttribute("classid")===b}return!0}}),f.fn.extend({data:function(a,c){var d,e,g,h=null;if(typeof a=="undefined"){if(this.length){h=f.data(this[0]);if(this[0].nodeType===1&&!f._data(this[0],"parsedAttrs")){e=this[0].attributes;for(var i=0,j=e.length;i<j;i++)g=e[i].name,g.indexOf("data-")===0&&(g=f.camelCase(g.substring(5)),l(this[0],g,h[g]));f._data(this[0],"parsedAttrs",!0)}}return h}return typeof a=="object"?this.each(function(){f.data(this,a)}):(d=a.split("."),d[1]=d[1]?"."+d[1]:"",c===b?(h=this.triggerHandler("getData"+d[1]+"!",[d[0]]),h===b&&this.length&&(h=f.data(this[0],a),h=l(this[0],a,h)),h===b&&d[1]?this.data(d[0]):h):this.each(function(){var b=f(this),e=[d[0],c];b.triggerHandler("setData"+d[1]+"!",e),f.data(this,a,c),b.triggerHandler("changeData"+d[1]+"!",e)}))},removeData:function(a){return this.each(function(){f.removeData(this,a)})}}),f.extend({_mark:function(a,b){a&&(b=(b||"fx")+"mark",f._data(a,b,(f._data(a,b)||0)+1))},_unmark:function(a,b,c){a!==!0&&(c=b,b=a,a=!1);if(b){c=c||"fx";var d=c+"mark",e=a?0:(f._data(b,d)||1)-1;e?f._data(b,d,e):(f.removeData(b,d,!0),n(b,c,"mark"))}},queue:function(a,b,c){var d;if(a)return b=(b||"fx")+"queue",d=f._data(a,b),c&&(!d||f.isArray(c)?d=f._data(a,b,f.makeArray(c)):d.push(c)),d||[]},dequeue:function(a,b){b=b||"fx";var c=f.queue(a,b),d=c.shift(),e={};d==="inprogress"&&(d=c.shift()),d&&(b==="fx"&&c.unshift("inprogress"),f._data(a,b+".run",e),d.call(a,function(){f.dequeue(a,b)},e)),c.length||(f.removeData(a,b+"queue "+b+".run",!0),n(a,b,"queue"))}}),f.fn.extend({queue:function(a,c){return typeof a!="string"&&(c=a,a="fx"),c===b?f.queue(this[0],a):this.each(function(){var b=f.queue(this,a,c);a==="fx"&&b[0]!=="inprogress"&&f.dequeue(this,a)})},dequeue:function(a){return this.each(function(){f.dequeue(this,a)})},delay:function(a,b){return a=f.fx?f.fx.speeds[a]||a:a,b=b||"fx",this.queue(b,function(b,c){var d=setTimeout(b,a);c.stop=function(){clearTimeout(d)}})},clearQueue:function(a){return this.queue(a||"fx",[])},promise:function(a,c){function m(){--h||d.resolveWith(e,[e])}typeof a!="string"&&(c=a,a=b),a=a||"fx";var d=f.Deferred(),e=this,g=e.length,h=1,i=a+"defer",j=a+"queue",k=a+"mark",l;while(g--)if(l=f.data(e[g],i,b,!0)||(f.data(e[g],j,b,!0)||f.data(e[g],k,b,!0))&&f.data(e[g],i,f.Callbacks("once memory"),!0))h++,l.add(m);return m(),d.promise()}});var o=/[\n\t\r]/g,p=/\s+/,q=/\r/g,r=/^(?:button|input)$/i,s=/^(?:button|input|object|select|textarea)$/i,t=/^a(?:rea)?$/i,u=/^(?:autofocus|autoplay|async|checked|controls|defer|disabled|hidden|loop|multiple|open|readonly|required|scoped|selected)$/i,v=f.support.getSetAttribute,w,x,y;f.fn.extend({attr:function(a,b){return f.access(this,a,b,!0,f.attr)},removeAttr:function(a){return this.each(function(){f.removeAttr(this,a)})},prop:function(a,b){return f.access(this,a,b,!0,f.prop)},removeProp:function(a){return a=f.propFix[a]||a,this.each(function(){try{this[a]=b,delete this[a]}catch(c){}})},addClass:function(a){var b,c,d,e,g,h,i;if(f.isFunction(a))return this.each(function(b){f(this).addClass(a.call(this,b,this.className))});if(a&&typeof a=="string"){b=a.split(p);for(c=0,d=this.length;c<d;c++){e=this[c];if(e.nodeType===1)if(!e.className&&b.length===1)e.className=a;else{g=" "+e.className+" ";for(h=0,i=b.length;h<i;h++)~g.indexOf(" "+b[h]+" ")||(g+=b[h]+" ");e.className=f.trim(g)}}}return this},removeClass:function(a){var c,d,e,g,h,i,j;if(f.isFunction(a))return this.each(function(b){f(this).removeClass(a.call(this,b,this.className))});if(a&&typeof a=="string"||a===b){c=(a||"").split(p);for(d=0,e=this.length;d<e;d++){g=this[d];if(g.nodeType===1&&g.className)if(a){h=(" "+g.className+" ").replace(o," ");for(i=0,j=c.length;i<j;i++)h=h.replace(" "+c[i]+" "," ");g.className=f.trim(h)}else g.className=""}}return this},toggleClass:function(a,b){var c=typeof a,d=typeof b=="boolean";return f.isFunction(a)?this.each(function(c){f(this).toggleClass(a.call(this,c,this.className,b),b)}):this.each(function(){if(c==="string"){var e,g=0,h=f(this),i=b,j=a.split(p);while(e=j[g++])i=d?i:!h.hasClass(e),h[i?"addClass":"removeClass"](e)}else if(c==="undefined"||c==="boolean")this.className&&f._data(this,"__className__",this.className),this.className=this.className||a===!1?"":f._data(this,"__className__")||""})},hasClass:function(a){var b=" "+a+" ",c=0,d=this.length;for(;c<d;c++)if(this[c].nodeType===1&&(" "+this[c].className+" ").replace(o," ").indexOf(b)>-1)return!0;return!1},val:function(a){var c,d,e,g=this[0];if(!arguments.length)return g?(c=f.valHooks[g.nodeName.toLowerCase()]||f.valHooks[g.type],c&&"get"in c&&(d=c.get(g,"value"))!==b?d:(d=g.value,typeof d=="string"?d.replace(q,""):d==null?"":d)):b;return e=f.isFunction(a),this.each(function(d){var g=f(this),h;if(this.nodeType!==1)return;e?h=a.call(this,d,g.val()):h=a,h==null?h="":typeof h=="number"?h+="":f.isArray(h)&&(h=f.map(h,function(a){return a==null?"":a+""})),c=f.valHooks[this.nodeName.toLowerCase()]||f.valHooks[this.type];if(!c||!("set"in c)||c.set(this,h,"value")===b)this.value=h})}}),f.extend({valHooks:{option:{get:function(a){var b=a.attributes.value;return!b||b.specified?a.value:a.text}},select:{get:function(a){var b,c,d,e,g=a.selectedIndex,h=[],i=a.options,j=a.type==="select-one";if(g<0)return null;c=j?g:0,d=j?g+1:i.length;for(;c<d;c++){e=i[c];if(e.selected&&(f.support.optDisabled?!e.disabled:e.getAttribute("disabled")===null)&&(!e.parentNode.disabled||!f.nodeName(e.parentNode,"optgroup"))){b=f(e).val();if(j)return b;h.push(b)}}return j&&!h.length&&i.length?f(i[g]).val():h},set:function(a,b){var c=f.makeArray(b);return f(a).find("option").each(function(){this.selected=f.inArray(f(this).val(),c)>=0}),c.length||(a.selectedIndex=-1),c}}},attrFn:{val:!0,css:!0,html:!0,text:!0,data:!0,width:!0,height:!0,offset:!0},attr:function(a,c,d,e){var g,h,i,j=a.nodeType;return!a||j===3||j===8||j===2?b:e&&c in f.attrFn?f(a)[c](d):"getAttribute"in a?(i=j!==1||!f.isXMLDoc(a),i&&(c=c.toLowerCase(),h=f.attrHooks[c]||(u.test(c)?x:w)),d!==b?d===null?(f.removeAttr(a,c),b):h&&"set"in h&&i&&(g=h.set(a,d,c))!==b?g:(a.setAttribute(c,""+d),d):h&&"get"in h&&i&&(g=h.get(a,c))!==null?g:(g=a.getAttribute(c),g===null?b:g)):f.prop(a,c,d)},removeAttr:function(a,b){var c,d,e,g,h=0;if(a.nodeType===1){d=(b||"").split(p),g=d.length;for(;h<g;h++)e=d[h].toLowerCase(),c=f.propFix[e]||e,f.attr(a,e,""),a.removeAttribute(v?e:c),u.test(e)&&c in a&&(a[c]=!1)}},attrHooks:{type:{set:function(a,b){if(r.test(a.nodeName)&&a.parentNode)f.error("type property can't be changed");else if(!f.support.radioValue&&b==="radio"&&f.nodeName(a,"input")){var c=a.value;return a.setAttribute("type",b),c&&(a.value=c),b}}},value:{get:function(a,b){return w&&f.nodeName(a,"button")?w.get(a,b):b in a?a.value:null},set:function(a,b,c){if(w&&f.nodeName(a,"button"))return w.set(a,b,c);a.value=b}}},propFix:{tabindex:"tabIndex",readonly:"readOnly","for":"htmlFor","class":"className",maxlength:"maxLength",cellspacing:"cellSpacing",cellpadding:"cellPadding",rowspan:"rowSpan",colspan:"colSpan",usemap:"useMap",frameborder:"frameBorder",contenteditable:"contentEditable"},prop:function(a,c,d){var e,g,h,i=a.nodeType;return!a||i===3||i===8||i===2?b:(h=i!==1||!f.isXMLDoc(a),h&&(c=f.propFix[c]||c,g=f.propHooks[c]),d!==b?g&&"set"in g&&(e=g.set(a,d,c))!==b?e:a[c]=d:g&&"get"in g&&(e=g.get(a,c))!==null?e:a[c])},propHooks:{tabIndex:{get:function(a){var c=a.getAttributeNode("tabindex");return c&&c.specified?parseInt(c.value,10):s.test(a.nodeName)||t.test(a.nodeName)&&a.href?0:b}}}}),f.attrHooks.tabindex=f.propHooks.tabIndex,x={get:function(a,c){var d,e=f.prop(a,c);return e===!0||typeof e!="boolean"&&(d=a.getAttributeNode(c))&&d.nodeValue!==!1?c.toLowerCase():b},set:function(a,b,c){var d;return b===!1?f.removeAttr(a,c):(d=f.propFix[c]||c,d in a&&(a[d]=!0),a.setAttribute(c,c.toLowerCase())),c}},v||(y={name:!0,id:!0},w=f.valHooks.button={get:function(a,c){var d;return d=a.getAttributeNode(c),d&&(y[c]?d.nodeValue!=="":d.specified)?d.nodeValue:b},set:function(a,b,d){var e=a.getAttributeNode(d);return e||(e=c.createAttribute(d),a.setAttributeNode(e)),e.nodeValue=b+""}},f.attrHooks.tabindex.set=w.set,f.each(["width","height"],function(a,b){f.attrHooks[b]=f.extend(f.attrHooks[b],{set:function(a,c){if(c==="")return a.setAttribute(b,"auto"),c}})}),f.attrHooks.contenteditable={get:w.get,set:function(a,b,c){b===""&&(b="false"),w.set(a,b,c)}}),f.support.hrefNormalized||f.each(["href","src","width","height"],function(a,c){f.attrHooks[c]=f.extend(f.attrHooks[c],{get:function(a){var d=a.getAttribute(c,2);return d===null?b:d}})}),f.support.style||(f.attrHooks.style={get:function(a){return a.style.cssText.toLowerCase()||b},set:function(a,b){return a.style.cssText=""+b}}),f.support.optSelected||(f.propHooks.selected=f.extend(f.propHooks.selected,{get:function(a){var b=a.parentNode;return b&&(b.selectedIndex,b.parentNode&&b.parentNode.selectedIndex),null}})),f.support.enctype||(f.propFix.enctype="encoding"),f.support.checkOn||f.each(["radio","checkbox"],function(){f.valHooks[this]={get:function(a){return a.getAttribute("value")===null?"on":a.value}}}),f.each(["radio","checkbox"],function(){f.valHooks[this]=f.extend(f.valHooks[this],{set:function(a,b){if(f.isArray(b))return a.checked=f.inArray(f(a).val(),b)>=0}})});var z=/\.(.*)$/,A=/^(?:textarea|input|select)$/i,B=/\./g,C=/ /g,D=/[^\w\s.|`]/g,E=/^([^\.]*)?(?:\.(.+))?$/,F=/\bhover(\.\S+)?/,G=/^key/,H=/^(?:mouse|contextmenu)|click/,I=/^(\w*)(?:#([\w\-]+))?(?:\.([\w\-]+))?$/,J=function(a){var b=I.exec(a);return b&&(b[1]=(b[1]||"").toLowerCase(),b[3]=b[3]&&new RegExp("(?:^|\\s)"+b[3]+"(?:\\s|$)")),b},K=function(a,b){return(!b[1]||a.nodeName
.toLowerCase()===b[1])&&(!b[2]||a.id===b[2])&&(!b[3]||b[3].test(a.className))},L=function(a){return f.event.special.hover?a:a.replace(F,"mouseenter$1 mouseleave$1")};f.event={add:function(a,c,d,e,g){var h,i,j,k,l,m,n,o,p,q,r,s;if(a.nodeType===3||a.nodeType===8||!c||!d||!(h=f._data(a)))return;d.handler&&(p=d,d=p.handler),d.guid||(d.guid=f.guid++),j=h.events,j||(h.events=j={}),i=h.handle,i||(h.handle=i=function(a){return typeof f=="undefined"||!!a&&f.event.triggered===a.type?b:f.event.dispatch.apply(i.elem,arguments)},i.elem=a),c=L(c).split(" ");for(k=0;k<c.length;k++){l=E.exec(c[k])||[],m=l[1],n=(l[2]||"").split(".").sort(),s=f.event.special[m]||{},m=(g?s.delegateType:s.bindType)||m,s=f.event.special[m]||{},o=f.extend({type:m,origType:l[1],data:e,handler:d,guid:d.guid,selector:g,namespace:n.join(".")},p),g&&(o.quick=J(g),!o.quick&&f.expr.match.POS.test(g)&&(o.isPositional=!0)),r=j[m];if(!r){r=j[m]=[],r.delegateCount=0;if(!s.setup||s.setup.call(a,e,n,i)===!1)a.addEventListener?a.addEventListener(m,i,!1):a.attachEvent&&a.attachEvent("on"+m,i)}s.add&&(s.add.call(a,o),o.handler.guid||(o.handler.guid=d.guid)),g?r.splice(r.delegateCount++,0,o):r.push(o),f.event.global[m]=!0}a=null},global:{},remove:function(a,b,c,d){var e=f.hasData(a)&&f._data(a),g,h,i,j,k,l,m,n,o,p,q;if(!e||!(m=e.events))return;b=L(b||"").split(" ");for(g=0;g<b.length;g++){h=E.exec(b[g])||[],i=h[1],j=h[2];if(!i){j=j?"."+j:"";for(l in m)f.event.remove(a,l+j,c,d);return}n=f.event.special[i]||{},i=(d?n.delegateType:n.bindType)||i,p=m[i]||[],k=p.length,j=j?new RegExp("(^|\\.)"+j.split(".").sort().join("\\.(?:.*\\.)?")+"(\\.|$)"):null;if(c||j||d||n.remove)for(l=0;l<p.length;l++){q=p[l];if(!c||c.guid===q.guid)if(!j||j.test(q.namespace))if(!d||d===q.selector||d==="**"&&q.selector)p.splice(l--,1),q.selector&&p.delegateCount--,n.remove&&n.remove.call(a,q)}else p.length=0;p.length===0&&k!==p.length&&((!n.teardown||n.teardown.call(a,j)===!1)&&f.removeEvent(a,i,e.handle),delete m[i])}f.isEmptyObject(m)&&(o=e.handle,o&&(o.elem=null),f.removeData(a,["events","handle"],!0))},customEvent:{getData:!0,setData:!0,changeData:!0},trigger:function(c,d,e,g){if(!e||e.nodeType!==3&&e.nodeType!==8){var h=c.type||c,i=[],j,k,l,m,n,o,p,q,r,s;h.indexOf("!")>=0&&(h=h.slice(0,-1),k=!0),h.indexOf(".")>=0&&(i=h.split("."),h=i.shift(),i.sort());if((!e||f.event.customEvent[h])&&!f.event.global[h])return;c=typeof c=="object"?c[f.expando]?c:new f.Event(h,c):new f.Event(h),c.type=h,c.isTrigger=!0,c.exclusive=k,c.namespace=i.join("."),c.namespace_re=c.namespace?new RegExp("(^|\\.)"+i.join("\\.(?:.*\\.)?")+"(\\.|$)"):null,o=h.indexOf(":")<0?"on"+h:"",(g||!e)&&c.preventDefault();if(!e){j=f.cache;for(l in j)j[l].events&&j[l].events[h]&&f.event.trigger(c,d,j[l].handle.elem,!0);return}c.result=b,c.target||(c.target=e),d=d!=null?f.makeArray(d):[],d.unshift(c),p=f.event.special[h]||{};if(p.trigger&&p.trigger.apply(e,d)===!1)return;r=[[e,p.bindType||h]];if(!g&&!p.noBubble&&!f.isWindow(e)){s=p.delegateType||h,n=null;for(m=e.parentNode;m;m=m.parentNode)r.push([m,s]),n=m;n&&n===e.ownerDocument&&r.push([n.defaultView||n.parentWindow||a,s])}for(l=0;l<r.length;l++){m=r[l][0],c.type=r[l][1],q=(f._data(m,"events")||{})[c.type]&&f._data(m,"handle"),q&&q.apply(m,d),q=o&&m[o],q&&f.acceptData(m)&&q.apply(m,d);if(c.isPropagationStopped())break}return c.type=h,c.isDefaultPrevented()||(!p._default||p._default.apply(e.ownerDocument,d)===!1)&&(h!=="click"||!f.nodeName(e,"a"))&&f.acceptData(e)&&o&&e[h]&&(h!=="focus"&&h!=="blur"||c.target.offsetWidth!==0)&&!f.isWindow(e)&&(n=e[o],n&&(e[o]=null),f.event.triggered=h,e[h](),f.event.triggered=b,n&&(e[o]=n)),c.result}return},dispatch:function(c){c=f.event.fix(c||a.event);var d=(f._data(this,"events")||{})[c.type]||[],e=d.delegateCount,g=[].slice.call(arguments,0),h=!c.exclusive&&!c.namespace,i=(f.event.special[c.type]||{}).handle,j=[],k,l,m,n,o,p,q,r,s,t,u;g[0]=c,c.delegateTarget=this;if(e&&!c.target.disabled&&(!c.button||c.type!=="click"))for(m=c.target;m!=this;m=m.parentNode||this){o={},q=[];for(k=0;k<e;k++)r=d[k],s=r.selector,t=o[s],r.isPositional?t=(t||(o[s]=f(s))).index(m)>=0:t===b&&(t=o[s]=r.quick?K(m,r.quick):f(m).is(s)),t&&q.push(r);q.length&&j.push({elem:m,matches:q})}d.length>e&&j.push({elem:this,matches:d.slice(e)});for(k=0;k<j.length&&!c.isPropagationStopped();k++){p=j[k],c.currentTarget=p.elem;for(l=0;l<p.matches.length&&!c.isImmediatePropagationStopped();l++){r=p.matches[l];if(h||!c.namespace&&!r.namespace||c.namespace_re&&c.namespace_re.test(r.namespace))c.data=r.data,c.handleObj=r,n=(i||r.handler).apply(p.elem,g),n!==b&&(c.result=n,n===!1&&(c.preventDefault(),c.stopPropagation()))}}return c.result},props:"attrChange attrName relatedNode srcElement altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),fixHooks:{},keyHooks:{props:"char charCode key keyCode".split(" "),filter:function(a,b){return a.which==null&&(a.which=b.charCode!=null?b.charCode:b.keyCode),a}},mouseHooks:{props:"button buttons clientX clientY fromElement offsetX offsetY pageX pageY screenX screenY toElement wheelDelta".split(" "),filter:function(a,d){var e,f,g,h=d.button,i=d.fromElement;return a.pageX==null&&d.clientX!=null&&(e=a.target.ownerDocument||c,f=e.documentElement,g=e.body,a.pageX=d.clientX+(f&&f.scrollLeft||g&&g.scrollLeft||0)-(f&&f.clientLeft||g&&g.clientLeft||0),a.pageY=d.clientY+(f&&f.scrollTop||g&&g.scrollTop||0)-(f&&f.clientTop||g&&g.clientTop||0)),!a.relatedTarget&&i&&(a.relatedTarget=i===a.target?d.toElement:i),!a.which&&h!==b&&(a.which=h&1?1:h&2?3:h&4?2:0),a}},fix:function(a){if(a[f.expando])return a;var d,e,g=a,h=f.event.fixHooks[a.type]||{},i=h.props?this.props.concat(h.props):this.props;a=f.Event(g);for(d=i.length;d;)e=i[--d],a[e]=g[e];return a.target||(a.target=g.srcElement||c),a.target.nodeType===3&&(a.target=a.target.parentNode),a.metaKey===b&&(a.metaKey=a.ctrlKey),h.filter?h.filter(a,g):a},special:{ready:{setup:f.bindReady},focus:{delegateType:"focusin",noBubble:!0},blur:{delegateType:"focusout",noBubble:!0},beforeunload:{setup:function(a,b,c){f.isWindow(this)&&(this.onbeforeunload=c)},teardown:function(a,b){this.onbeforeunload===b&&(this.onbeforeunload=null)}}},simulate:function(a,b,c,d){var e=f.extend(new f.Event,c,{type:a,isSimulated:!0,originalEvent:{}});d?f.event.trigger(e,null,b):f.event.dispatch.call(b,e),e.isDefaultPrevented()&&c.preventDefault()}},f.event.handle=f.event.dispatch,f.removeEvent=c.removeEventListener?function(a,b,c){a.removeEventListener&&a.removeEventListener(b,c,!1)}:function(a,b,c){a.detachEvent&&a.detachEvent("on"+b,c)},f.Event=function(a,b){if(!(this instanceof f.Event))return new f.Event(a,b);a&&a.type?(this.originalEvent=a,this.type=a.type,this.isDefaultPrevented=a.defaultPrevented||a.returnValue===!1||a.getPreventDefault&&a.getPreventDefault()?N:M):this.type=a,b&&f.extend(this,b),this.timeStamp=a&&a.timeStamp||f.now(),this[f.expando]=!0},f.Event.prototype={preventDefault:function(){this.isDefaultPrevented=N;var a=this.originalEvent;if(!a)return;a.preventDefault?a.preventDefault():a.returnValue=!1},stopPropagation:function(){this.isPropagationStopped=N;var a=this.originalEvent;if(!a)return;a.stopPropagation&&a.stopPropagation(),a.cancelBubble=!0},stopImmediatePropagation:function(){this.isImmediatePropagationStopped=N,this.stopPropagation()},isDefaultPrevented:M,isPropagationStopped:M,isImmediatePropagationStopped:M},f.each({mouseenter:"mouseover",mouseleave:"mouseout"},function(a,b){f.event.special[a]=f.event.special[b]={delegateType:b,bindType:b,handle:function(a){var b=this,c=a.relatedTarget,d=a.handleObj,e=d.selector,g,h;if(!c||d.origType===a.type||c!==b&&!f.contains(b,c))g=a.type,a.type=d.origType,h=d.handler.apply(this,arguments),a.type=g;return h}}}),f.support.submitBubbles||(f.event.special.submit={setup:function(){if(f.nodeName(this,"form"))return!1;f.event.add(this,"click._submit keypress._submit",function(a){var c=a.target,d=f.nodeName(c,"input")||f.nodeName(c,"button")?c.form:b;d&&!d._submit_attached&&(f.event.add(d,"submit._submit",function(a){this.parentNode&&f.event.simulate("submit",this.parentNode,a,!0)}),d._submit_attached=!0)})},teardown:function(){if(f.nodeName(this,"form"))return!1;f.event.remove(this,"._submit")}}),f.support.changeBubbles||(f.event.special.change={setup:function(){if(A.test(this.nodeName)){if(this.type==="checkbox"||this.type==="radio")f.event.add(this,"propertychange._change",function(a){a.originalEvent.propertyName==="checked"&&(this._just_changed=!0)}),f.event.add(this,"click._change",function(a){this._just_changed&&(this._just_changed=!1,f.event.simulate("change",this,a,!0))});return!1}f.event.add(this,"beforeactivate._change",function(a){var b=a.target;A.test(b.nodeName)&&!b._change_attached&&(f.event.add(b,"change._change",function(a){this.parentNode&&!a.isSimulated&&f.event.simulate("change",this.parentNode,a,!0)}),b._change_attached=!0)})},handle:function(a){var b=a.target;if(this!==b||a.isSimulated||a.isTrigger||b.type!=="radio"&&b.type!=="checkbox")return a.handleObj.handler.apply(this,arguments)},teardown:function(){return f.event.remove(this,"._change"),A.test(this.nodeName)}}),f.support.focusinBubbles||f.each({focus:"focusin",blur:"focusout"},function(a,b){var d=0,e=function(a){f.event.simulate(b,a.target,f.event.fix(a),!0)};f.event.special[b]={setup:function(){d++===0&&c.addEventListener(a,e,!0)},teardown:function(){--d===0&&c.removeEventListener(a,e,!0)}}}),f.fn.extend({on:function(a,c,d,e,g){var h,i;if(typeof a=="object"){typeof c!="string"&&(d=c,c=b);for(i in a)this.on(i,c,d,a[i],g);return this}d==null&&e==null?(e=c,d=c=b):e==null&&(typeof c=="string"?(e=d,d=b):(e=d,d=c,c=b));if(e===!1)e=M;else if(!e)return this;return g===1&&(h=e,e=function(a){return f().off(a),h.apply(this,arguments)},e.guid=h.guid||(h.guid=f.guid++)),this.each(function(){f.event.add(this,a,e,d,c)})},one:function(a,b,c,d){return this.on.call(this,a,b,c,d,1)},off:function(a,c,d){if(a&&a.preventDefault&&a.handleObj){var e=a.handleObj;return f(a.delegateTarget).off(e.namespace?e.type+"."+e.namespace:e.type,e.selector,e.handler),this}if(typeof a=="object"){for(var g in a)this.off(g,c,a[g]);return this}if(c===!1||typeof c=="function")d=c,c=b;return d===!1&&(d=M),this.each(function(){f.event.remove(this,a,d,c)})},bind:function(a,b,c){return this.on(a,null,b,c)},unbind:function(a,b){return this.off(a,null,b)},live:function(a,b,c){return f(this.context).on(a,this.selector,b,c),this},die:function(a,b){return f(this.context).off(a,this.selector||"**",b),this},delegate:function(a,b,c,d){return this.on(b,a,c,d)},undelegate:function(a,b,c){return arguments.length==1?this.off(a,"**"):this.off(b,a,c)},trigger:function(a,b){return this.each(function(){f.event.trigger(a,b,this)})},triggerHandler:function(a,b){if(this[0])return f.event.trigger(a,b,this[0],!0)},toggle:function(a){var b=arguments,c=a.guid||f.guid++,d=0,e=function(c){var e=(f._data(this,"lastToggle"+a.guid)||0)%d;return f._data(this,"lastToggle"+a.guid,e+1),c.preventDefault(),b[e].apply(this,arguments)||!1};e.guid=c;while(d<b.length)b[d++].guid=c;return this.click(e)},hover:function(a,b){return this.mouseenter(a).mouseleave(b||a)}}),f.each("blur focus focusin focusout load resize scroll unload click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup error contextmenu".split(" "),function(a,b){f.fn[b]=function(a,c){return c==null&&(c=a,a=null),arguments.length>0?this.bind(b,a,c):this.trigger(b)},f.attrFn&&(f.attrFn[b]=!0),G.test(b)&&(f.event.fixHooks[b]=f.event.keyHooks),H.test(b)&&(f.event.fixHooks[b]=f.event.mouseHooks)}),function(){function w(a,b,c,e,f,g){for(var h=0,i=e.length;h<i;h++){var j=e[h];if(j){var k=!1;j=j[a];while(j){if(j[d]===c){k=e[j.sizset];break}j.nodeType===1&&!g&&(j[d]=c,j.sizset=h);if(j.nodeName.toLowerCase()===b){k=j;break}j=j[a]}e[h]=k}}}function x(a,b,c,e,f,g){for(var h=0,i=e.length;h<i;h++){var j=e[h];if(j){var k=!1;j=j[a];while(j){if(j[d]===c){k=e[j.sizset];break}if(j.nodeType===1){g||(j[d]=c,j.sizset=h);if(typeof b!="string"){if(j===b){k=!0;break}}else if(m.filter(b,[j]).length>0){k=j;break}}j=j[a]}e[h]=k}}}var a=/((?:\((?:\([^()]+\)|[^()]+)+\)|\[(?:\[[^\[\]]*\]|['"][^'"]*['"]|[^\[\]'"]+)+\]|\\.|[^ >+~,(\[\\]+)+|[>+~])(\s*,\s*)?((?:.|\r|\n)*)/g,d="sizcache"+(Math.random()+"").replace(".",""),e=0,g=Object.prototype.toString,h=!1,i=!0,j=/\\/g,k=/\r\n/g,l=/\W/;[0,0].sort(function(){return i=!1,0});var m=function(b,d,e,f){e=e||[],d=d||c;var h=d;if(d.nodeType!==1&&d.nodeType!==9)return[];if(!b||typeof b!="string")return e;var i,j,k,l,n,q,r,t,u=!0,v=m.isXML(d),w=[],x=b;do{a.exec(""),i=a.exec(x);if(i){x=i[3],w.push(i[1]);if(i[2]){l=i[3];break}}}while(i);if(w.length>1&&p.exec(b))if(w.length===2&&o.relative[w[0]])j=y(w[0]+w[1],d,f);else{j=o.relative[w[0]]?[d]:m(w.shift(),d);while(w.length)b=w.shift(),o.relative[b]&&(b+=w.shift()),j=y(b,j,f)}else{!f&&w.length>1&&d.nodeType===9&&!v&&o.match.ID.test(w[0])&&!o.match.ID.test(w[w.length-1])&&(n=m.find(w.shift(),d,v),d=n.expr?m.filter(n.expr,n.set)[0]:n.set[0]);if(d){n=f?{expr:w.pop(),set:s(f)}:m.find(w.pop(),w.length!==1||w[0]!=="~"&&w[0]!=="+"||!d.parentNode?d:d.parentNode,v),j=n.expr?m.filter(n.expr,n.set):n.set,w.length>0?k=s(j):u=!1;while(w.length)q=w.pop(),r=q,o.relative[q]?r=w.pop():q="",r==null&&(r=d),o.relative[q](k,r,v)}else k=w=[]}k||(k=j),k||m.error(q||b);if(g.call(k)==="[object Array]")if(!u)e.push.apply(e,k);else if(d&&d.nodeType===1)for(t=0;k[t]!=null;t++)k[t]&&(k[t]===!0||k[t].nodeType===1&&m.contains(d,k[t]))&&e.push(j[t]);else for(t=0;k[t]!=null;t++)k[t]&&k[t].nodeType===1&&e.push(j[t]);else s(k,e);return l&&(m(l,h,e,f),m.uniqueSort(e)),e};m.uniqueSort=function(a){if(u){h=i,a.sort(u);if(h)for(var b=1;b<a.length;b++)a[b]===a[b-1]&&a.splice(b--,1)}return a},m.matches=function(a,b){return m(a,null,null,b)},m.matchesSelector=function(a,b){return m(b,null,null,[a]).length>0},m.find=function(a,b,c){var d,e,f,g,h,i;if(!a)return[];for(e=0,f=o.order.length;e<f;e++){h=o.order[e];if(g=o.leftMatch[h].exec(a)){i=g[1],g.splice(1,1);if(i.substr(i.length-1)!=="\\"){g[1]=(g[1]||"").replace(j,""),d=o.find[h](g,b,c);if(d!=null){a=a.replace(o.match[h],"");break}}}}return d||(d=typeof b.getElementsByTagName!="undefined"?b.getElementsByTagName("*"):[]),{set:d,expr:a}},m.filter=function(a,c,d,e){var f,g,h,i,j,k,l,n,p,q=a,r=[],s=c,t=c&&c[0]&&m.isXML(c[0]);while(a&&c.length){for(h in o.filter)if((f=o.leftMatch[h].exec(a))!=null&&f[2]){k=o.filter[h],l=f[1],g=!1,f.splice(1,1);if(l.substr(l.length-1)==="\\")continue;s===r&&(r=[]);if(o.preFilter[h]){f=o.preFilter[h](f,s,d,r,e,t);if(!f)g=i=!0;else if(f===!0)continue}if(f)for(n=0;(j=s[n])!=null;n++)j&&(i=k(j,f,n,s),p=e^i,d&&i!=null?p?g=!0:s[n]=!1:p&&(r.push(j),g=!0));if(i!==b){d||(s=r),a=a.replace(o.match[h],"");if(!g)return[];break}}if(a===q){if(g!=null)break;m.error(a)}q=a}return s},m.error=function(a){throw"Syntax error, unrecognized expression: "+a};var n=m.getText=function(a){var b,c,d=a.nodeType,e="";if(d){if(d===1){if(typeof a.textContent=="string")return a.textContent;if(typeof a.innerText=="string")return a.innerText.replace(k,"");for(a=a.firstChild;a;a=a.nextSibling)e+=n(a)}else if(d===3||d===4)return a.nodeValue}else for(b=0;c=a[b];b++)c.nodeType!==8&&(e+=n(c));return e},o=m.selectors={order:["ID","NAME","TAG"],match:{ID:/#((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,CLASS:/\.((?:[\w\u00c0-\uFFFF\-]|\\.)+)/,NAME:/\[name=['"]*((?:[\w\u00c0-\uFFFF\-]|\\.)+)['"]*\]/,ATTR:/\[\s*((?:[\w\u00c0-\uFFFF\-]|\\.)+)\s*(?:(\S?=)\s*(?:(['"])(.*?)\3|(#?(?:[\w\u00c0-\uFFFF\-]|\\.)*)|)|)\s*\]/,TAG:/^((?:[\w\u00c0-\uFFFF\*\-]|\\.)+)/,CHILD:/:(only|nth|last|first)-child(?:\(\s*(even|odd|(?:[+\-]?\d+|(?:[+\-]?\d*)?n\s*(?:[+\-]\s*\d+)?))\s*\))?/,POS:/:(nth|eq|gt|lt|first|last|even|odd)(?:\((\d*)\))?(?=[^\-]|$)/,PSEUDO:/:((?:[\w\u00c0-\uFFFF\-]|\\.)+)(?:\((['"]?)((?:\([^\)]+\)|[^\(\)]*)+)\2\))?/},leftMatch:{},attrMap:{"class":"className","for":"htmlFor"},attrHandle:{href:function(a){return a.getAttribute("href")},type:function(a){return a.getAttribute("type")}},relative:{"+":function(a,b){var c=typeof b=="string",d=c&&!l.test(b),e=c&&!d;d&&(b=b.toLowerCase());for(var f=0,g=a.length,h;f<g;f++)if(h=a[f]){while((h=h.previousSibling)&&h.nodeType!==1);a[f]=e||h&&h.nodeName.toLowerCase()===b?h||!1:h===b}e&&m.filter(b,a,!0)},">":function(a,b){var c,d=typeof b=="string",e=0,f=a.length;if(d&&!l.test(b)){b=b.toLowerCase();for(;e<f;e++){c=a[e];if(c){var g=c.parentNode;a[e]=g.nodeName.toLowerCase()===b?g:!1}}}else{for(;e<f;e++)c=a[e],c&&(a[e]=d?c.parentNode:c.parentNode===b);d&&m.filter(b,a,!0)}},"":function(a,b,c){var d,f=e++,g=x;typeof b=="string"&&!l.test(b)&&(b=b.toLowerCase(),d=b,g=w),g("parentNode",b,f,a,d,c)},"~":function(a,b,c){var d,f=e++,g=x;typeof b=="string"&&!l.test(b)&&(b=b.toLowerCase(),d=b,g=w),g("previousSibling",b,f,a,d,c)}},find:{ID:function(a,b,c){if(typeof b.getElementById!="undefined"&&!c){var d=b.getElementById(a[1]);return d&&d.parentNode?[d]:[]}},NAME:function(a,b){if(typeof b.getElementsByName!="undefined"){var c=[],d=b.getElementsByName(a[1]);for(var e=0,f=d.length;e<f;e++)d[e].getAttribute("name")===a[1]&&c.push(d[e]);return c.length===0?null:c}},TAG:function(a,b){if(typeof b.getElementsByTagName!="undefined")return b.getElementsByTagName(a[1])}},preFilter:{CLASS:function(a,b,c,d,e,f){a=" "+a[1].replace(j,"")+" ";if(f)return a;for(var g=0,h;(h=b[g])!=null;g++)h&&(e^(h.className&&(" "+h.className+" ").replace(/[\t\n\r]/g," ").indexOf(a)>=0)?c||d.push(h):c&&(b[g]=!1));return!1},ID:function(a){return a[1].replace(j,"")},TAG:function(a,b){return a[1].replace(j,"").toLowerCase()},CHILD:function(a){if(a[1]==="nth"){a[2]||m.error(a[0]),a[2]=a[2].replace(/^\+|\s*/g,"");var b=/(-?)(\d*)(?:n([+\-]?\d*))?/.exec(a[2]==="even"&&"2n"||a[2]==="odd"&&"2n+1"||!/\D/.test(a[2])&&"0n+"+a[2]||a[2]);a[2]=b[1]+(b[2]||1)-0,a[3]=b[3]-0}else a[2]&&m.error(a[0]);return a[0]=e++,a},ATTR:function(a,b,c,d,e,f){var g=a[1]=a[1].replace(j,"");return!f&&o.attrMap[g]&&(a[1]=o.attrMap[g]),a[4]=(a[4]||a[5]||"").replace(j,""),a[2]==="~="&&(a[4]=" "+a[4]+" "),a},PSEUDO:function(b,c,d,e,f){if(b[1]==="not"){if(!((a.exec(b[3])||"").length>1||/^\w/.test(b[3]))){var g=m.filter(b[3],c,d,!0^f);return d||e.push.apply(e,g),!1}b[3]=m(b[3],null,null,c)}else if(o.match.POS.test(b[0])||o.match.CHILD.test(b[0]))return!0;return b},POS:function(a){return a.unshift(!0),a}},filters:{enabled:function(a){return a.disabled===!1&&a.type!=="hidden"},disabled:function(a){return a.disabled===!0},checked:function(a){return a.checked===!0},selected:function(a){return a.parentNode&&a.parentNode.selectedIndex,a.selected===!0},parent:function(a){return!!a.firstChild},empty:function(a){return!a.firstChild},has:function(a,b,c){return!!m(c[3],a).length},header:function(a){return/h\d/i.test(a.nodeName)},text:function(a){var b=a.getAttribute("type"),c=a.type;return a.nodeName.toLowerCase()==="input"&&"text"===c&&(b===c||b===null)},radio:function(a){return a.nodeName.toLowerCase()==="input"&&"radio"===a.type},checkbox:function(a){return a.nodeName.toLowerCase()==="input"&&"checkbox"===a.type},file:function(a){return a.nodeName.toLowerCase()==="input"&&"file"===a.type},password:function(a){return a.nodeName.toLowerCase()==="input"&&"password"===a.type},submit:function(a){var b=a.nodeName.toLowerCase();return(b==="input"||b==="button")&&"submit"===a.type},image:function(a){return a.nodeName.toLowerCase()==="input"&&"image"===a.type},reset:function(a){var b=a.nodeName.toLowerCase();return(b==="input"||b==="button")&&"reset"===a.type},button:function(a){var b=a.nodeName.toLowerCase();return b==="input"&&"button"===a.type||b==="button"},input:function(a){return/input|select|textarea|button/i.test(a.nodeName)},focus:function(a){return a===a.ownerDocument.activeElement}},setFilters:{first:function(a,b){return b===0},last:function(a,b,c,d){return b===d.length-1},even:function(a,b){return b%2===0},odd:function(a,b){return b%2===1},lt:function(a,b,c){return b<c[3]-0},gt:function(a,b,c){return b>c[3]-0},nth:function(a,b,c){return c[3]-0===b},eq:function(a,b,c){return c[3]-0===b}},filter:{PSEUDO:function(a,b,c,d){var e=b[1],f=o.filters[e];if(f)return f(a,c,b,d);if(e==="contains")return(a.textContent||a.innerText||n([a])||"").indexOf(b[3])>=0;if(e==="not"){var g=b[3];for(var h=0,i=g.length;h<i;h++)if(g[h]===a)return!1;return!0}m.error(e)},CHILD:function(a,b){var c,e,f,g,h,i,j,k=b[1],l=a;switch(k){case"only":case"first":while(l=l.previousSibling)if(l.nodeType===1)return!1;if(k==="first")return!0;l=a;case"last":while(l=l.nextSibling)if(l.nodeType===1)return!1;return!0;case"nth":c=b[2],e=b[3];if(c===1&&e===0)return!0;f=b[0],g=a.parentNode;if(g&&(g[d]!==f||!a.nodeIndex)){i=0;for(l=g.firstChild;l;l=l.nextSibling)l.nodeType===1&&(l.nodeIndex=++i);g[d]=f}return j=a.nodeIndex-e,c===0?j===0:j%c===0&&j/c>=0}},ID:function(a,b){return a.nodeType===1&&a.getAttribute("id")===b},TAG:function(a,b){return b==="*"&&a.nodeType===1||!!a.nodeName&&a.nodeName.toLowerCase()===b},CLASS:function(a,b){return(" "+(a.className||a.getAttribute("class"))+" ").indexOf(b)>-1},ATTR:function(a,b){var c=b[1],d=m.attr?m.attr(a,c):o.attrHandle[c]?o.attrHandle[c](a):a[c]!=null?a[c]:a.getAttribute(c),e=d+"",f=b[2],g=b[4];return d==null?f==="!=":!f&&m.attr?d!=null:f==="="?e===g:f==="*="?e.indexOf(g)>=0:f==="~="?(" "+e+" ").indexOf(g)>=0:g?f==="!="?e!==g:f==="^="?e.indexOf(g)===0:f==="$="?e.substr(e.length-g.length)===g:f==="|="?e===g||e.substr(0,g.length+1)===g+"-":!1:e&&d!==!1},POS:function(a,b,c,d){var e=b[2],f=o.setFilters[e];if(f)return f(a,c,b,d)}}},p=o.match.POS,q=function(a,b){return"\\"+(b-0+1)};for(var r in o.match)o.match[r]=new RegExp(o.match[r].source+/(?![^\[]*\])(?![^\(]*\))/.source),o.leftMatch[r]=new RegExp(/(^(?:.|\r|\n)*?)/.source+o.match[r].source.replace(/\\(\d+)/g,q));var s=function(a,b){return a=Array.prototype.slice.call(a,0),b?(b.push.apply(b,a),b):a};try{Array.prototype.slice.call(c.documentElement.childNodes,0)[0].nodeType}catch(t){s=function(a,b){var c=0,d=b||[];if(g.call(a)==="[object Array]")Array.prototype.push.apply(d,a);else if(typeof a.length=="number")for(var e=a.length;c<e;c++)d.push(a[c]);else for(;a[c];c++)d.push(a[c]);return d}}var u,v;c.documentElement.compareDocumentPosition?u=function(a,b){return a===b?(h=!0,0):!a.compareDocumentPosition||!b.compareDocumentPosition?a.compareDocumentPosition?-1:1:a.compareDocumentPosition(b)&4?-1:1}:(u=function(a,b){if(a===b)return h=!0,0;if(a.sourceIndex&&b.sourceIndex)return a.sourceIndex-b.sourceIndex;var c,d,e=[],f=[],g=a.parentNode,i=b.parentNode,j=g;if(g===i)return v(a,b);if(!g)return-1;if(!i)return 1;while(j)e.unshift(j),j=j.parentNode;j=i;while(j)f.unshift(j),j=j.parentNode;c=e.length,d=f.length;for(var k=0;k<c&&k<d;k++)if(e[k]!==f[k])return v(e[k],f[k]);return k===c?v(a,f[k],-1):v(e[k],b,1)},v=function(a,b,c){if(a===b)return c;var d=a.nextSibling;while(d){if(d===b)return-1;d=d.nextSibling}return 1}),function(){var a=c.createElement("div"),d="script"+(new Date).getTime(),e=c.documentElement;a.innerHTML="<a name='"+d+"'/>",e.insertBefore(a,e.firstChild),c.getElementById(d)&&(o.find.ID=function(a,c,d){if(typeof c.getElementById!="undefined"&&!d){var e=c.getElementById(a[1]);return e?e.id===a[1]||typeof e.getAttributeNode!="undefined"&&e.getAttributeNode("id").nodeValue===a[1]?[e]:b:[]}},o.filter.ID=function(a,b){var c=typeof a.getAttributeNode!="undefined"&&a.getAttributeNode("id");return a.nodeType===1&&c&&c.nodeValue===b}),e.removeChild(a),e=a=null}(),function(){var a=c.createElement("div");a.appendChild(c.createComment("")),a.getElementsByTagName("*").length>0&&(o.find.TAG=function(a,b){var c=b.getElementsByTagName(a[1]);if(a[1]==="*"){var d=[];for(var e=0;c[e];e++)c[e].nodeType===1&&d.push(c[e]);c=d}return c}),a.innerHTML="<a href='#'></a>",a.firstChild&&typeof a.firstChild.getAttribute!="undefined"&&a.firstChild.getAttribute("href")!=="#"&&(o.attrHandle.href=function(a){return a.getAttribute("href",2)}),a=null}(),c.querySelectorAll&&function(){var a=m,b=c.createElement("div"),d="__sizzle__";b.innerHTML="<p class='TEST'></p>";if(b.querySelectorAll&&b.querySelectorAll(".TEST").length===0)return;m=function(b,e,f,g){e=e||c;if(!g&&!m.isXML(e)){var h=/^(\w+$)|^\.([\w\-]+$)|^#([\w\-]+$)/.exec(b);if(h&&(e.nodeType===1||e.nodeType===9)){if(h[1])return s(e.getElementsByTagName(b),f);if(h[2]&&o.find.CLASS&&e.getElementsByClassName)return s(e.getElementsByClassName(h[2]),f)}if(e.nodeType===9){if(b==="body"&&e.body)return s([e.body],f);if(h&&h[3]){var i=e.getElementById(h[3]);if(!i||!i.parentNode)return s([],f);if(i.id===h[3])return s([i],f)}try{return s(e.querySelectorAll(b),f)}catch(j){}}else if(e.nodeType===1&&e.nodeName.toLowerCase()!=="object"){var k=e,l=e.getAttribute("id"),n=l||d,p=e.parentNode,q=/^\s*[+~]/.test(b);l?n=n.replace(/'/g,"\\$&"):e.setAttribute("id",n),q&&p&&(e=e.parentNode);try{if(!q||p)return s(e.querySelectorAll("[id='"+n+"'] "+b),f)}catch(r){}finally{l||k.removeAttribute("id")}}}return a(b,e,f,g)};for(var e in a)m[e]=a[e];b=null}(),function(){var a=c.documentElement,b=a.matchesSelector||a.mozMatchesSelector||a.webkitMatchesSelector||a.msMatchesSelector;if(b){var d=!b.call(c.createElement("div"),"div"),e=!1;try{b.call(c.documentElement,"[test!='']:sizzle")}catch(f){e=!0}m.matchesSelector=function(a,c){c=c.replace(/\=\s*([^'"\]]*)\s*\]/g,"='$1']");if(!m.isXML(a))try{if(e||!o.match.PSEUDO.test(c)&&!/!=/.test(c)){var f=b.call(a,c);if(f||!d||a.document&&a.document.nodeType!==11)return f}}catch(g){}return m(c,null,null,[a]).length>0}}}(),function(){var a=c.createElement("div");a.innerHTML="<div class='test e'></div><div class='test'></div>";if(!a.getElementsByClassName||a.getElementsByClassName("e").length===0)return;a.lastChild.className="e";if(a.getElementsByClassName("e").length===1)return;o.order.splice(1,0,"CLASS"),o.find.CLASS=function(a,b,c){if(typeof b.getElementsByClassName!="undefined"&&!c)return b.getElementsByClassName(a[1])},a=null}(),c.documentElement.contains?m.contains=function(a,b){return a!==b&&(a.contains?a.contains(b):!0)}:c.documentElement.compareDocumentPosition?m.contains=function(a,b){return!!(a.compareDocumentPosition(b)&16)}:m.contains=function(){return!1},m.isXML=function(a){var b=(a?a.ownerDocument||a:0).documentElement;return b?b.nodeName!=="HTML":!1};var y=function(a,b,c){var d,e=[],f="",g=b.nodeType?[b]:b;while(d=o.match.PSEUDO.exec(a))f+=d[0],a=a.replace(o.match.PSEUDO,"");a=o.relative[a]?a+"*":a;for(var h=0,i=g.length;h<i;h++)m(a,g[h],e,c);return m.filter(f,e)};m.attr=f.attr,m.selectors.attrMap={},f.find=m,f.expr=m.selectors,f.expr[":"]=f.expr.filters,f.unique=m.uniqueSort,f.text=m.getText,f.isXMLDoc=m.isXML,f.contains=m.contains}();var O=/Until$/,P=/^(?:parents|prevUntil|prevAll)/,Q=/,/,R=/^.[^:#\[\.,]*$/,S=Array.prototype.slice,T=f.expr.match.POS,U={children:!0,contents:!0,next:!0,prev:!0};f.fn.extend({find:function(a){var b=this,c,d;if(typeof a!="string")return f(a).filter(function(){for(c=0,d=b.length;c<d;c++)if(f.contains(b[c],this))return!0});var e=this.pushStack("","find",a),g,h,i;for(c=0,d=this.length;c<d;c++){g=e.length,f.find(a,this[c],e);if(c>0)for(h=g;h<e.length;h++)for(i=0;i<g;i++)if(e[i]===e[h]){e.splice(h--,1);break}}return e},has:function(a){var b=f(a);return this.filter(function(){for(var a=0,c=b.length;a<c;a++)if(f.contains(this,b[a]))return!0})},not:function(a){return this.pushStack(W(this,a,!1),"not",a)},filter:function(a){return this.pushStack(W(this,a,!0),"filter",a)},is:function(a){return!!a&&(typeof a=="string"?T.test(a)?f(a,this.context).index(this[0])>=0:f.filter(a,this).length>0:this.filter(a).length>0)},closest:function(a,b){var c=[],d,e,g=this[0];if(f.isArray(a)){var h=1;while(g&&g.ownerDocument&&g!==b){for(d=0;d<a.length;d++)f(g).is(a[d])&&c.push({selector:a[d],elem:g,level:h});g=g.parentNode,h++}return c}var i=T.test(a)||typeof a!="string"?f(a,b||this.context):0;for(d=0,e=this.length;d<e;d++){g=this[d];while(g){if(i?i.index(g)>-1:f.find.matchesSelector(g,a)){c.push(g);break}g=g.parentNode;if(!g||!g.ownerDocument||g===b||g.nodeType===11)break}}return c=c.length>1?f.unique(c):c,this.pushStack(c,"closest",a)},index:function(a){return a?typeof a=="string"?f.inArray(this[0],f(a)):f.inArray(a.jquery?a[0]:a,this):this[0]&&this[0].parentNode?this.prevAll().length:-1},add:function(a,b){var c=typeof a=="string"?f(a,b):f.makeArray(a&&a.nodeType?[a]:a),d=f.merge(this.get(),c);return this.pushStack(V(c[0])||V(d[0])?d:f.unique(d))},andSelf:function(){return this.add(this.prevObject)}}),f.each({parent:function(a){var b=a.parentNode;return b&&b.nodeType!==11?b:null},parents:function(a){return f.dir(a,"parentNode")},parentsUntil:function(a,b,c){return f.dir(a,"parentNode",c)},next:function(a){return f.nth(a,2,"nextSibling")},prev:function(a){return f.nth(a,2,"previousSibling")},nextAll:function(a){return f.dir(a,"nextSibling")},prevAll:function(a){return f.dir(a,"previousSibling")},nextUntil:function(a,b,c){return f.dir(a,"nextSibling",c)},prevUntil:function(a,b,c){return f.dir(a,"previousSibling",c)},siblings:function(a){return f.sibling(a.parentNode.firstChild,a)},children:function(a){return f.sibling(a.firstChild)},contents:function(a){return f.nodeName(a,"iframe")?a.contentDocument||a.contentWindow.document:f.makeArray(a.childNodes)}},function(a,b){f.fn[a]=function(c,d){var e=f.map(this,b,c),g=S.call(arguments);return O.test(a)||(d=c),d&&typeof d=="string"&&(e=f.filter(d,e)),e=this.length>1&&!U[a]?f.unique(e):e,(this.length>1||Q.test(d))&&P.test(a)&&(e=e.reverse()),this.pushStack(e,a,g.join(","))}}),f.extend({filter:function(a,b,c){return c&&(a=":not("+a+")"),b.length===1?f.find.matchesSelector(b[0],a)?[b[0]]:[]:f.find.matches(a,b)},dir:function(a,c,d){var e=[],g=a[c];while(g&&g.nodeType!==9&&(d===b||g.nodeType!==1||!f(g).is(d)))g.nodeType===1&&e.push(g),g=g[c];return e},nth:function(a,b,c,d){b=b||1;var e=0;for(;a;a=a[c])if(a.nodeType===1&&++e===b)break;return a},sibling:function(a,b){var c=[];for(;a;a=a.nextSibling)a.nodeType===1&&a!==b&&c.push(a);return c}});var Y="abbr article aside audio canvas datalist details figcaption figure footer header hgroup mark meter nav output progress section summary time video",Z=/ jQuery\d+="(?:\d+|null)"/g,$=/^\s+/,_=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/ig,ab=/<([\w:]+)/,bb=/<tbody/i,cb=/<|&#?\w+;/,db=/<(?:script|style)/i,eb=/<(?:script|object|embed|option|style)/i,fb=new RegExp("<(?:"+Y.replace(" ","|")+")","i"),gb=/checked\s*(?:[^=]|=\s*.checked.)/i,hb=/\/(java|ecma)script/i,ib=/^\s*<!(?:\[CDATA\[|\-\-)/,jb={option:[1,"<select multiple='multiple'>","</select>"],legend:[1,"<fieldset>","</fieldset>"],thead:[1,"<table>","</table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],col:[2,"<table><tbody></tbody><colgroup>","</colgroup></table>"],area:[1,"<map>","</map>"],_default:[0,"",""]},kb=X(c);jb.optgroup=jb.option,jb.tbody=jb.tfoot=jb.colgroup=jb.caption=jb.thead,jb.th=jb.td,f.support.htmlSerialize||(jb._default=[1,"div<div>","</div>"]),f.fn.extend({text:function(a){return f.isFunction(a)?this.each(function(b){var c=f(this);c.text(a.call(this,b,c.text()))}):typeof a!="object"&&a!==b?this.empty().append((this[0]&&this[0].ownerDocument||c).createTextNode(a)):f.text(this)},wrapAll:function(a){if(f.isFunction(a))return this.each(function(b){f(this).wrapAll(a.call(this,b))});if(this[0]){var b=f(a,this[0].ownerDocument).eq(0).clone(!0);this[0].parentNode&&b.insertBefore(this[0]),b.map(function(){var a=this;while(a.firstChild&&a.firstChild.nodeType===1)a=a.firstChild;return a}).append(this)}return this},wrapInner:function(a){return f.isFunction(a)?this.each(function(b){f(this).wrapInner(a.call(this,b))}):this.each(function(){var b=f(this),c=b.contents();c.length?c.wrapAll(a):b.append(a)})},wrap:function(a){return this.each(function(){f(this).wrapAll(a)})},unwrap:function(){return this.parent().each(function(){f.nodeName(this,"body")||f(this).replaceWith(this.childNodes)}).end()},append:function(){return this.domManip(arguments,!0,function(a){this.nodeType===1&&this.appendChild(a)})},prepend:function(){return this.domManip(arguments,!0,function(a){this.nodeType===1&&this.insertBefore(a,this.firstChild)})},before:function(){if(this[0]&&this[0].parentNode)return this.domManip(arguments,!1,function(a){this.parentNode.insertBefore(a,this)});if(arguments.length){var a=f(arguments[0]);return a.push.apply(a,this.toArray()),this.pushStack(a,"before",arguments)}},after:function(){if(this[0]&&this[0].parentNode)return this.domManip(arguments,!1,function(a){this.parentNode.insertBefore(a,this.nextSibling)});if(arguments.length){var a=this.pushStack(this,"after",arguments);return a.push.apply(a,f(arguments[0]).toArray()),a}},remove:function(a,b){for(var c=0,d;(d=this[c])!=null;c++)if(!a||f.filter(a,[d]).length)!b&&d.nodeType===1&&(f.cleanData(d
.getElementsByTagName("*")),f.cleanData([d])),d.parentNode&&d.parentNode.removeChild(d);return this},empty:function(){for(var a=0,b;(b=this[a])!=null;a++){b.nodeType===1&&f.cleanData(b.getElementsByTagName("*"));while(b.firstChild)b.removeChild(b.firstChild)}return this},clone:function(a,b){return a=a==null?!1:a,b=b==null?a:b,this.map(function(){return f.clone(this,a,b)})},html:function(a){if(a===b)return this[0]&&this[0].nodeType===1?this[0].innerHTML.replace(Z,""):null;if(typeof a=="string"&&!db.test(a)&&(f.support.leadingWhitespace||!$.test(a))&&!jb[(ab.exec(a)||["",""])[1].toLowerCase()]){a=a.replace(_,"<$1></$2>");try{for(var c=0,d=this.length;c<d;c++)this[c].nodeType===1&&(f.cleanData(this[c].getElementsByTagName("*")),this[c].innerHTML=a)}catch(e){this.empty().append(a)}}else f.isFunction(a)?this.each(function(b){var c=f(this);c.html(a.call(this,b,c.html()))}):this.empty().append(a);return this},replaceWith:function(a){return this[0]&&this[0].parentNode?f.isFunction(a)?this.each(function(b){var c=f(this),d=c.html();c.replaceWith(a.call(this,b,d))}):(typeof a!="string"&&(a=f(a).detach()),this.each(function(){var b=this.nextSibling,c=this.parentNode;f(this).remove(),b?f(b).before(a):f(c).append(a)})):this.length?this.pushStack(f(f.isFunction(a)?a():a),"replaceWith",a):this},detach:function(a){return this.remove(a,!0)},domManip:function(a,c,d){var e,g,h,i,j=a[0],k=[];if(!f.support.checkClone&&arguments.length===3&&typeof j=="string"&&gb.test(j))return this.each(function(){f(this).domManip(a,c,d,!0)});if(f.isFunction(j))return this.each(function(e){var g=f(this);a[0]=j.call(this,e,c?g.html():b),g.domManip(a,c,d)});if(this[0]){i=j&&j.parentNode,f.support.parentNode&&i&&i.nodeType===11&&i.childNodes.length===this.length?e={fragment:i}:e=f.buildFragment(a,this,k),h=e.fragment,h.childNodes.length===1?g=h=h.firstChild:g=h.firstChild;if(g){c=c&&f.nodeName(g,"tr");for(var l=0,m=this.length,n=m-1;l<m;l++)d.call(c?lb(this[l],g):this[l],e.cacheable||m>1&&l<n?f.clone(h,!0,!0):h)}k.length&&f.each(k,rb)}return this}}),f.buildFragment=function(a,b,d){var e,g,h,i,j=a[0];return b&&b[0]&&(i=b[0].ownerDocument||b[0]),i.createDocumentFragment||(i=c),a.length===1&&typeof j=="string"&&j.length<512&&i===c&&j.charAt(0)==="<"&&!eb.test(j)&&(f.support.checkClone||!gb.test(j))&&!f.support.unknownElems&&fb.test(j)&&(g=!0,h=f.fragments[j],h&&h!==1&&(e=h)),e||(e=i.createDocumentFragment(),f.clean(a,i,e,d)),g&&(f.fragments[j]=h?e:1),{fragment:e,cacheable:g}},f.fragments={},f.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(a,b){f.fn[a]=function(c){var d=[],e=f(c),g=this.length===1&&this[0].parentNode;if(g&&g.nodeType===11&&g.childNodes.length===1&&e.length===1)return e[b](this[0]),this;for(var h=0,i=e.length;h<i;h++){var j=(h>0?this.clone(!0):this).get();f(e[h])[b](j),d=d.concat(j)}return this.pushStack(d,a,e.selector)}}),f.extend({clone:function(a,b,c){var d=a.cloneNode(!0),e,g,h;if((!f.support.noCloneEvent||!f.support.noCloneChecked)&&(a.nodeType===1||a.nodeType===11)&&!f.isXMLDoc(a)){nb(a,d),e=ob(a),g=ob(d);for(h=0;e[h];++h)g[h]&&nb(e[h],g[h])}if(b){mb(a,d);if(c){e=ob(a),g=ob(d);for(h=0;e[h];++h)mb(e[h],g[h])}}return e=g=null,d},clean:function(a,b,d,e){var g;b=b||c,typeof b.createElement=="undefined"&&(b=b.ownerDocument||b[0]&&b[0].ownerDocument||c);var h=[],i;for(var j=0,k;(k=a[j])!=null;j++){typeof k=="number"&&(k+="");if(!k)continue;if(typeof k=="string")if(!cb.test(k))k=b.createTextNode(k);else{k=k.replace(_,"<$1></$2>");var l=(ab.exec(k)||["",""])[1].toLowerCase(),m=jb[l]||jb._default,n=m[0],o=b.createElement("div");b===c?kb.appendChild(o):X(b).appendChild(o),o.innerHTML=m[1]+k+m[2];while(n--)o=o.lastChild;if(!f.support.tbody){var p=bb.test(k),q=l==="table"&&!p?o.firstChild&&o.firstChild.childNodes:m[1]==="<table>"&&!p?o.childNodes:[];for(i=q.length-1;i>=0;--i)f.nodeName(q[i],"tbody")&&!q[i].childNodes.length&&q[i].parentNode.removeChild(q[i])}!f.support.leadingWhitespace&&$.test(k)&&o.insertBefore(b.createTextNode($.exec(k)[0]),o.firstChild),k=o.childNodes}var r;if(!f.support.appendChecked)if(k[0]&&typeof (r=k.length)=="number")for(i=0;i<r;i++)qb(k[i]);else qb(k);k.nodeType?h.push(k):h=f.merge(h,k)}if(d){g=function(a){return!a.type||hb.test(a.type)};for(j=0;h[j];j++)if(e&&f.nodeName(h[j],"script")&&(!h[j].type||h[j].type.toLowerCase()==="text/javascript"))e.push(h[j].parentNode?h[j].parentNode.removeChild(h[j]):h[j]);else{if(h[j].nodeType===1){var s=f.grep(h[j].getElementsByTagName("script"),g);h.splice.apply(h,[j+1,0].concat(s))}d.appendChild(h[j])}}return h},cleanData:function(a){var b,c,d=f.cache,e=f.event.special,g=f.support.deleteExpando;for(var h=0,i;(i=a[h])!=null;h++){if(i.nodeName&&f.noData[i.nodeName.toLowerCase()])continue;c=i[f.expando];if(c){b=d[c];if(b&&b.events){for(var j in b.events)e[j]?f.event.remove(i,j):f.removeEvent(i,j,b.handle);b.handle&&(b.handle.elem=null)}g?delete i[f.expando]:i.removeAttribute&&i.removeAttribute(f.expando),delete d[c]}}}});var sb=/alpha\([^)]*\)/i,tb=/opacity=([^)]*)/,ub=/([A-Z]|^ms)/g,vb=/^-?\d+(?:px)?$/i,wb=/^-?\d/,xb=/^([\-+])=([\-+.\de]+)/,yb={position:"absolute",visibility:"hidden",display:"block"},zb=["Left","Right"],Ab=["Top","Bottom"],Bb,Cb,Db;f.fn.css=function(a,c){return arguments.length===2&&c===b?this:f.access(this,a,c,!0,function(a,c,d){return d!==b?f.style(a,c,d):f.css(a,c)})},f.extend({cssHooks:{opacity:{get:function(a,b){if(b){var c=Bb(a,"opacity","opacity");return c===""?"1":c}return a.style.opacity}}},cssNumber:{fillOpacity:!0,fontWeight:!0,lineHeight:!0,opacity:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{"float":f.support.cssFloat?"cssFloat":"styleFloat"},style:function(a,c,d,e){if(!a||a.nodeType===3||a.nodeType===8||!a.style)return;var g,h,i=f.camelCase(c),j=a.style,k=f.cssHooks[i];c=f.cssProps[i]||i;if(d===b)return k&&"get"in k&&(g=k.get(a,!1,e))!==b?g:j[c];h=typeof d,h==="string"&&(g=xb.exec(d))&&(d=+(g[1]+1)*+g[2]+parseFloat(f.css(a,c)),h="number");if(d==null||h==="number"&&isNaN(d))return;h==="number"&&!f.cssNumber[i]&&(d+="px");if(!k||!("set"in k)||(d=k.set(a,d))!==b)try{j[c]=d}catch(l){}},css:function(a,c,d){var e,g;c=f.camelCase(c),g=f.cssHooks[c],c=f.cssProps[c]||c,c==="cssFloat"&&(c="float");if(g&&"get"in g&&(e=g.get(a,!0,d))!==b)return e;if(Bb)return Bb(a,c)},swap:function(a,b,c){var d={};for(var e in b)d[e]=a.style[e],a.style[e]=b[e];c.call(a);for(e in b)a.style[e]=d[e]}}),f.curCSS=f.css,f.each(["height","width"],function(a,b){f.cssHooks[b]={get:function(a,c,d){var e;if(c)return a.offsetWidth!==0?Eb(a,b,d):(f.swap(a,yb,function(){e=Eb(a,b,d)}),e)},set:function(a,b){if(!vb.test(b))return b;b=parseFloat(b);if(b>=0)return b+"px"}}}),f.support.opacity||(f.cssHooks.opacity={get:function(a,b){return tb.test((b&&a.currentStyle?a.currentStyle.filter:a.style.filter)||"")?parseFloat(RegExp.$1)/100+"":b?"1":""},set:function(a,b){var c=a.style,d=a.currentStyle,e=f.isNumeric(b)?"alpha(opacity="+b*100+")":"",g=d&&d.filter||c.filter||"";c.zoom=1;if(b>=1&&f.trim(g.replace(sb,""))===""){c.removeAttribute("filter");if(d&&!d.filter)return}c.filter=sb.test(g)?g.replace(sb,e):g+" "+e}}),f(function(){f.support.reliableMarginRight||(f.cssHooks.marginRight={get:function(a,b){var c;return f.swap(a,{display:"inline-block"},function(){b?c=Bb(a,"margin-right","marginRight"):c=a.style.marginRight}),c}})}),c.defaultView&&c.defaultView.getComputedStyle&&(Cb=function(a,c){var d,e,g;c=c.replace(ub,"-$1").toLowerCase();if(!(e=a.ownerDocument.defaultView))return b;if(g=e.getComputedStyle(a,null))d=g.getPropertyValue(c),d===""&&!f.contains(a.ownerDocument.documentElement,a)&&(d=f.style(a,c));return d}),c.documentElement.currentStyle&&(Db=function(a,b){var c,d,e,f=a.currentStyle&&a.currentStyle[b],g=a.style;return f===null&&g&&(e=g[b])&&(f=e),!vb.test(f)&&wb.test(f)&&(c=g.left,d=a.runtimeStyle&&a.runtimeStyle.left,d&&(a.runtimeStyle.left=a.currentStyle.left),g.left=b==="fontSize"?"1em":f||0,f=g.pixelLeft+"px",g.left=c,d&&(a.runtimeStyle.left=d)),f===""?"auto":f}),Bb=Cb||Db,f.expr&&f.expr.filters&&(f.expr.filters.hidden=function(a){var b=a.offsetWidth,c=a.offsetHeight;return b===0&&c===0||!f.support.reliableHiddenOffsets&&(a.style&&a.style.display||f.css(a,"display"))==="none"},f.expr.filters.visible=function(a){return!f.expr.filters.hidden(a)});var Fb=/%20/g,Gb=/\[\]$/,Hb=/\r?\n/g,Ib=/#.*$/,Jb=/^(.*?):[ \t]*([^\r\n]*)\r?$/mg,Kb=/^(?:color|date|datetime|datetime-local|email|hidden|month|number|password|range|search|tel|text|time|url|week)$/i,Lb=/^(?:about|app|app\-storage|.+\-extension|file|res|widget):$/,Mb=/^(?:GET|HEAD)$/,Nb=/^\/\//,Ob=/\?/,Pb=/<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,Qb=/^(?:select|textarea)/i,Rb=/\s+/,Sb=/([?&])_=[^&]*/,Tb=/^([\w\+\.\-]+:)(?:\/\/([^\/?#:]*)(?::(\d+))?)?/,Ub=f.fn.load,Vb={},Wb={},Xb,Yb,Zb=["*/"]+["*"];try{Xb=e.href}catch($b){Xb=c.createElement("a"),Xb.href="",Xb=Xb.href}Yb=Tb.exec(Xb.toLowerCase())||[],f.fn.extend({load:function(a,c,d){if(typeof a!="string"&&Ub)return Ub.apply(this,arguments);if(!this.length)return this;var e=a.indexOf(" ");if(e>=0){var g=a.slice(e,a.length);a=a.slice(0,e)}var h="GET";c&&(f.isFunction(c)?(d=c,c=b):typeof c=="object"&&(c=f.param(c,f.ajaxSettings.traditional),h="POST"));var i=this;return f.ajax({url:a,type:h,dataType:"html",data:c,complete:function(a,b,c){c=a.responseText,a.isResolved()&&(a.done(function(a){c=a}),i.html(g?f("<div>").append(c.replace(Pb,"")).find(g):c)),d&&i.each(d,[c,b,a])}}),this},serialize:function(){return f.param(this.serializeArray())},serializeArray:function(){return this.map(function(){return this.elements?f.makeArray(this.elements):this}).filter(function(){return this.name&&!this.disabled&&(this.checked||Qb.test(this.nodeName)||Kb.test(this.type))}).map(function(a,b){var c=f(this).val();return c==null?null:f.isArray(c)?f.map(c,function(a,c){return{name:b.name,value:a.replace(Hb,"\r\n")}}):{name:b.name,value:c.replace(Hb,"\r\n")}}).get()}}),f.each("ajaxStart ajaxStop ajaxComplete ajaxError ajaxSuccess ajaxSend".split(" "),function(a,b){f.fn[b]=function(a){return this.bind(b,a)}}),f.each(["get","post"],function(a,c){f[c]=function(a,d,e,g){return f.isFunction(d)&&(g=g||e,e=d,d=b),f.ajax({type:c,url:a,data:d,success:e,dataType:g})}}),f.extend({getScript:function(a,c){return f.get(a,b,c,"script")},getJSON:function(a,b,c){return f.get(a,b,c,"json")},ajaxSetup:function(a,b){return b?bc(a,f.ajaxSettings):(b=a,a=f.ajaxSettings),bc(a,b),a},ajaxSettings:{url:Xb,isLocal:Lb.test(Yb[1]),global:!0,type:"GET",contentType:"application/x-www-form-urlencoded",processData:!0,async:!0,accepts:{xml:"application/xml, text/xml",html:"text/html",text:"text/plain",json:"application/json, text/javascript","*":Zb},contents:{xml:/xml/,html:/html/,json:/json/},responseFields:{xml:"responseXML",text:"responseText"},converters:{"* text":a.String,"text html":!0,"text json":f.parseJSON,"text xml":f.parseXML},flatOptions:{context:!0,url:!0}},ajaxPrefilter:_b(Vb),ajaxTransport:_b(Wb),ajax:function(a,c){function w(a,c,l,m){if(s===2)return;s=2,q&&clearTimeout(q),p=b,n=m||"",v.readyState=a>0?4:0;var o,r,u,w=c,x=l?dc(d,v,l):b,y,z;if(a>=200&&a<300||a===304){if(d.ifModified){if(y=v.getResponseHeader("Last-Modified"))f.lastModified[k]=y;if(z=v.getResponseHeader("Etag"))f.etag[k]=z}if(a===304)w="notmodified",o=!0;else try{r=ec(d,x),w="success",o=!0}catch(A){w="parsererror",u=A}}else{u=w;if(!w||a)w="error",a<0&&(a=0)}v.status=a,v.statusText=""+(c||w),o?h.resolveWith(e,[r,w,v]):h.rejectWith(e,[v,w,u]),v.statusCode(j),j=b,t&&g.trigger("ajax"+(o?"Success":"Error"),[v,d,o?r:u]),i.fireWith(e,[v,w]),t&&(g.trigger("ajaxComplete",[v,d]),--f.active||f.event.trigger("ajaxStop"))}typeof a=="object"&&(c=a,a=b),c=c||{};var d=f.ajaxSetup({},c),e=d.context||d,g=e!==d&&(e.nodeType||e instanceof f)?f(e):f.event,h=f.Deferred(),i=f.Callbacks("once memory"),j=d.statusCode||{},k,l={},m={},n,o,p,q,r,s=0,t,u,v={readyState:0,setRequestHeader:function(a,b){if(!s){var c=a.toLowerCase();a=m[c]=m[c]||a,l[a]=b}return this},getAllResponseHeaders:function(){return s===2?n:null},getResponseHeader:function(a){var c;if(s===2){if(!o){o={};while(c=Jb.exec(n))o[c[1].toLowerCase()]=c[2]}c=o[a.toLowerCase()]}return c===b?null:c},overrideMimeType:function(a){return s||(d.mimeType=a),this},abort:function(a){return a=a||"abort",p&&p.abort(a),w(0,a),this}};h.promise(v),v.success=v.done,v.error=v.fail,v.complete=i.add,v.statusCode=function(a){if(a){var b;if(s<2)for(b in a)j[b]=[j[b],a[b]];else b=a[v.status],v.then(b,b)}return this},d.url=((a||d.url)+"").replace(Ib,"").replace(Nb,Yb[1]+"//"),d.dataTypes=f.trim(d.dataType||"*").toLowerCase().split(Rb),d.crossDomain==null&&(r=Tb.exec(d.url.toLowerCase()),d.crossDomain=!(!r||r[1]==Yb[1]&&r[2]==Yb[2]&&(r[3]||(r[1]==="http:"?80:443))==(Yb[3]||(Yb[1]==="http:"?80:443)))),d.data&&d.processData&&typeof d.data!="string"&&(d.data=f.param(d.data,d.traditional)),ac(Vb,d,c,v);if(s===2)return!1;t=d.global,d.type=d.type.toUpperCase(),d.hasContent=!Mb.test(d.type),t&&f.active++===0&&f.event.trigger("ajaxStart");if(!d.hasContent){d.data&&(d.url+=(Ob.test(d.url)?"&":"?")+d.data,delete d.data),k=d.url;if(d.cache===!1){var x=f.now(),y=d.url.replace(Sb,"$1_="+x);d.url=y+(y===d.url?(Ob.test(d.url)?"&":"?")+"_="+x:"")}}(d.data&&d.hasContent&&d.contentType!==!1||c.contentType)&&v.setRequestHeader("Content-Type",d.contentType),d.ifModified&&(k=k||d.url,f.lastModified[k]&&v.setRequestHeader("If-Modified-Since",f.lastModified[k]),f.etag[k]&&v.setRequestHeader("If-None-Match",f.etag[k])),v.setRequestHeader("Accept",d.dataTypes[0]&&d.accepts[d.dataTypes[0]]?d.accepts[d.dataTypes[0]]+(d.dataTypes[0]!=="*"?", "+Zb+"; q=0.01":""):d.accepts["*"]);for(u in d.headers)v.setRequestHeader(u,d.headers[u]);if(!d.beforeSend||d.beforeSend.call(e,v,d)!==!1&&s!==2){for(u in{success:1,error:1,complete:1})v[u](d[u]);p=ac(Wb,d,c,v);if(!p)w(-1,"No Transport");else{v.readyState=1,t&&g.trigger("ajaxSend",[v,d]),d.async&&d.timeout>0&&(q=setTimeout(function(){v.abort("timeout")},d.timeout));try{s=1,p.send(l,w)}catch(z){s<2?w(-1,z):f.error(z)}}return v}return v.abort(),!1},param:function(a,c){var d=[],e=function(a,b){b=f.isFunction(b)?b():b,d[d.length]=encodeURIComponent(a)+"="+encodeURIComponent(b)};c===b&&(c=f.ajaxSettings.traditional);if(f.isArray(a)||a.jquery&&!f.isPlainObject(a))f.each(a,function(){e(this.name,this.value)});else for(var g in a)cc(g,a[g],c,e);return d.join("&").replace(Fb,"+")}}),f.extend({active:0,lastModified:{},etag:{}});var fc=f.now(),gc=/(\=)\?(&|$)|\?\?/i;f.ajaxSetup({jsonp:"callback",jsonpCallback:function(){return f.expando+"_"+fc++}}),f.ajaxPrefilter("json jsonp",function(b,c,d){var e=b.contentType==="application/x-www-form-urlencoded"&&typeof b.data=="string";if(b.dataTypes[0]==="jsonp"||b.jsonp!==!1&&(gc.test(b.url)||e&&gc.test(b.data))){var g,h=b.jsonpCallback=f.isFunction(b.jsonpCallback)?b.jsonpCallback():b.jsonpCallback,i=a[h],j=b.url,k=b.data,l="$1"+h+"$2";return b.jsonp!==!1&&(j=j.replace(gc,l),b.url===j&&(e&&(k=k.replace(gc,l)),b.data===k&&(j+=(/\?/.test(j)?"&":"?")+b.jsonp+"="+h))),b.url=j,b.data=k,a[h]=function(a){g=[a]},d.always(function(){a[h]=i,g&&f.isFunction(i)&&a[h](g[0])}),b.converters["script json"]=function(){return g||f.error(h+" was not called"),g[0]},b.dataTypes[0]="json","script"}}),f.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/javascript|ecmascript/},converters:{"text script":function(a){return f.globalEval(a),a}}}),f.ajaxPrefilter("script",function(a){a.cache===b&&(a.cache=!1),a.crossDomain&&(a.type="GET",a.global=!1)}),f.ajaxTransport("script",function(a){if(a.crossDomain){var d,e=c.head||c.getElementsByTagName("head")[0]||c.documentElement;return{send:function(f,g){d=c.createElement("script"),d.async="async",a.scriptCharset&&(d.charset=a.scriptCharset),d.src=a.url,d.onload=d.onreadystatechange=function(a,c){if(c||!d.readyState||/loaded|complete/.test(d.readyState))d.onload=d.onreadystatechange=null,e&&d.parentNode&&e.removeChild(d),d=b,c||g(200,"success")},e.insertBefore(d,e.firstChild)},abort:function(){d&&d.onload(0,1)}}}});var hc=a.ActiveXObject?function(){for(var a in jc)jc[a](0,1)}:!1,ic=0,jc;f.ajaxSettings.xhr=a.ActiveXObject?function(){return!this.isLocal&&kc()||lc()}:kc,function(a){f.extend(f.support,{ajax:!!a,cors:!!a&&"withCredentials"in a})}(f.ajaxSettings.xhr()),f.support.ajax&&f.ajaxTransport(function(c){if(!c.crossDomain||f.support.cors){var d;return{send:function(e,g){var h=c.xhr(),i,j;c.username?h.open(c.type,c.url,c.async,c.username,c.password):h.open(c.type,c.url,c.async);if(c.xhrFields)for(j in c.xhrFields)h[j]=c.xhrFields[j];c.mimeType&&h.overrideMimeType&&h.overrideMimeType(c.mimeType),!c.crossDomain&&!e["X-Requested-With"]&&(e["X-Requested-With"]="XMLHttpRequest");try{for(j in e)h.setRequestHeader(j,e[j])}catch(k){}h.send(c.hasContent&&c.data||null),d=function(a,e){var j,k,l,m,n;try{if(d&&(e||h.readyState===4)){d=b,i&&(h.onreadystatechange=f.noop,hc&&delete jc[i]);if(e)h.readyState!==4&&h.abort();else{j=h.status,l=h.getAllResponseHeaders(),m={},n=h.responseXML,n&&n.documentElement&&(m.xml=n),m.text=h.responseText;try{k=h.statusText}catch(o){k=""}!j&&c.isLocal&&!c.crossDomain?j=m.text?200:404:j===1223&&(j=204)}}}catch(p){e||g(-1,p)}m&&g(j,k,m,l)},!c.async||h.readyState===4?d():(i=++ic,hc&&(jc||(jc={},f(a).unload(hc)),jc[i]=d),h.onreadystatechange=d)},abort:function(){d&&d(0,1)}}}});var mc={},nc,oc,pc=/^(?:toggle|show|hide)$/,qc=/^([+\-]=)?([\d+.\-]+)([a-z%]*)$/i,rc,sc=[["height","marginTop","marginBottom","paddingTop","paddingBottom"],["width","marginLeft","marginRight","paddingLeft","paddingRight"],["opacity"]],tc;f.fn.extend({show:function(a,b,c){var d,e;if(a||a===0)return this.animate(wc("show",3),a,b,c);for(var g=0,h=this.length;g<h;g++)d=this[g],d.style&&(e=d.style.display,!f._data(d,"olddisplay")&&e==="none"&&(e=d.style.display=""),e===""&&f.css(d,"display")==="none"&&f._data(d,"olddisplay",xc(d.nodeName)));for(g=0;g<h;g++){d=this[g];if(d.style){e=d.style.display;if(e===""||e==="none")d.style.display=f._data(d,"olddisplay")||""}}return this},hide:function(a,b,c){if(a||a===0)return this.animate(wc("hide",3),a,b,c);var d,e,g=0,h=this.length;for(;g<h;g++)d=this[g],d.style&&(e=f.css(d,"display"),e!=="none"&&!f._data(d,"olddisplay")&&f._data(d,"olddisplay",e));for(g=0;g<h;g++)this[g].style&&(this[g].style.display="none");return this},_toggle:f.fn.toggle,toggle:function(a,b,c){var d=typeof a=="boolean";return f.isFunction(a)&&f.isFunction(b)?this._toggle.apply(this,arguments):a==null||d?this.each(function(){var b=d?a:f(this).is(":hidden");f(this)[b?"show":"hide"]()}):this.animate(wc("toggle",3),a,b,c),this},fadeTo:function(a,b,c,d){return this.filter(":hidden").css("opacity",0).show().end().animate({opacity:b},a,c,d)},animate:function(a,b,c,d){function g(){e.queue===!1&&f._mark(this);var b=f.extend({},e),c=this.nodeType===1,d=c&&f(this).is(":hidden"),g,h,i,j,k,l,m,n,o;b.animatedProperties={};for(i in a){g=f.camelCase(i),i!==g&&(a[g]=a[i],delete a[i]),h=a[g],f.isArray(h)?(b.animatedProperties[g]=h[1],h=a[g]=h[0]):b.animatedProperties[g]=b.specialEasing&&b.specialEasing[g]||b.easing||"swing";if(h==="hide"&&d||h==="show"&&!d)return b.complete.call(this);c&&(g==="height"||g==="width")&&(b.overflow=[this.style.overflow,this.style.overflowX,this.style.overflowY],f.css(this,"display")==="inline"&&f.css(this,"float")==="none"&&(!f.support.inlineBlockNeedsLayout||xc(this.nodeName)==="inline"?this.style.display="inline-block":this.style.zoom=1))}b.overflow!=null&&(this.style.overflow="hidden");for(i in a)j=new f.fx(this,b,i),h=a[i],pc.test(h)?(o=f._data(this,"toggle"+i)||(h==="toggle"?d?"show":"hide":0),o?(f._data(this,"toggle"+i,o==="show"?"hide":"show"),j[o]()):j[h]()):(k=qc.exec(h),l=j.cur(),k?(m=parseFloat(k[2]),n=k[3]||(f.cssNumber[i]?"":"px"),n!=="px"&&(f.style(this,i,(m||1)+n),l=(m||1)/j.cur()*l,f.style(this,i,l+n)),k[1]&&(m=(k[1]==="-="?-1:1)*m+l),j.custom(l,m,n)):j.custom(l,h,""));return!0}var e=f.speed(b,c,d);return f.isEmptyObject(a)?this.each(e.complete,[!1]):(a=f.extend({},a),e.queue===!1?this.each(g):this.queue(e.queue,g))},stop:function(a,c,d){return typeof a!="string"&&(d=c,c=a,a=b),c&&a!==!1&&this.queue(a||"fx",[]),this.each(function(){function h(a,b,c){var e=b[c];f.removeData(a,c,!0),e.stop(d)}var b,c=!1,e=f.timers,g=f._data(this);d||f._unmark(!0,this);if(a==null)for(b in g)g[b].stop&&b.indexOf(".run")===b.length-4&&h(this,g,b);else g[b=a+".run"]&&g[b].stop&&h(this,g,b);for(b=e.length;b--;)e[b].elem===this&&(a==null||e[b].queue===a)&&(d?e[b](!0):e[b].saveState(),c=!0,e.splice(b,1));(!d||!c)&&f.dequeue(this,a)})}}),f.each({slideDown:wc("show",1),slideUp:wc("hide",1),slideToggle:wc("toggle",1),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(a,b){f.fn[a]=function(a,c,d){return this.animate(b,a,c,d)}}),f.extend({speed:function(a,b,c){var d=a&&typeof a=="object"?f.extend({},a):{complete:c||!c&&b||f.isFunction(a)&&a,duration:a,easing:c&&b||b&&!f.isFunction(b)&&b};d.duration=f.fx.off?0:typeof d.duration=="number"?d.duration:d.duration in f.fx.speeds?f.fx.speeds[d.duration]:f.fx.speeds._default;if(d.queue==null||d.queue===!0)d.queue="fx";return d.old=d.complete,d.complete=function(a){f.isFunction(d.old)&&d.old.call(this),d.queue?f.dequeue(this,d.queue):a!==!1&&f._unmark(this)},d},easing:{linear:function(a,b,c,d){return c+d*a},swing:function(a,b,c,d){return(-Math.cos(a*Math.PI)/2+.5)*d+c}},timers:[],fx:function(a,b,c){this.options=b,this.elem=a,this.prop=c,b.orig=b.orig||{}}}),f.fx.prototype={update:function(){this.options.step&&this.options.step.call(this.elem,this.now,this),(f.fx.step[this.prop]||f.fx.step._default)(this)},cur:function(){if(this.elem[this.prop]==null||!!this.elem.style&&this.elem.style[this.prop]!=null){var a,b=f.css(this.elem,this.prop);return isNaN(a=parseFloat(b))?!b||b==="auto"?0:b:a}return this.elem[this.prop]},custom:function(a,c,d){function h(a){return e.step(a)}var e=this,g=f.fx;this.startTime=tc||uc(),this.end=c,this.now=this.start=a,this.pos=this.state=0,this.unit=d||this.unit||(f.cssNumber[this.prop]?"":"px"),h.queue=this.options.queue,h.elem=this.elem,h.saveState=function(){e.options.hide&&f._data(e.elem,"fxshow"+e.prop)===b&&f._data(e.elem,"fxshow"+e.prop,e.start)},h()&&f.timers.push(h)&&!rc&&(rc=setInterval(g.tick,g.interval))},show:function(){var a=f._data(this.elem,"fxshow"+this.prop);this.options.orig[this.prop]=a||f.style(this.elem,this.prop),this.options.show=!0,a!==b?this.custom(this.cur(),a):this.custom(this.prop==="width"||this.prop==="height"?1:0,this.cur()),f(this.elem).show()},hide:function(){this.options.orig[this.prop]=f._data(this.elem,"fxshow"+this.prop)||f.style(this.elem,this.prop),this.options.hide=!0,this.custom(this.cur(),0)},step:function(a){var b,c,d,e=tc||uc(),g=!0,h=this.elem,i=this.options;if(a||e>=i.duration+this.startTime){this.now=this.end,this.pos=this.state=1,this.update(),i.animatedProperties[this.prop]=!0;for(b in i.animatedProperties)i.animatedProperties[b]!==!0&&(g=!1);if(g){i.overflow!=null&&!f.support.shrinkWrapBlocks&&f.each(["","X","Y"],function(a,b){h.style["overflow"+b]=i.overflow[a]}),i.hide&&f(h).hide();if(i.hide||i.show)for(b in i.animatedProperties)f.style(h,b,i.orig[b]),f.removeData(h,"fxshow"+b,!0),f.removeData(h,"toggle"+b,!0);d=i.complete,d&&(i.complete=!1,d.call(h))}return!1}return i.duration==Infinity?this.now=e:(c=e-this.startTime,this.state=c/i.duration,this.pos=f.easing[i.animatedProperties[this.prop]](this.state,c,0,1,i.duration),this.now=this.start+(this.end-this.start)*this.pos),this.update(),!0}},f.extend(f.fx,{tick:function(){var a,b=f.timers,c=0;for(;c<b.length;c++)a=b[c],!a()&&b[c]===a&&b.splice(c--,1);b.length||f.fx.stop()},interval:13,stop:function(){clearInterval(rc),rc=null},speeds:{slow:600,fast:200,_default:400},step:{opacity:function(a){f.style(a.elem,"opacity",a.now)},_default:function(a){a.elem.style&&a.elem.style[a.prop]!=null?a.elem.style[a.prop]=a.now+a.unit:a.elem[a.prop]=a.now}}}),f.each(["width","height"],function(a,b){f.fx.step[b]=function(a){f.style(a.elem,b,Math.max(0,a.now))}}),f.expr&&f.expr.filters&&(f.expr.filters.animated=function(a){return f.grep(f.timers,function(b){return a===b.elem}).length});var yc=/^t(?:able|d|h)$/i,zc=/^(?:body|html)$/i;"getBoundingClientRect"in c.documentElement?f.fn.offset=function(a){var b=this[0],c;if(a)return this.each(function(b){f.offset.setOffset(this,a,b)});if(!b||!b.ownerDocument)return null;if(b===b.ownerDocument.body)return f.offset.bodyOffset(b);try{c=b.getBoundingClientRect()}catch(d){}var e=b.ownerDocument,g=e.documentElement;if(!c||!f.contains(g,b))return c?{top:c.top,left:c.left}:{top:0,left:0};var h=e.body,i=Ac(e),j=g.clientTop||h.clientTop||0,k=g.clientLeft||h.clientLeft||0,l=i.pageYOffset||f.support.boxModel&&g.scrollTop||h.scrollTop,m=i.pageXOffset||f.support.boxModel&&g.scrollLeft||h.scrollLeft,n=c.top+l-j,o=c.left+m-k;return{top:n,left:o}}:f.fn.offset=function(a){var b=this[0];if(a)return this.each(function(b){f.offset.setOffset(this,a,b)});if(!b||!b.ownerDocument)return null;if(b===b.ownerDocument.body)return f.offset.bodyOffset(b);var c,d=b.offsetParent,e=b,g=b.ownerDocument,h=g.documentElement,i=g.body,j=g.defaultView,k=j?j.getComputedStyle(b,null):b.currentStyle,l=b.offsetTop,m=b.offsetLeft;while((b=b.parentNode)&&b!==i&&b!==h){if(f.support.fixedPosition&&k.position==="fixed")break;c=j?j.getComputedStyle(b,null):b.currentStyle,l-=b.scrollTop,m-=b.scrollLeft,b===d&&(l+=b.offsetTop,m+=b.offsetLeft,f.support.doesNotAddBorder&&(!f.support.doesAddBorderForTableAndCells||!yc.test(b.nodeName))&&(l+=parseFloat(c.borderTopWidth)||0,m+=parseFloat(c.borderLeftWidth)||0),e=d,d=b.offsetParent),f.support.subtractsBorderForOverflowNotVisible&&c.overflow!=="visible"&&(l+=parseFloat(c.borderTopWidth)||0,m+=parseFloat(c.borderLeftWidth)||0),k=c}if(k.position==="relative"||k.position==="static")l+=i.offsetTop,m+=i.offsetLeft;return f.support.fixedPosition&&k.position==="fixed"&&(l+=Math.max(h.scrollTop,i.scrollTop),m+=Math.max(h.scrollLeft,i.scrollLeft)),{top:l,left:m}},f.offset={bodyOffset:function(a){var b=a.offsetTop,c=a.offsetLeft;return f.support.doesNotIncludeMarginInBodyOffset&&(b+=parseFloat(f.css(a,"marginTop"))||0,c+=parseFloat(f.css(a,"marginLeft"))||0),{top:b,left:c}},setOffset:function(a,b,c){var d=f.css(a,"position");d==="static"&&(a.style.position="relative");var e=f(a),g=e.offset(),h=f.css(a,"top"),i=f.css(a,"left"),j=(d==="absolute"||d==="fixed")&&f.inArray("auto",[h,i])>-1,k={},l={},m,n;j?(l=e.position(),m=l.top,n=l.left):(m=parseFloat(h)||0,n=parseFloat(i)||0),f.isFunction(b)&&(b=b.call(a,c,g)),b.top!=null&&(k.top=b.top-g.top+m),b.left!=null&&(k.left=b.left-g.left+n),"using"in b?b.using.call(a,k):e.css(k)}},f.fn.extend({position:function(){if(!this[0])return null;var a=this[0],b=this.offsetParent(),c=this.offset(),d=zc.test(b[0].nodeName)?{top:0,left:0}:b.offset();return c.top-=parseFloat(f.css(a,"marginTop"))||0,c.left-=parseFloat(f.css(a,"marginLeft"))||0,d.top+=parseFloat(f.css(b[0],"borderTopWidth"))||0,d.left+=parseFloat(f.css(b[0],"borderLeftWidth"))||0,{top:c.top-d.top,left:c.left-d.left}},offsetParent:function(){return this.map(function(){var a=this.offsetParent||c.body;while(a&&!zc.test(a.nodeName)&&f.css(a,"position")==="static")a=a.offsetParent;return a})}}),f.each(["Left","Top"],function(a,c){var d="scroll"+c;f.fn[d]=function(c){var e,g;return c===b?(e=this[0],e?(g=Ac(e),g?"pageXOffset"in g?g[a?"pageYOffset":"pageXOffset"]:f.support.boxModel&&g.document.documentElement[d]||g.document.body[d]:e[d]):null):this.each(function(){g=Ac(this),g?g.scrollTo(a?f(g).scrollLeft():c,a?c:f(g).scrollTop()):this[d]=c})}}),f.each(["Height","Width"],function(a,c){var d=c.toLowerCase();f.fn["inner"+c]=function(){var a=this[0];return a?a.style?parseFloat(f.css(a,d,"padding")):this[d]():null},f.fn["outer"+c]=function(a){var b=this[0];return b?b.style?parseFloat(f.css(b,d,a?"margin":"border")):this[d]():null},f.fn[d]=function(a){var e=this[0];if(!e)return a==null?null:this;if(f.isFunction(a))return this.each(function(b){var c=f(this);c[d](a.call(this,b,c[d]()))});if(f.isWindow(e)){var g=e.document.documentElement["client"+c],h=e.document.body;return e.document.compatMode==="CSS1Compat"&&g||h&&h["client"+c]||g}if(e.nodeType===9)return Math.max(e.documentElement["client"+c],e.body["scroll"+c],e.documentElement["scroll"+c],e.body["offset"+c],e.documentElement["offset"+c]);if(a===b){var i=f.css(e,d),j=parseFloat(i);return f.isNumeric(j)?j:i}return this.css(d,typeof a=="string"?a:a+"px")}}),a.jQuery=a.$=f})(window);/*!
 * jQuery UI 1.8.13
 *
 * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://jquery.org/license
 *
 * http://docs.jquery.com/UI
 */
(function(a,b){function c(b,c){var e=b.nodeName.toLowerCase();return"area"===e?(c=b.parentNode,e=c.name,!b.href||!e||c.nodeName.toLowerCase()!=="map"?!1:(b=a("img[usemap=#"+e+"]")[0],!!b&&d(b))):(/input|select|textarea|button|object/.test(e)?!b.disabled:"a"==e?b.href||c:c)&&d(b)}function d(b){return!a(b).parents().andSelf().filter(function(){return a.curCSS(this,"visibility")==="hidden"||a.expr.filters.hidden(this)}).length}a.ui=a.ui||{},a.ui.version||(a.extend(a.ui,{version:"1.8.13",keyCode:{ALT:18,BACKSPACE:8,CAPS_LOCK:20,COMMA:188,COMMAND:91,COMMAND_LEFT:91,COMMAND_RIGHT:93,CONTROL:17,DELETE:46,DOWN:40,END:35,ENTER:13,ESCAPE:27,HOME:36,INSERT:45,LEFT:37,MENU:93,NUMPAD_ADD:107,NUMPAD_DECIMAL:110,NUMPAD_DIVIDE:111,NUMPAD_ENTER:108,NUMPAD_MULTIPLY:106,NUMPAD_SUBTRACT:109,PAGE_DOWN:34,PAGE_UP:33,PERIOD:190,RIGHT:39,SHIFT:16,SPACE:32,TAB:9,UP:38,WINDOWS:91}}),a.fn.extend({_focus:a.fn.focus,focus:function(b,c){return typeof b=="number"?this.each(function(){var d=this;setTimeout(function(){a(d).focus(),c&&c.call(d)},b)}):this._focus.apply(this,arguments)},scrollParent:function(){var b;return b=a.browser.msie&&/(static|relative)/.test(this.css("position"))||/absolute/.test(this.css("position"))?this.parents().filter(function(){return/(relative|absolute|fixed)/.test(a.curCSS(this,"position",1))&&/(auto|scroll)/.test(a.curCSS(this,"overflow",1)+a.curCSS(this,"overflow-y",1)+a.curCSS(this,"overflow-x",1))}).eq(0):this.parents().filter(function(){return/(auto|scroll)/.test(a.curCSS(this,"overflow",1)+a.curCSS(this,"overflow-y",1)+a.curCSS(this,"overflow-x",1))}).eq(0),/fixed/.test(this.css("position"))||!b.length?a(document):b},zIndex:function(c){if(c!==b)return this.css("zIndex",c);if(this.length){c=a(this[0]);for(var d;c.length&&c[0]!==document;){d=c.css("position");if(d==="absolute"||d==="relative"||d==="fixed"){d=parseInt(c.css("zIndex"),10);if(!isNaN(d)&&d!==0)return d}c=c.parent()}}return 0},disableSelection:function(){return this.bind((a.support.selectstart?"selectstart":"mousedown")+".ui-disableSelection",function(a){a.preventDefault()})},enableSelection:function(){return this.unbind(".ui-disableSelection")}}),a.each(["Width","Height"],function(c,d){function e(b,c,d,e){return a.each(f,function(){c-=parseFloat(a.curCSS(b,"padding"+this,!0))||0,d&&(c-=parseFloat(a.curCSS(b,"border"+this+"Width",!0))||0),e&&(c-=parseFloat(a.curCSS(b,"margin"+this,!0))||0)}),c}var f=d==="Width"?["Left","Right"]:["Top","Bottom"],g=d.toLowerCase(),h={innerWidth:a.fn.innerWidth,innerHeight:a.fn.innerHeight,outerWidth:a.fn.outerWidth,outerHeight:a.fn.outerHeight};a.fn["inner"+d]=function(c){return c===b?h["inner"+d].call(this):this.each(function(){a(this).css(g,e(this,c)+"px")})},a.fn["outer"+d]=function(b,c){return typeof b!="number"?h["outer"+d].call(this,b):this.each(function(){a(this).css(g,e(this,b,!0,c)+"px")})}}),a.extend(a.expr[":"],{data:function(b,c,d){return!!a.data(b,d[3])},focusable:function(b){return c(b,!isNaN(a.attr(b,"tabindex")))},tabbable:function(b){var d=a.attr(b,"tabindex"),e=isNaN(d);return(e||d>=0)&&c(b,!e)}}),a(function(){var b=document.body,c=b.appendChild(c=document.createElement("div"));a.extend(c.style,{minHeight:"100px",height:"auto",padding:0,borderWidth:0}),a.support.minHeight=c.offsetHeight===100,a.support.selectstart="onselectstart"in c,b.removeChild(c).style.display="none"}),a.extend(a.ui,{plugin:{add:function(b,c,d){b=a.ui[b].prototype;for(var e in d)b.plugins[e]=b.plugins[e]||[],b.plugins[e].push([c,d[e]])},call:function(a,b,c){if((b=a.plugins[b])&&a.element[0].parentNode)for(var d=0;d<b.length;d++)a.options[b[d][0]]&&b[d][1].apply(a.element,c)}},contains:function(a,b){return document.compareDocumentPosition?a.compareDocumentPosition(b)&16:a!==b&&a.contains(b)},hasScroll:function(b,c){if(a(b).css("overflow")==="hidden")return!1;c=c&&c==="left"?"scrollLeft":"scrollTop";var d=!1;return b[c]>0?!0:(b[c]=1,d=b[c]>0,b[c]=0,d)},isOverAxis:function(a,b,c){return a>b&&a<b+c},isOver:function(b,c,d,e,f,g){return a.ui.isOverAxis(b,d,f)&&a.ui.isOverAxis(c,e,g)}}))})(jQuery),function(a,b){if(a.cleanData){var c=a.cleanData;a.cleanData=function(b){for(var d=0,e;(e=b[d])!=null;d++)a(e).triggerHandler("remove");c(b)}}else{var d=a.fn.remove;a.fn.remove=function(b,c){return this.each(function(){return c||(!b||a.filter(b,[this]).length)&&a("*",this).add([this]).each(function(){a(this).triggerHandler("remove")}),d.call(a(this),b,c)})}}a.widget=function(b,c,d){var e=b.split(".")[0],f;b=b.split(".")[1],f=e+"-"+b,d||(d=c,c=a.Widget),a.expr[":"][f]=function(c){return!!a.data(c,b)},a[e]=a[e]||{},a[e][b]=function(a,b){arguments.length&&this._createWidget(a,b)},c=new c,c.options=a.extend(!0,{},c.options),a[e][b].prototype=a.extend(!0,c,{namespace:e,widgetName:b,widgetEventPrefix:a[e][b].prototype.widgetEventPrefix||b,widgetBaseClass:f},d),a.widget.bridge(b,a[e][b])},a.widget.bridge=function(c,d){a.fn[c]=function(e){var f=typeof e=="string",g=Array.prototype.slice.call(arguments,1),h=this;return e=!f&&g.length?a.extend.apply(null,[!0,e].concat(g)):e,f&&e.charAt(0)==="_"?h:(f?this.each(function(){var d=a.data(this,c),f=d&&a.isFunction(d[e])?d[e].apply(d,g):d;if(f!==d&&f!==b)return h=f,!1}):this.each(function(){var b=a.data(this,c);b?b.option(e||{})._init():a.data(this,c,new d(e,this))}),h)}},a.Widget=function(a,b){arguments.length&&this._createWidget(a,b)},a.Widget.prototype={widgetName:"widget",widgetEventPrefix:"",options:{disabled:!1},_createWidget:function(b,c){a.data(c,this.widgetName,this),this.element=a(c),this.options=a.extend(!0,{},this.options,this._getCreateOptions(),b);var d=this;this.element.bind("remove."+this.widgetName,function(){d.destroy()}),this._create(),this._trigger("create"),this._init()},_getCreateOptions:function(){return a.metadata&&a.metadata.get(this.element[0])[this.widgetName]},_create:function(){},_init:function(){},destroy:function(){this.element.unbind("."+this.widgetName).removeData(this.widgetName),this.widget().unbind("."+this.widgetName).removeAttr("aria-disabled").removeClass(this.widgetBaseClass+"-disabled ui-state-disabled")},widget:function(){return this.element},option:function(c,d){var e=c;if(arguments.length===0)return a.extend({},this.options);if(typeof c=="string"){if(d===b)return this.options[c];e={},e[c]=d}return this._setOptions(e),this},_setOptions:function(b){var c=this;return a.each(b,function(a,b){c._setOption(a,b)}),this},_setOption:function(a,b){return this.options[a]=b,a==="disabled"&&this.widget()[b?"addClass":"removeClass"](this.widgetBaseClass+"-disabled ui-state-disabled").attr("aria-disabled",b),this},enable:function(){return this._setOption("disabled",!1)},disable:function(){return this._setOption("disabled",!0)},_trigger:function(b,c,d){var e=this.options[b];c=a.Event(c),c.type=(b===this.widgetEventPrefix?b:this.widgetEventPrefix+b).toLowerCase(),d=d||{};if(c.originalEvent){b=a.event.props.length;for(var f;b;)f=a.event.props[--b],c[f]=c.originalEvent[f]}return this.element.trigger(c,d),!(a.isFunction(e)&&e.call(this.element[0],c,d)===!1||c.isDefaultPrevented())}}}(jQuery),function(a,b){var c=!1;a(document).mousedown(function(a){c=!1}),a.widget("ui.mouse",{options:{cancel:":input,option",distance:1,delay:0},_mouseInit:function(){var b=this;this.element.bind("mousedown."+this.widgetName,function(a){return b._mouseDown(a)}).bind("click."+this.widgetName,function(c){if(!0===a.data(c.target,b.widgetName+".preventClickEvent"))return a.removeData(c.target,b.widgetName+".preventClickEvent"),c.stopImmediatePropagation(),!1}),this.started=!1},_mouseDestroy:function(){this.element.unbind("."+this.widgetName)},_mouseDown:function(b){a(this.document||document).mousedown(function(a){c=!1});if(c)return;this._mouseStarted&&this._mouseUp(b),this._mouseDownEvent=b;var d=this,e=b.which==1,f=typeof this.options.cancel=="string"?a(b.target).parents().add(b.target).filter(this.options.cancel).length:!1;if(!e||f||!this._mouseCapture(b))return!0;this.mouseDelayMet=!this.options.delay,this.mouseDelayMet||(this._mouseDelayTimer=setTimeout(function(){d.mouseDelayMet=!0},this.options.delay));if(this._mouseDistanceMet(b)&&this._mouseDelayMet(b)){this._mouseStarted=this._mouseStart(b)!==!1;if(!this._mouseStarted)return b.preventDefault(),!0}return!0===a.data(b.target,this.widgetName+".preventClickEvent")&&a.removeData(b.target,this.widgetName+".preventClickEvent"),this._mouseMoveDelegate=function(a){return d._mouseMove(a)},this._mouseUpDelegate=function(a){return d._mouseUp(a)},a(this.document||document).bind("mousemove."+this.widgetName,this._mouseMoveDelegate).bind("mouseup."+this.widgetName,this._mouseUpDelegate),b.preventDefault(),c=!0,!0},_mouseMove:function(b){return!a.browser.msie||(this.document||document).documentMode>=9||!!b.button?this._mouseStarted?(this._mouseDrag(b),b.preventDefault()):(this._mouseDistanceMet(b)&&this._mouseDelayMet(b)&&(this._mouseStarted=this._mouseStart(this._mouseDownEvent,b)!==!1,this._mouseStarted?this._mouseDrag(b):this._mouseUp(b)),!this._mouseStarted):this._mouseUp(b)},_mouseUp:function(b){return a(this.document||document).unbind("mousemove."+this.widgetName,this._mouseMoveDelegate).unbind("mouseup."+this.widgetName,this._mouseUpDelegate),this._mouseStarted&&(this._mouseStarted=!1,b.target==this._mouseDownEvent.target&&a.data(b.target,this.widgetName+".preventClickEvent",!0),this._mouseStop(b)),!1},_mouseDistanceMet:function(a){return Math.max(Math.abs(this._mouseDownEvent.pageX-a.pageX),Math.abs(this._mouseDownEvent.pageY-a.pageY))>=this.options.distance},_mouseDelayMet:function(a){return this.mouseDelayMet},_mouseStart:function(a){},_mouseDrag:function(a){},_mouseStop:function(a){},_mouseCapture:function(a){return!0}})}(jQuery),function(a){a.widget("ui.draggable",a.ui.mouse,{widgetEventPrefix:"drag",options:{addClasses:!0,appendTo:"parent",axis:!1,connectToSortable:!1,containment:!1,cursor:"auto",cursorAt:!1,grid:!1,handle:!1,helper:"original",iframeFix:!1,opacity:!1,refreshPositions:!1,revert:!1,revertDuration:500,scope:"default",scroll:!0,scrollSensitivity:20,scrollSpeed:20,snap:!1,snapMode:"both",snapTolerance:20,stack:!1,zIndex:!1},_create:function(){this.options.helper=="original"&&!/^(?:r|a|f)/.test(this.element.css("position"))&&(this.element[0].style.position="relative"),this.options.addClasses&&this.element.addClass("ui-draggable"),this.options.disabled&&this.element.addClass("ui-draggable-disabled"),this._mouseInit()},destroy:function(){if(this.element.data("draggable"))return this.element.removeData("draggable").unbind(".draggable").removeClass("ui-draggable ui-draggable-dragging ui-draggable-disabled"),this._mouseDestroy(),this},_mouseCapture:function(b){var c=this.options;return this.helper||c.disabled||a(b.target).is(".ui-resizable-handle")?!1:(this.handle=this._getHandle(b),this.handle?(a(c.iframeFix===!0?"iframe":c.iframeFix).each(function(){a('<div class="ui-draggable-iframeFix" style="background: #fff;"></div>').css({width:this.offsetWidth+"px",height:this.offsetHeight+"px",position:"absolute",opacity:"0.001",zIndex:1e3}).css(a(this).offset()).appendTo("body")}),!0):!1)},_mouseStart:function(b){var c=this.options;return this.helper=this._createHelper(b),this._cacheHelperProportions(),a.ui.ddmanager&&(a.ui.ddmanager.current=this),this._cacheMargins(),this.cssPosition=this.helper.css("position"),this.scrollParent=this.helper.scrollParent(),this.offset=this.positionAbs=this.element.offset(),this.offset={top:this.offset.top-this.margins.top,left:this.offset.left-this.margins.left},a.extend(this.offset,{click:{left:b.pageX-this.offset.left,top:b.pageY-this.offset.top},parent:this._getParentOffset(),relative:this._getRelativeOffset()}),this.originalPosition=this.position=this._generatePosition(b),this.originalPageX=b.pageX,this.originalPageY=b.pageY,c.cursorAt&&this._adjustOffsetFromHelper(c.cursorAt),c.containment&&this._setContainment(),this._trigger("start",b)===!1?(this._clear(),!1):(this._cacheHelperProportions(),a.ui.ddmanager&&!c.dropBehaviour&&a.ui.ddmanager.prepareOffsets(this,b),this.helper.addClass("ui-draggable-dragging"),this._mouseDrag(b,!0),!0)},_mouseDrag:function(b,c){this.position=this._generatePosition(b),this.positionAbs=this._convertPositionTo("absolute");if(!c){c=this._uiHash();if(this._trigger("drag",b,c)===!1)return this._mouseUp({}),!1;this.position=c.position}if(!this.options.axis||this.options.axis!="y")this.helper[0].style.left=this.position.left+"px";if(!this.options.axis||this.options.axis!="x")this.helper[0].style.top=this.position.top+"px";return a.ui.ddmanager&&a.ui.ddmanager.drag(this,b),!1},_mouseStop:function(b){var c=!1;a.ui.ddmanager&&!this.options.dropBehaviour&&(c=a.ui.ddmanager.drop(this,b)),this.dropped&&(c=this.dropped,this.dropped=!1);if((!this.element[0]||!this.element[0].parentNode)&&this.options.helper=="original")return!1;if(this.options.revert=="invalid"&&!c||this.options.revert=="valid"&&c||this.options.revert===!0||a.isFunction(this.options.revert)&&this.options.revert.call(this.element,c)){var e=this;a(this.helper).animate(this.originalPosition,parseInt(this.options.revertDuration,10),function(){e._trigger("stop",b)!==!1&&e._clear()})}else this._trigger("stop",b)!==!1&&this._clear();return!1},_mouseUp:function(b){return this.options.iframeFix===!0&&a("div.ui-draggable-iframeFix").each(function(){this.parentNode.removeChild(this)}),a.ui.mouse.prototype._mouseUp.call(this,b)},cancel:function(){return this.helper.is(".ui-draggable-dragging")?this._mouseUp({}):this._clear(),this},_getHandle:function(b){var c=!this.options.handle||!a(this.options.handle,this.element).length?!0:!1;return a(this.options.handle,this.element).find("*").andSelf().each(function(){this==b.target&&(c=!0)}),c},_createHelper:function(b){var c=this.options;return b=a.isFunction(c.helper)?a(c.helper.apply(this.element[0],[b])):c.helper=="clone"?this.element.clone().removeAttr("id"):this.element,b.parents("body").length||b.appendTo(c.appendTo=="parent"?this.element[0].parentNode:c.appendTo),b[0]!=this.element[0]&&!/(fixed|absolute)/.test(b.css("position"))&&b.css("position","absolute"),b},_adjustOffsetFromHelper:function(b){typeof b=="string"&&(b=b.split(" ")),a.isArray(b)&&(b={left:+b[0],top:+b[1]||0}),"left"in b&&(this.offset.click.left=b.left+this.margins.left),"right"in b&&(this.offset.click.left=this.helperProportions.width-b.right+this.margins.left),"top"in b&&(this.offset.click.top=b.top+this.margins.top),"bottom"in b&&(this.offset.click.top=this.helperProportions.height-b.bottom+this.margins.top)},_getParentOffset:function(){this.offsetParent=this.helper.offsetParent();var b=this.offsetParent.offset();this.cssPosition=="absolute"&&this.scrollParent[0]!=document&&a.ui.contains(this.scrollParent[0],this.offsetParent[0])&&(b.left+=this.scrollParent.scrollLeft(),b.top+=this.scrollParent.scrollTop());if(this.offsetParent[0]==document.body||this.offsetParent[0].tagName&&this.offsetParent[0].tagName.toLowerCase()=="html"&&a.browser.msie)b={top:0,left:0};return{top:b.top+(parseInt(this.offsetParent.css("borderTopWidth"),10)||0),left:b.left+(parseInt(this.offsetParent.css("borderLeftWidth"),10)||0)}},_getRelativeOffset:function(){if(this.cssPosition=="relative"){var a=this.element.position();return{top:a.top-(parseInt(this.helper.css("top"),10)||0)+this.scrollParent.scrollTop(),left:a.left-(parseInt(this.helper.css("left"),10)||0)+this.scrollParent.scrollLeft()}}return{top:0,left:0}},_cacheMargins:function(){this.margins={left:parseInt(this.element.css("marginLeft"),10)||0,top:parseInt(this.element.css("marginTop"),10)||0,right:parseInt(this.element.css("marginRight"),10)||0,bottom:parseInt(this.element.css("marginBottom"),10)||0}},_cacheHelperProportions:function(){this.helperProportions={width:this.helper.outerWidth(),height:this.helper.outerHeight()}},_setContainment:function(){var b=this.options;b.containment=="parent"&&(b.containment=this.helper[0].parentNode);if(b.containment=="document"||b.containment=="window")this.containment=[(b.containment=="document"?0:a(window).scrollLeft())-this.offset.relative.left-this.offset.parent.left,(b.containment=="document"?0:a(window).scrollTop())-this.offset.relative.top-this.offset.parent.top,(b.containment=="document"?0:a(window).scrollLeft())+a(b.containment=="document"?document:window).width()-this.helperProportions.width-this.margins.left,(b.containment=="document"?0:a(window).scrollTop())+(a(b.containment=="document"?document:window).height()||document.body.parentNode.scrollHeight)-this.helperProportions.height-this.margins.top];if(!/^(document|window|parent)$/.test(b.containment)&&b.containment.constructor!=Array){b=a(b.containment);var c=b[0];if(c){b.offset();var e=a(c).css("overflow")!="hidden";this.containment=[(parseInt(a(c).css("borderLeftWidth"),10)||0)+(parseInt(a(c).css("paddingLeft"),10)||0),(parseInt(a(c).css("borderTopWidth"),10)||0)+(parseInt(a(c).css("paddingTop"),10)||0),(e?Math.max(c.scrollWidth,c.offsetWidth):c.offsetWidth)-(parseInt(a(c).css("borderLeftWidth"),10)||0)-(parseInt(a(c).css("paddingRight"),10)||0)-this.helperProportions.width-this.margins.left-this.margins.right,(e?Math.max(c.scrollHeight,c.offsetHeight):c.offsetHeight)-(parseInt(a(c).css("borderTopWidth"),10)||0)-(parseInt(a(c).css("paddingBottom"),10)||0)-this.helperProportions.height-this.margins.top-this.margins.bottom],this.relative_container=b}}else b.containment.constructor==Array&&(this.containment=b.containment)},_convertPositionTo:function(b,c){c||(c=this.position),b=b=="absolute"?1:-1;var e=this.cssPosition!="absolute"||this.scrollParent[0]!=document&&!!a.ui.contains(this.scrollParent[0],this.offsetParent[0])?this.scrollParent:this.offsetParent,f=/(html|body)/i.test(e[0].tagName);return{top:c.top+this.offset.relative.top*b+this.offset.parent.top*b-(a.browser.safari&&a.browser.version<526&&this.cssPosition=="fixed"?0:(this.cssPosition=="fixed"?-this.scrollParent.scrollTop():f?0:e.scrollTop())*b),left:c.left+this.offset.relative.left*b+this.offset.parent.left*b-(a.browser.safari&&a.browser.version<526&&this.cssPosition=="fixed"?0:(this.cssPosition=="fixed"?-this.scrollParent.scrollLeft():f?0:e.scrollLeft())*b)}},_generatePosition:function(b){var c=this.options,e=this.cssPosition!="absolute"||this.scrollParent[0]!=document&&!!a.ui.contains(this.scrollParent[0],this.offsetParent[0])?this.scrollParent:this.offsetParent,f=/(html|body)/i.test(e[0].tagName),g=b.pageX,h=b.pageY;if(this.originalPosition){var i;this.containment&&(this.relative_container?(i=this.relative_container.offset(),i=[this.containment[0]+i.left,this.containment[1]+i.top,this.containment[2]+i.left,this.containment[3]+i.top]):i=this.containment,b.pageX-this.offset.click.left<i[0]&&(g=i[0]+this.offset.click.left),b.pageY-this.offset.click.top<i[1]&&(h=i[1]+this.offset.click.top),b.pageX-this.offset.click.left>i[2]&&(g=i[2]+this.offset.click.left),b.pageY-this.offset.click.top>i[3]&&(h=i[3]+this.offset.click.top)),c.grid&&(h=this.originalPageY+Math.round((h-this.originalPageY)/c.grid[1])*c.grid[1],h=i?h-this.offset.click.top<i[1]||h-this.offset.click.top>i[3]?h-this.offset.click.top<i[1]?h+c.grid[1]:h-c.grid[1]:h:h,g=this.originalPageX+Math.round((g-this.originalPageX)/c.grid[0])*c.grid[0],g=i?g-this.offset.click.left<i[0]||g-this.offset.click.left>i[2]?g-this.offset.click.left<i[0]?g+c.grid[0]:g-c.grid[0]:g:g)}return{top:h-this.offset.click.top-this.offset.relative.top-this.offset.parent.top+(a.browser.safari&&a.browser.version<526&&this.cssPosition=="fixed"?0:this.cssPosition=="fixed"?-this.scrollParent.scrollTop():f?0:e.scrollTop()),left:g-this.offset.click.left-this.offset.relative.left-this.offset.parent.left+(a.browser.safari&&a.browser.version<526&&this.cssPosition=="fixed"?0:this.cssPosition=="fixed"?-this.scrollParent.scrollLeft():f?0:e.scrollLeft())}},_clear:function(){this.helper.removeClass("ui-draggable-dragging"),this.helper[0]!=this.element[0]&&!this.cancelHelperRemoval&&this.helper.remove(),this.helper=null,this.cancelHelperRemoval=!1},_trigger:function(b,c,e){return e=e||this._uiHash(),a.ui.plugin.call(this,b,[c,e]),b=="drag"&&(this.positionAbs=this._convertPositionTo("absolute")),a.Widget.prototype._trigger.call(this,b,c,e)},plugins:{},_uiHash:function(){return{helper:this.helper,position:this.position,originalPosition:this.originalPosition,offset:this.positionAbs}}}),a.extend(a.ui.draggable,{version:"1.8.13"}),a.ui.plugin.add("draggable","connectToSortable",{start:function(b,c){var e=a(this).data("draggable"),f=e.options,g=a.extend({},c,{item:e.element});e.sortables=[],a(f.connectToSortable).each(function(){var c=a.data(this,"sortable");c&&!c.options.disabled&&(e.sortables.push({instance:c,shouldRevert:c.options.revert}),c.refreshPositions(),c._trigger("activate",b,g))})},stop:function(b,c){var e=a(this).data("draggable"),f=a.extend({},c,{item:e.element});a.each(e.sortables,function(){this.instance.isOver?(this.instance.isOver=0,e.cancelHelperRemoval=!0,this.instance.cancelHelperRemoval=!1,this.shouldRevert&&(this.instance.options.revert=!0),this.instance._mouseStop(b),this.instance.options.helper=this.instance.options._helper,e.options.helper=="original"&&this.instance.currentItem.css({top:"auto",left:"auto"})):(this.instance.cancelHelperRemoval=!1,this.instance._trigger("deactivate",b,f))})},drag:function(b,c){var e=a(this).data("draggable"),f=this;a.each(e.sortables,function(){this.instance.positionAbs=e.positionAbs,this.instance.helperProportions=e.helperProportions,this.instance.offset.click=e.offset.click,this.instance._intersectsWith(this.instance.containerCache)?(this.instance.isOver||(this.instance.isOver=1,this.instance.currentItem=a(f).clone().removeAttr("id").appendTo(this.instance.element).data("sortable-item",!0),this.instance.options._helper=this.instance.options.helper,this.instance.options.helper=function(){return c.helper[0]},b.target=this.instance.currentItem[0],this.instance._mouseCapture(b,!0),this.instance._mouseStart(b,!0,!0),this.instance.offset.click.top=e.offset.click.top,this.instance.offset.click.left=e.offset.click.left,this.instance.offset.parent.left-=e.offset.parent.left-this.instance.offset.parent.left,this.instance.offset.parent.top-=e.offset.parent.top-this.instance.offset.parent.top,e._trigger("toSortable",b),e.dropped=this.instance.element,e.currentItem=e.element,this.instance.fromOutside=e),this.instance.currentItem&&this.instance._mouseDrag(b)):this.instance.isOver&&(this.instance.isOver=0,this.instance.cancelHelperRemoval=!0,this.instance.options.revert=!1,this.instance._trigger("out",b,this.instance._uiHash(this.instance)),this.instance._mouseStop(b,!0),this.instance.options.helper=this.instance.options._helper,this.instance.currentItem.remove(),this.instance.placeholder&&this.instance.placeholder.remove(),e._trigger("fromSortable",b),e.dropped=!1)})}}),a.ui.plugin.add("draggable","cursor",{start:function(){var b=a("body"),c=a(this).data("draggable").options;b.css("cursor")&&(c._cursor=b.css("cursor")),b.css("cursor",c.cursor)},stop:function(){var b=a(this).data("draggable").options;b._cursor&&a("body").css("cursor",b._cursor)}}),a.ui.plugin.add("draggable","opacity",{start:function(b,c){b=a(c.helper),c=a(this).data("draggable").options,b.css("opacity")&&(c._opacity=b.css("opacity")),b.css("opacity",c.opacity)},stop:function(b,c){b=a(this).data("draggable").options,b._opacity&&a(c.helper).css("opacity",b._opacity)}}),a.ui.plugin.add("draggable","scroll",{start:function(){var b=a(this).data("draggable");b.scrollParent[0]!=document&&b.scrollParent[0].tagName!="HTML"&&(b.overflowOffset=b.scrollParent.offset())},drag:function(b){var c=a(this).data("draggable"),e=c.options,f=!1;if(c.scrollParent[0]!=document&&c.scrollParent[0].tagName!="HTML"){if(!e.axis||e.axis!="x")c.overflowOffset.top+c.scrollParent[0].offsetHeight-b.pageY<e.scrollSensitivity?c.scrollParent[0].scrollTop=f=c.scrollParent[0].scrollTop+e.scrollSpeed:b.pageY-c.overflowOffset.top<e.scrollSensitivity&&(c.scrollParent[0].scrollTop=f=c.scrollParent[0].scrollTop-e.scrollSpeed);if(!e.axis||e.axis!="y")c.overflowOffset.left+c.scrollParent[0].offsetWidth-b.pageX<e.scrollSensitivity?c.scrollParent[0].scrollLeft=f=c.scrollParent[0].scrollLeft+e.scrollSpeed:b.pageX-c.overflowOffset.left<e.scrollSensitivity&&(c.scrollParent[0].scrollLeft=f=c.scrollParent[0].scrollLeft-e.scrollSpeed)}else{if(!e.axis||e.axis!="x")b.pageY-a(document).scrollTop()<e.scrollSensitivity?f=a(document).scrollTop(a(document).scrollTop()-e.scrollSpeed):a(window).height()-(b.pageY-a(document).scrollTop())<e.scrollSensitivity&&(f=a(document).scrollTop(a(document).scrollTop()+e.scrollSpeed));if(!e.axis||e.axis!="y")b.pageX-a(document).scrollLeft()<e.scrollSensitivity?f=a(document).scrollLeft(a(document).scrollLeft()-e.scrollSpeed):a(window).width()-(b.pageX-a(document).scrollLeft())<e.scrollSensitivity&&(f=a(document).scrollLeft(a(document).scrollLeft()+e.scrollSpeed))}f!==!1&&a.ui.ddmanager&&!e.dropBehaviour&&a.ui.ddmanager.prepareOffsets(c,b)}}),a.ui.plugin.add("draggable","snap",{start:function(){var b=a(this).data("draggable"),c=b.options;b.snapElements=[],a(c.snap.constructor!=String?c.snap.items||":data(draggable)":c.snap).each(function(){var c=a(this),e=c.offset();this!=b.element[0]&&b.snapElements.push({item:this,width:c.outerWidth(),height:c.outerHeight(),top:e.top,left:e.left})})},drag:function(b,c){for(var e=a(this).data("draggable"),f=e.options,g=f.snapTolerance,h=c.offset.left,i=h+e.helperProportions.width,j=c.offset.top,k=j+e.helperProportions.height,l=e.snapElements.length-1;l>=0;l--){var m=e.snapElements[l].left,n=m+e.snapElements[l].width,o=e.snapElements[l].top,p=o+e.snapElements[l].height;if(m-g<h&&h<n+g&&o-g<j&&j<p+g||m-g<h&&h<n+g&&o-g<k&&k<p+g||m-g<i&&i<n+g&&o-g<j&&j<p+g||m-g<i&&i<n+g&&o-g<k&&k<p+g){if(f.snapMode!="inner"){var q=Math.abs(o-k)<=g,r=Math.abs(p-j)<=g,s=Math.abs(m-i)<=g,t=Math.abs(n-h)<=g;q&&(c.position.top=e._convertPositionTo("relative",{top:o-e.helperProportions.height,left:0}).top-e.margins.top),r&&(c.position.top=e._convertPositionTo("relative",{top:p,left:0}).top-e.margins.top),s&&(c.position.left=e._convertPositionTo("relative",{top:0,left:m-e.helperProportions.width}).left-e.margins.left),t&&(c.position.left=e._convertPositionTo("relative",{top:0,left:n}).left-e.margins.left)}var u=q||r||s||t;f.snapMode!="outer"&&(q=Math.abs(o-j)<=g,r=Math.abs(p-k)<=g,s=Math.abs(m-h)<=g,t=Math.abs(n-i)<=g,q&&(c.position.top=e._convertPositionTo("relative",{top:o,left:0}).top-e.margins.top),r&&(c.position.top=e._convertPositionTo("relative",{top:p-e.helperProportions.height,left:0}).top-e.margins.top),s&&(c.position.left=e._convertPositionTo("relative",{top:0,left:m}).left-e.margins.left),t&&(c.position.left=e._convertPositionTo("relative",{top:0,left:n-e.helperProportions.width}).left-e.margins.left)),!e.snapElements[l].snapping&&(q||r||s||t||u)&&e.options.snap.snap&&e.options.snap.snap.call(e.element,b,a.extend(e._uiHash(),{snapItem:e.snapElements[l].item})),e.snapElements[l].snapping=q||r||s||t||u}else e.snapElements[l].snapping&&e.options.snap.release&&e.options.snap.release.call(e.element,b,a.extend(e._uiHash(),{snapItem:e.snapElements[l].item})),e.snapElements[l].snapping=!1}}}),a.ui.plugin.add("draggable","stack",{start:function(){var b=a(this).data("draggable").options;b=a.makeArray(a(b.stack)).sort(function(b,c){return(parseInt(a(b).css("zIndex"),10)||0)-(parseInt(a(c).css("zIndex"),10)||0)});if(b.length){var c=parseInt(b[0].style.zIndex)||0;a(b).each(function(a){this.style.zIndex=c+a}),this[0].style.zIndex=c+b.length}}}),a.ui.plugin.add("draggable","zIndex",{start:function(b,c){b=a(c.helper),c=a(this).data("draggable").options,b.css("zIndex")&&(c._zIndex=b.css("zIndex")),b.css("zIndex",c.zIndex)},stop:function(b,c){b=a(this).data("draggable").options,b._zIndex&&a(c.helper).css("zIndex",b._zIndex)}})}(jQuery),function(a,b){a.widget("ui.sortable",a.ui.mouse,{widgetEventPrefix:"sort",options:{appendTo:"parent",axis:!1,connectWith:!1,containment:!1,cursor:"auto",cursorAt:!1,dropOnEmpty:!0,forcePlaceholderSize:!1,forceHelperSize:!1,grid:!1,handle:!1,helper:"original",items:"> *",opacity:!1,placeholder:!1,revert:!1,scroll:!0,scrollSensitivity:20,scrollSpeed:20,scope:"default",tolerance:"intersect",zIndex:1e3},_create:function(){var a=this.options;this.document=a.document,this.containerCache={},this.element.addClass("ui-sortable"),this.refresh(),this.floating=this.items.length?a.axis==="x"||/left|right/.test(this.items[0].item.css("float"))||/inline|table-cell/.test(this.items[0].item.css("display")):!1,this.offset=this.element.offset(),this._mouseInit()},destroy:function(){this.element.removeClass("ui-sortable ui-sortable-disabled").removeData("sortable").unbind(".sortable"),this._mouseDestroy();for(var a=this.items.length-1;a>=0;a--)this.items[a].item.removeData("sortable-item");return this},_setOption:function(b,c){b==="disabled"?(this.options[b]=c,this.widget()[c?"addClass":"removeClass"]("ui-sortable-disabled")):a.Widget.prototype._setOption.apply(this,arguments)},_mouseCapture:function(b,c){if(this.reverting)return!1;if(this.options.disabled||this.options.type=="static")return!1;this._refreshItems(b);var d=null,e=this,f=a(b.target).parents().each(function(){if(a.data(this,"sortable-item")==e)return d=a(this),!1});a.data(b.target,"sortable-item")==e&&(d=a(b.target));if(!d)return!1;if(this.options.handle&&!c){var g=!1;a(this.options.handle,d).find("*").andSelf().each(function(){this==b.target&&(g=!0)});if(!g)return!1}return this.currentItem=d,this._removeCurrentsFromItems(),!0},_mouseStart:function(b,c,d){var e=this.options,f=this;this.currentContainer=this,this.refreshPositions(),this.helper=this._createHelper(b),this._cacheHelperProportions(),this._cacheMargins(),this.scrollParent=this.helper.scrollParent(),this.offset=this.currentItem.offset(),this.offset={top:this.offset.top-this.margins.top,left:this.offset.left-this.margins.left},this.helper.css("position","absolute"),this.cssPosition=this.helper.css("position"),a.extend(this.offset,{click:{left:b.pageX-this.offset.left,top:b.pageY-this.offset.top},parent:this._getParentOffset(),relative:this._getRelativeOffset()}),this.originalPosition=this._generatePosition(b),this.originalPageX=b.pageX,this.originalPageY=b.pageY,e.cursorAt&&this._adjustOffsetFromHelper(e.cursorAt),this.domPosition={prev:this.currentItem.prev()[0],parent:this.currentItem.parent()[0]},this.helper[0]!=this.currentItem[0]&&this.currentItem.hide(),this._createPlaceholder(),e.containment&&this._setContainment(),e.cursor&&(a("body").css("cursor")&&(this._storedCursor=a("body").css("cursor")),a("body").css("cursor",e.cursor)),e.opacity&&(this.helper.css("opacity")&&(this._storedOpacity=this.helper.css("opacity")),this.helper.css("opacity",e.opacity)),e.zIndex&&(this.helper.css("zIndex")&&(this._storedZIndex=this.helper.css("zIndex")),this.helper.css("zIndex",e.zIndex)),this.scrollParent[0]!=(this.document||document)&&this.scrollParent[0].tagName!="HTML"&&(this.overflowOffset=this.scrollParent.offset()),this._trigger("start",b,this._uiHash()),this._preserveHelperProportions||this._cacheHelperProportions();if(!d)for(var g=this.containers.length-1;g>=0;g--)this.containers[g]._trigger("activate",b,f._uiHash(this));return a.ui.ddmanager&&(a.ui.ddmanager.current=this),a.ui.ddmanager&&!e.dropBehaviour&&a.ui.ddmanager.prepareOffsets(this,b),this.dragging=!0,this.helper.addClass("ui-sortable-helper"),this._mouseDrag(b),!0},_mouseDrag:function(b){this.position=this._generatePosition(b),this.positionAbs=this._convertPositionTo("absolute"),this.lastPositionAbs||(this.lastPositionAbs=this.positionAbs);if(this.options.scroll){var c=this.options,d=!1;this.scrollParent[0]!=(this.document||document)&&this.scrollParent[0].tagName!="HTML"?(this.overflowOffset.top+this.scrollParent[0].offsetHeight-b.pageY<c.scrollSensitivity?this.scrollParent[0].scrollTop=d=this.scrollParent[0].scrollTop+c.scrollSpeed:b.pageY-this.overflowOffset.top<c.scrollSensitivity&&(this.scrollParent[0].scrollTop=d=this.scrollParent[0].scrollTop-c.scrollSpeed),this.overflowOffset.left+this.scrollParent[0].offsetWidth-b.pageX<c.scrollSensitivity?this.scrollParent[0].scrollLeft=d=this.scrollParent[0].scrollLeft+c.scrollSpeed:b.pageX-this.overflowOffset.left<c.scrollSensitivity&&(this.scrollParent[0].scrollLeft=d=this.scrollParent[0].scrollLeft-c.scrollSpeed)):(b.pageY-a(this.document||document).scrollTop()<c.scrollSensitivity?d=a(this.document||document).scrollTop(a(this.document||document).scrollTop()-c.scrollSpeed):a(window).height()-(b.pageY-a(this.document||document).scrollTop())<c.scrollSensitivity&&(d=a(this.document||document).scrollTop(a(this.document||document).scrollTop
()+c.scrollSpeed)),b.pageX-a(this.document||document).scrollLeft()<c.scrollSensitivity?d=a(this.document||document).scrollLeft(a(this.document||document).scrollLeft()-c.scrollSpeed):a(window).width()-(b.pageX-a(this.document||document).scrollLeft())<c.scrollSensitivity&&(d=a(this.document||document).scrollLeft(a(this.document||document).scrollLeft()+c.scrollSpeed))),d!==!1&&a.ui.ddmanager&&!c.dropBehaviour&&a.ui.ddmanager.prepareOffsets(this,b)}this.positionAbs=this._convertPositionTo("absolute");if(!this.options.axis||this.options.axis!="y")this.helper[0].style.left=this.position.left+"px";if(!this.options.axis||this.options.axis!="x")this.helper[0].style.top=this.position.top+"px";for(var e=this.items.length-1;e>=0;e--){var f=this.items[e],g=f.item[0],h=this._intersectsWithPointer(f);if(!h)continue;if(g!=this.currentItem[0]&&this.placeholder[h==1?"next":"prev"]()[0]!=g&&!a.ui.contains(this.placeholder[0],g)&&(this.options.type=="semi-dynamic"?!a.ui.contains(this.element[0],g):!0)){this.direction=h==1?"down":"up";if(this.options.tolerance!="pointer"&&!this._intersectsWithSides(f))break;this._rearrange(b,f),this._trigger("change",b,this._uiHash());break}}return this._contactContainers(b),a.ui.ddmanager&&a.ui.ddmanager.drag(this,b),this._trigger("sort",b,this._uiHash()),this.lastPositionAbs=this.positionAbs,!1},_mouseStop:function(b,c){if(!b)return;a.ui.ddmanager&&!this.options.dropBehaviour&&a.ui.ddmanager.drop(this,b);if(this.options.revert){var d=this,e=d.placeholder.offset();d.reverting=!0,a(this.helper).animate({left:e.left-this.offset.parent.left-d.margins.left+(this.offsetParent[0]==(this.document||document).body?0:this.offsetParent[0].scrollLeft),top:e.top-this.offset.parent.top-d.margins.top+(this.offsetParent[0]==(this.document||document).body?0:this.offsetParent[0].scrollTop)},parseInt(this.options.revert,10)||500,function(){d._clear(b)})}else this._clear(b,c);return!1},cancel:function(){var b=this;if(this.dragging){this._mouseUp({target:null}),this.options.helper=="original"?this.currentItem.css(this._storedCSS).removeClass("ui-sortable-helper"):this.currentItem.show();for(var c=this.containers.length-1;c>=0;c--)this.containers[c]._trigger("deactivate",null,b._uiHash(this)),this.containers[c].containerCache.over&&(this.containers[c]._trigger("out",null,b._uiHash(this)),this.containers[c].containerCache.over=0)}return this.placeholder&&(this.placeholder[0].parentNode&&this.placeholder[0].parentNode.removeChild(this.placeholder[0]),this.options.helper!="original"&&this.helper&&this.helper[0].parentNode&&this.helper.remove(),a.extend(this,{helper:null,dragging:!1,reverting:!1,_noFinalSort:null}),this.domPosition.prev?a(this.domPosition.prev).after(this.currentItem):a(this.domPosition.parent).prepend(this.currentItem)),this},serialize:function(b){var c=this._getItemsAsjQuery(b&&b.connected),d=[];return b=b||{},a(c).each(function(){var c=(a(b.item||this).attr(b.attribute||"id")||"").match(b.expression||/(.+)[-=_](.+)/);c&&d.push((b.key||c[1]+"[]")+"="+(b.key&&b.expression?c[1]:c[2]))}),!d.length&&b.key&&d.push(b.key+"="),d.join("&")},toArray:function(b){var c=this._getItemsAsjQuery(b&&b.connected),d=[];return b=b||{},c.each(function(){d.push(a(b.item||this).attr(b.attribute||"id")||"")}),d},_intersectsWith:function(a){var b=this.positionAbs.left,c=b+this.helperProportions.width,d=this.positionAbs.top,e=d+this.helperProportions.height,f=a.left,g=f+a.width,h=a.top,i=h+a.height,j=this.offset.click.top,k=this.offset.click.left,l=d+j>h&&d+j<i&&b+k>f&&b+k<g;return this.options.tolerance=="pointer"||this.options.forcePointerForContainers||this.options.tolerance!="pointer"&&this.helperProportions[this.floating?"width":"height"]>a[this.floating?"width":"height"]?l:f<b+this.helperProportions.width/2&&c-this.helperProportions.width/2<g&&h<d+this.helperProportions.height/2&&e-this.helperProportions.height/2<i},_intersectsWithPointer:function(b){var c=a.ui.isOverAxis(this.positionAbs.top+this.offset.click.top,b.top,b.height),d=a.ui.isOverAxis(this.positionAbs.left+this.offset.click.left,b.left,b.width),e=c&&d,f=this._getDragVerticalDirection(),g=this._getDragHorizontalDirection();return e?this.floating?g&&g=="right"||f=="down"?2:1:f&&(f=="down"?2:1):!1},_intersectsWithSides:function(b){var c=a.ui.isOverAxis(this.positionAbs.top+this.offset.click.top,b.top+b.height/2,b.height),d=a.ui.isOverAxis(this.positionAbs.left+this.offset.click.left,b.left+b.width/2,b.width),e=this._getDragVerticalDirection(),f=this._getDragHorizontalDirection();return this.floating&&f?f=="right"&&d||f=="left"&&!d:e&&(e=="down"&&c||e=="up"&&!c)},_getDragVerticalDirection:function(){var a=this.positionAbs.top-this.lastPositionAbs.top;return a!=0&&(a>0?"down":"up")},_getDragHorizontalDirection:function(){var a=this.positionAbs.left-this.lastPositionAbs.left;return a!=0&&(a>0?"right":"left")},refresh:function(a){return this._refreshItems(a),this.refreshPositions(),this},_connectWith:function(){var a=this.options;return a.connectWith.constructor==String?[a.connectWith]:a.connectWith},_getItemsAsjQuery:function(b){var c=this,d=[],e=[],f=this._connectWith();if(f&&b)for(var g=f.length-1;g>=0;g--){var h=a(f[g]);for(var i=h.length-1;i>=0;i--){var j=a.data(h[i],"sortable");j&&j!=this&&!j.options.disabled&&e.push([a.isFunction(j.options.items)?j.options.items.call(j.element):a(j.options.items,j.element).not(".ui-sortable-helper").not(".ui-sortable-placeholder"),j])}}e.push([a.isFunction(this.options.items)?this.options.items.call(this.element,null,{options:this.options,item:this.currentItem}):a(this.options.items,this.element).not(".ui-sortable-helper").not(".ui-sortable-placeholder"),this]);for(var g=e.length-1;g>=0;g--)e[g][0].each(function(){d.push(this)});return a(d)},_removeCurrentsFromItems:function(){var a=this.currentItem.find(":data(sortable-item)");for(var b=0;b<this.items.length;b++)for(var c=0;c<a.length;c++)a[c]==this.items[b].item[0]&&this.items.splice(b,1)},_refreshItems:function(b){this.items=[],this.containers=[this];var c=this.items,d=this,e=[[a.isFunction(this.options.items)?this.options.items.call(this.element[0],b,{item:this.currentItem}):a(this.options.items,this.element),this]],f=this._connectWith();if(f)for(var g=f.length-1;g>=0;g--){var h=a(f[g]);for(var i=h.length-1;i>=0;i--){var j=a.data(h[i],"sortable");j&&j!=this&&!j.options.disabled&&(e.push([a.isFunction(j.options.items)?j.options.items.call(j.element[0],b,{item:this.currentItem}):a(j.options.items,j.element),j]),this.containers.push(j))}}for(var g=e.length-1;g>=0;g--){var k=e[g][1],l=e[g][0];for(var i=0,m=l.length;i<m;i++){var n=a(l[i]);n.data("sortable-item",k),c.push({item:n,instance:k,width:0,height:0,left:0,top:0})}}},refreshPositions:function(b){this.offsetParent&&this.helper&&(this.offset.parent=this._getParentOffset());for(var c=this.items.length-1;c>=0;c--){var d=this.items[c];if(d.instance!=this.currentContainer&&this.currentContainer&&d.item[0]!=this.currentItem[0])continue;var e=this.options.toleranceElement?a(this.options.toleranceElement,d.item):d.item;b||(d.width=e.outerWidth(),d.height=e.outerHeight());var f=e.offset();d.left=f.left,d.top=f.top}if(this.options.custom&&this.options.custom.refreshContainers)this.options.custom.refreshContainers.call(this);else for(var c=this.containers.length-1;c>=0;c--){var f=this.containers[c].element.offset();this.containers[c].containerCache.left=f.left,this.containers[c].containerCache.top=f.top,this.containers[c].containerCache.width=this.containers[c].element.outerWidth(),this.containers[c].containerCache.height=this.containers[c].element.outerHeight()}return this},_createPlaceholder:function(b){var c=b||this,d=c.options;if(!d.placeholder||d.placeholder.constructor==String){var e=d.placeholder;d.placeholder={element:function(){var b=a((this.document||document).createElement(c.currentItem[0].nodeName)).addClass(e||c.currentItem[0].className+" ui-sortable-placeholder").removeClass("ui-sortable-helper")[0];return e||(b.style.visibility="hidden"),b},update:function(a,b){if(e&&!d.forcePlaceholderSize)return;b.height()||b.height(c.currentItem.innerHeight()-parseInt(c.currentItem.css("paddingTop")||0,10)-parseInt(c.currentItem.css("paddingBottom")||0,10)),b.width()||b.width(c.currentItem.innerWidth()-parseInt(c.currentItem.css("paddingLeft")||0,10)-parseInt(c.currentItem.css("paddingRight")||0,10))}}}c.placeholder=a(d.placeholder.element.call(c.element,c.currentItem)),c.currentItem.after(c.placeholder),d.placeholder.update(c,c.placeholder)},_contactContainers:function(b){var c=null,d=null;for(var e=this.containers.length-1;e>=0;e--){if(a.ui.contains(this.currentItem[0],this.containers[e].element[0]))continue;if(this._intersectsWith(this.containers[e].containerCache)){if(c&&a.ui.contains(this.containers[e].element[0],c.element[0]))continue;c=this.containers[e],d=e}else this.containers[e].containerCache.over&&(this.containers[e]._trigger("out",b,this._uiHash(this)),this.containers[e].containerCache.over=0)}if(!c)return;if(this.containers.length===1)this.containers[d]._trigger("over",b,this._uiHash(this)),this.containers[d].containerCache.over=1;else if(this.currentContainer!=this.containers[d]){var f=1e4,g=null,h=this.positionAbs[this.containers[d].floating?"left":"top"];for(var i=this.items.length-1;i>=0;i--){if(!a.ui.contains(this.containers[d].element[0],this.items[i].item[0]))continue;var j=this.items[i][this.containers[d].floating?"left":"top"];Math.abs(j-h)<f&&(f=Math.abs(j-h),g=this.items[i])}if(!g&&!this.options.dropOnEmpty)return;this.currentContainer=this.containers[d],g?this._rearrange(b,g,null,!0):this._rearrange(b,null,this.containers[d].element,!0),this._trigger("change",b,this._uiHash()),this.containers[d]._trigger("change",b,this._uiHash(this)),this.options.placeholder.update(this.currentContainer,this.placeholder),this.containers[d]._trigger("over",b,this._uiHash(this)),this.containers[d].containerCache.over=1}},_createHelper:function(b){var c=this.options,d=a.isFunction(c.helper)?a(c.helper.apply(this.element[0],[b,this.currentItem])):c.helper=="clone"?this.currentItem.clone():this.currentItem;return d.parents("body").length||a(c.appendTo!="parent"?c.appendTo:this.currentItem[0].parentNode)[0].appendChild(d[0]),d[0]==this.currentItem[0]&&(this._storedCSS={width:this.currentItem[0].style.width,height:this.currentItem[0].style.height,position:this.currentItem.css("position"),top:this.currentItem.css("top"),left:this.currentItem.css("left")}),(d[0].style.width==""||c.forceHelperSize)&&d.width(this.currentItem.width()),(d[0].style.height==""||c.forceHelperSize)&&d.height(this.currentItem.height()),d},_adjustOffsetFromHelper:function(b){typeof b=="string"&&(b=b.split(" ")),a.isArray(b)&&(b={left:+b[0],top:+b[1]||0}),"left"in b&&(this.offset.click.left=b.left+this.margins.left),"right"in b&&(this.offset.click.left=this.helperProportions.width-b.right+this.margins.left),"top"in b&&(this.offset.click.top=b.top+this.margins.top),"bottom"in b&&(this.offset.click.top=this.helperProportions.height-b.bottom+this.margins.top)},_getParentOffset:function(){this.offsetParent=this.helper.offsetParent();var b=this.offsetParent.offset();this.cssPosition=="absolute"&&this.scrollParent[0]!=(this.document||document)&&a.ui.contains(this.scrollParent[0],this.offsetParent[0])&&(b.left+=this.scrollParent.scrollLeft(),b.top+=this.scrollParent.scrollTop());if(this.offsetParent[0]==(this.document||document).body||this.offsetParent[0].tagName&&this.offsetParent[0].tagName.toLowerCase()=="html"&&a.browser.msie)b={top:0,left:0};return{top:b.top+(parseInt(this.offsetParent.css("borderTopWidth"),10)||0),left:b.left+(parseInt(this.offsetParent.css("borderLeftWidth"),10)||0)}},_getRelativeOffset:function(){if(this.cssPosition=="relative"){var a=this.currentItem.position();return{top:a.top-(parseInt(this.helper.css("top"),10)||0)+this.scrollParent.scrollTop(),left:a.left-(parseInt(this.helper.css("left"),10)||0)+this.scrollParent.scrollLeft()}}return{top:0,left:0}},_cacheMargins:function(){this.margins={left:parseInt(this.currentItem.css("marginLeft"),10)||0,top:parseInt(this.currentItem.css("marginTop"),10)||0}},_cacheHelperProportions:function(){this.helperProportions={width:this.helper.outerWidth(),height:this.helper.outerHeight()}},_setContainment:function(){var b=this.options;b.containment=="parent"&&(b.containment=this.helper[0].parentNode);if(b.containment=="document"||b.containment=="window")this.containment=[0-this.offset.relative.left-this.offset.parent.left,0-this.offset.relative.top-this.offset.parent.top,a(b.containment=="document"?this.document||document:window).width()-this.helperProportions.width-this.margins.left,(a(b.containment=="document"?this.document||document:window).height()||(this.document||document).body.parentNode.scrollHeight)-this.helperProportions.height-this.margins.top];if(!/^(document|window|parent)$/.test(b.containment)){var c=a(b.containment)[0],d=a(b.containment).offset(),e=a(c).css("overflow")!="hidden";this.containment=[d.left+(parseInt(a(c).css("borderLeftWidth"),10)||0)+(parseInt(a(c).css("paddingLeft"),10)||0)-this.margins.left,d.top+(parseInt(a(c).css("borderTopWidth"),10)||0)+(parseInt(a(c).css("paddingTop"),10)||0)-this.margins.top,d.left+(e?Math.max(c.scrollWidth,c.offsetWidth):c.offsetWidth)-(parseInt(a(c).css("borderLeftWidth"),10)||0)-(parseInt(a(c).css("paddingRight"),10)||0)-this.helperProportions.width-this.margins.left,d.top+(e?Math.max(c.scrollHeight,c.offsetHeight):c.offsetHeight)-(parseInt(a(c).css("borderTopWidth"),10)||0)-(parseInt(a(c).css("paddingBottom"),10)||0)-this.helperProportions.height-this.margins.top]}},_convertPositionTo:function(b,c){c||(c=this.position);var d=b=="absolute"?1:-1,e=this.options,f=this.cssPosition!="absolute"||this.scrollParent[0]!=(this.document||document)&&!!a.ui.contains(this.scrollParent[0],this.offsetParent[0])?this.scrollParent:this.offsetParent,g=/(html|body)/i.test(f[0].tagName);return{top:c.top+this.offset.relative.top*d+this.offset.parent.top*d-(a.browser.safari&&this.cssPosition=="fixed"?0:(this.cssPosition=="fixed"?-this.scrollParent.scrollTop():g?0:f.scrollTop())*d),left:c.left+this.offset.relative.left*d+this.offset.parent.left*d-(a.browser.safari&&this.cssPosition=="fixed"?0:(this.cssPosition=="fixed"?-this.scrollParent.scrollLeft():g?0:f.scrollLeft())*d)}},_generatePosition:function(b){var c=this.options,d=this.cssPosition!="absolute"||this.scrollParent[0]!=(this.document||document)&&!!a.ui.contains(this.scrollParent[0],this.offsetParent[0])?this.scrollParent:this.offsetParent,e=/(html|body)/i.test(d[0].tagName);this.cssPosition=="relative"&&(this.scrollParent[0]==(this.document||document)||this.scrollParent[0]==this.offsetParent[0])&&(this.offset.relative=this._getRelativeOffset());var f=b.pageX,g=b.pageY;if(this.originalPosition){this.containment&&(b.pageX-this.offset.click.left<this.containment[0]&&(f=this.containment[0]+this.offset.click.left),b.pageY-this.offset.click.top<this.containment[1]&&(g=this.containment[1]+this.offset.click.top),b.pageX-this.offset.click.left>this.containment[2]&&(f=this.containment[2]+this.offset.click.left),b.pageY-this.offset.click.top>this.containment[3]&&(g=this.containment[3]+this.offset.click.top));if(c.grid){var h=this.originalPageY+Math.round((g-this.originalPageY)/c.grid[1])*c.grid[1];g=this.containment?h-this.offset.click.top<this.containment[1]||h-this.offset.click.top>this.containment[3]?h-this.offset.click.top<this.containment[1]?h+c.grid[1]:h-c.grid[1]:h:h;var i=this.originalPageX+Math.round((f-this.originalPageX)/c.grid[0])*c.grid[0];f=this.containment?i-this.offset.click.left<this.containment[0]||i-this.offset.click.left>this.containment[2]?i-this.offset.click.left<this.containment[0]?i+c.grid[0]:i-c.grid[0]:i:i}}return{top:g-this.offset.click.top-this.offset.relative.top-this.offset.parent.top+(a.browser.safari&&this.cssPosition=="fixed"?0:this.cssPosition=="fixed"?-this.scrollParent.scrollTop():e?0:d.scrollTop()),left:f-this.offset.click.left-this.offset.relative.left-this.offset.parent.left+(a.browser.safari&&this.cssPosition=="fixed"?0:this.cssPosition=="fixed"?-this.scrollParent.scrollLeft():e?0:d.scrollLeft())}},_rearrange:function(a,b,c,d){c?c[0].appendChild(this.placeholder[0]):b.item[0].parentNode.insertBefore(this.placeholder[0],this.direction=="down"?b.item[0]:b.item[0].nextSibling),this.counter=this.counter?++this.counter:1;var e=this,f=this.counter;window.setTimeout(function(){f==e.counter&&e.refreshPositions(!d)},0)},_clear:function(b,c){this.reverting=!1;var d=[],e=this;!this._noFinalSort&&this.currentItem[0].parentNode&&this.placeholder.before(this.currentItem),this._noFinalSort=null;if(this.helper[0]==this.currentItem[0]){for(var f in this._storedCSS)if(this._storedCSS[f]=="auto"||this._storedCSS[f]=="static")this._storedCSS[f]="";this.currentItem.css(this._storedCSS).removeClass("ui-sortable-helper")}else this.currentItem.show();this.fromOutside&&!c&&d.push(function(a){this._trigger("receive",a,this._uiHash(this.fromOutside))}),(this.fromOutside||this.domPosition.prev!=this.currentItem.prev().not(".ui-sortable-helper")[0]||this.domPosition.parent!=this.currentItem.parent()[0])&&!c&&d.push(function(a){this._trigger("update",a,this._uiHash())});if(!a.ui.contains(this.element[0],this.currentItem[0])){c||d.push(function(a){this._trigger("remove",a,this._uiHash())});for(var f=this.containers.length-1;f>=0;f--)a.ui.contains(this.containers[f].element[0],this.currentItem[0])&&!c&&(d.push(function(a){return function(b){a._trigger("receive",b,this._uiHash(this))}}.call(this,this.containers[f])),d.push(function(a){return function(b){a._trigger("update",b,this._uiHash(this))}}.call(this,this.containers[f])))}for(var f=this.containers.length-1;f>=0;f--)c||d.push(function(a){return function(b){a._trigger("deactivate",b,this._uiHash(this))}}.call(this,this.containers[f])),this.containers[f].containerCache.over&&(d.push(function(a){return function(b){a._trigger("out",b,this._uiHash(this))}}.call(this,this.containers[f])),this.containers[f].containerCache.over=0);this._storedCursor&&a("body").css("cursor",this._storedCursor),this._storedOpacity&&this.helper.css("opacity",this._storedOpacity),this._storedZIndex&&this.helper.css("zIndex",this._storedZIndex=="auto"?"":this._storedZIndex),this.dragging=!1;if(this.cancelHelperRemoval){if(!c){this._trigger("beforeStop",b,this._uiHash());for(var f=0;f<d.length;f++)d[f].call(this,b);this._trigger("stop",b,this._uiHash())}return!1}c||this._trigger("beforeStop",b,this._uiHash()),this.placeholder[0].parentNode.removeChild(this.placeholder[0]),this.helper[0]!=this.currentItem[0]&&this.helper.remove(),this.helper=null;if(!c){for(var f=0;f<d.length;f++)d[f].call(this,b);this._trigger("stop",b,this._uiHash())}return this.fromOutside=!1,!0},_trigger:function(){a.Widget.prototype._trigger.apply(this,arguments)===!1&&this.cancel()},_uiHash:function(b){var c=b||this;return{helper:c.helper,placeholder:c.placeholder||a([]),position:c.position,originalPosition:c.originalPosition,offset:c.positionAbs,item:c.currentItem,sender:b?b.element:null}}}),a.extend(a.ui.sortable,{version:"1.8.13"})}(jQuery),function(a){a.fn.serializeObject=function(){var a={},b=this.serializeArray();return jQuery.each(b,function(){a[this.name]!==undefined?(a[this.name].push||(a[this.name]=[a[this.name]]),a[this.name].push(this.value||"")):a[this.name]=this.value||""}),a}}(jQuery),jQuery.extend(jQuery.easing,{easeInSine:function(a,b,c,d,e){return-d*Math.cos(b/e*(Math.PI/2))+d+c},easeOutSine:function(a,b,c,d,e){return d*Math.sin(b/e*(Math.PI/2))+c},easeInOutSine:function(a,b,c,d,e){return-d/2*(Math.cos(Math.PI*b/e)-1)+c}}),function(a){a.toJSON=function(b){if(typeof JSON=="object"&&JSON.stringify)return JSON.stringify(b);var c=typeof b;if(b===null)return"null";if(c=="undefined")return undefined;if(c=="number"||c=="boolean")return b+"";if(c=="string")return a.quoteString(b);if(c=="object"){if(typeof b.toJSON=="function")return a.toJSON(b.toJSON());if(b.constructor===Date){var d=b.getUTCFullYear(),e=b.getUTCMonth()+1;e<10&&(e="0"+e);var f=b.getUTCDate();f<10&&(f="0"+f);var g=b.getUTCHours();g<10&&(g="0"+g);var h=b.getUTCMinutes();h<10&&(h="0"+h);var i=b.getUTCSeconds();i<10&&(i="0"+i);var j=b.getUTCMilliseconds();return j<100&&(j="0"+j),j<10&&(j="0"+j),'"'+d+"-"+e+"-"+f+"T"+g+":"+h+":"+i+"."+j+'Z"'}if(b.constructor===Array){var k=[];for(var l=0;l<b.length;l++)k.push(a.toJSON(b[l])||"null");return"["+k.join(",")+"]"}var m=[];for(var n in b){var o;c=typeof n;if(c=="number")o='"'+n+'"';else{if(c!="string")continue;o=a.quoteString(n)}if(typeof b[n]=="function")continue;var p=a.toJSON(b[n]);m.push(o+":"+p)}return"{"+m.join(", ")+"}"}},a.quoteString=function(a){return a.match(b)?'"'+a.replace(b,function(a){var b=c[a];return typeof b=="string"?b:(b=a.charCodeAt(),"\\u00"+Math.floor(b/16).toString(16)+(b%16).toString(16))})+'"':'"'+a+'"'};var b=/["\\\x00-\x1f\x7f-\x9f]/g,c={"\b":"\\b","	":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"}}(jQuery),function(a){a.fn.localize=function(b){this.find("*").contents().each(function(){var c=!1,d="";return typeof this.data=="string"&&(d=a.trim(this.data),d&&(c=b.sub[d]||b.top[d])&&(this.data=c)),this.nodeName=="IMG"&&this.attributes.src&&(d=this.attributes.src.nodeValue,d&&(c=b.sub[d]||b.top[d])&&a(this).attr("src",c)),this.nodeName=="A"&&this.attributes.href&&(d=a.trim(this.attributes.href.nodeValue),d&&(c=b.sub[d]||b.top[d])&&a(this).attr("href",c)),this.nodeName=="INPUT"&&this.attributes.type&&this.attributes.value&&["submit","reset","button"].indexOf(this.attributes.type.nodeValue.toLowerCase())>-1&&(d=a.trim(this.attributes.value.nodeValue),d&&(c=b.sub[d]||b.top[d])&&a(this).attr("value",c)),this})}}(jQuery),function(a){function b(a,b,c,d){if(!a.tag.isInline&&c.length>0){c.push("\n");for(var e=0;e<d;e++)c.push("	")}}function c(d,e){var f=[],g=d.attributes.length==0,l=0,n=null,o=d.tag.render&&(e.allowedTags.length==0||a.inArray(d.tag.name,e.allowedTags)>-1)&&(e.removeTags.length==0||a.inArray(d.tag.name,e.removeTags)==-1);!d.isRoot&&o&&(f.push("<"),f.push(d.tag.name),a.each(d.attributes,function(){if(a.inArray(this.name,e.removeAttrs)==-1){var b=(new RegExp(/^(['"]?)(.*?)['"]?$/)).exec(this.value),c=b[2],g=b[1]||"'";this.name=="class"&&(c=a.grep(c.split(" "),function(b){return a.grep(e.allowedClasses,function(c){return c[0]==b&&(c.length==1||a.inArray(d.tag.name,c[1])>-1)}).length>0}).join(" "),g="'"),c!=null&&(c.length>0||a.inArray(this.name,d.tag.requiredAttributes)>-1)&&(f.push(" "),f.push(this.name),f.push("="),f.push(g),f.push(c),f.push(g))}}));if(d.tag.isSelfClosing)o&&f.push(" />"),g=!1;else if(d.tag.isNonClosing)g=!1;else{!d.isRoot&&o&&f.push(">"),l=e.formatIndent++;if(d.tag.toProtect)n=a.htmlClean.trim(d.children.join("")).replace(/<br>/ig,"\n"),f.push(n),g=n.length==0,e.formatIndent--;else{n=[];for(var p=0;p<d.children.length;p++){var q=d.children[p],r=a.htmlClean.trim(m(j(q)?q:q.childrenToString()));k(q)&&p>0&&r.length>0&&(h(q)||i(d.children[p-1]))&&n.push(" ");if(j(q))r.length>0&&n.push(r);else if(p!=d.children.length-1||q.tag.name!="br")e.format&&b(q,e,n,l),n=n.concat(c(q,e))}e.formatIndent--,n.length>0&&(e.format&&n[0]!="\n"&&b(d,e,f,l),f=f.concat(n),g=!1)}!d.isRoot&&o&&(e.format&&b(d,e,f,l-1),f.push("</"),f.push(d.tag.name),f.push(">"))}return!d.tag.allowEmpty&&g?[]:f}function d(b,c,e){return e=e||1,a.inArray(b[b.length-e].tag.name,c)>-1?!0:b.length-(e+1)>0&&d(b,c,e+1)?(b.pop(),!0):!1}function e(a){return a?(this.tag=a,this.isRoot=!1):(this.tag=new g("root"),this.isRoot=!0),this.attributes=[],this.children=[],this.hasAttribute=function(a){for(var b=0;b<this.attributes.length;b++)if(this.attributes[b].name==a)return!0;return!1},this.childrenToString=function(){return this.children.join("")},this}function f(a,b){return this.name=a,this.value=b,this}function g(b,c,d,e){return this.name=b.toLowerCase(),this.isSelfClosing=a.inArray(this.name,s)>-1,this.isNonClosing=a.inArray(this.name,t)>-1,this.isClosing=c!=undefined&&c.length>0,this.isInline=a.inArray(this.name,n)>-1,this.disallowNest=a.inArray(this.name,o)>-1,this.requiredParent=q[a.inArray(this.name,q)+1],this.allowEmpty=a.inArray(this.name,p)>-1,this.toProtect=a.inArray(this.name,r)>-1,this.rawAttributes=d,this.allowedAttributes=u[a.inArray(this.name,u)+1],this.requiredAttributes=v[a.inArray(this.name,v)+1],this.render=e&&a.inArray(this.name,e.notRenderedTags)==-1,this}function h(b){while(l(b)&&b.children.length>0)b=b.children[0];return j(b)&&b.length>0&&a.htmlClean.isWhitespace(b.charAt(0))}function i(b){while(l(b)&&b.children.length>0)b=b.children[b.children.length-1];return j(b)&&b.length>0&&a.htmlClean.isWhitespace(b.charAt(b.length-1))}function j(a){return a.constructor==String}function k(a){return j(a)||a.tag.isInline}function l(a){return a.constructor==e}function m(a){return a.replace(/&nbsp;|\n/g," ").replace(/\s\s+/g," ")}a.fn.htmlClean=function(b){return this.each(function(){this.value?this.value=a.htmlClean(this.value,b):this.innerHTML=a.htmlClean(this.innerHTML,b)})},a.htmlClean=function(b,h){h=a.extend({},a.htmlClean.defaults,h);var i=/<(\/)?(\w+:)?([\w]+)([^>]*)>/gi,k=/(\w+)=(".*?"|'.*?'|[^\s>]*)/gi,l,m=new e,n=[m],o=m;h.bodyOnly&&(l=/<body[^>]*>((\n|.)*)<\/body>/i.exec(b))&&(b=l[1]),b=b.concat("<xxx>");var p;while(l=i.exec(b)){var q=new g(l[3],l[1],l[4],h),r=b.substring(p,l.index);if(r.length>0){var s=o.children[o.children.length-1];o.children.length>0&&j(s=o.children[o.children.length-1])?o.children[o.children.length-1]=s.concat(r):o.children.push(r)}p=i.lastIndex;if(q.isClosing)d(n,[q.name])&&(n.pop(),o=n[n.length-1]);else{var t=new e(q),u;while(u=k.exec(q.rawAttributes)){if(u[1].toLowerCase()=="style"&&h.replaceStyles){var v=!q.isInline;for(var w=0;w<h.replaceStyles.length;w++)h.replaceStyles[w][0].test(u[2])&&(v||(q.render=!1,v=!0),o.children.push(t),n.push(t),o=t,q=new g(h.replaceStyles[w][1],"","",h),t=new e(q))}q.allowedAttributes!=null&&(q.allowedAttributes.length==0||a.inArray(u[1],q.allowedAttributes)>-1)&&t.attributes.push(new f(u[1],u[2]))}a.each(q.requiredAttributes,function(){var a=this.toString();t.hasAttribute(a)||t.attributes.push(new f(a,""))});for(var x=0;x<h.replace.length;x++)for(var y=0;y<h.replace[x][0].length;y++){var z=typeof h.replace[x][0][y]=="string";if(z&&h.replace[x][0][y]==q.name||!z&&h.replace[x][0][y].test(l)){q.render=!1,o.children.push(t),n.push(t),o=t,q=new g(h.replace[x][1],l[1],l[4],h),t=new e(q),t.attributes=o.attributes,x=h.replace.length;break}}var A=!0;o.isRoot||(o.tag.isInline&&!q.isInline?A=!1:o.tag.disallowNest&&q.disallowNest&&!q.requiredParent?A=!1:q.requiredParent&&(A=d(n,q.requiredParent))&&(o=n[n.length-1]));if(A){o.children.push(t);if(q.toProtect){var B=null;while(B=i.exec(b)){var C=new g(B[3],B[1],B[4],h);if(C.isClosing&&C.name==q.name){t.children.push(RegExp.leftContext.substring(p)),p=i.lastIndex;break}}}else!q.isSelfClosing&&!q.isNonClosing&&(n.push(t),o=t)}}}return c(m,h).join("")},a.htmlClean.defaults={bodyOnly:!0,allowedTags:[],removeTags:["basefont","center","dir","font","frame","frameset","iframe","isindex","menu","noframes","s","strike","u"],removeAttrs:[],allowedClasses:[],notRenderedTags:[],format:!1,formatIndent:0,replace:[[["b","big"],"strong"],[["i"],"em"]],replaceStyles:[[/font-weight:\s*bold/i,"strong"],[/font-style:\s*italic/i,"em"],[/vertical-align:\s*super/i,"sup"],[/vertical-align:\s*sub/i,"sub"]]},a.htmlClean.trim=function(b){return a.htmlClean.trimStart(a.htmlClean.trimEnd(b))},a.htmlClean.trimStart=function(b){return b.substring(a.htmlClean.trimStartIndex(b))},a.htmlClean.trimStartIndex=function(b){for(var c=0;c<b.length-1&&a.htmlClean.isWhitespace(b.charAt(c));c++);return c},a.htmlClean.trimEnd=function(b){return b.substring(0,a.htmlClean.trimEndIndex(b))},a.htmlClean.trimEndIndex=function(b){for(var c=b.length-1;c>=0&&a.htmlClean.isWhitespace(b.charAt(c));c--);return c+1},a.htmlClean.isWhitespace=function(b){return a.inArray(b,w)!=-1};var n=["a","abbr","acronym","address","b","big","br","button","caption","cite","code","del","em","font","hr","i","input","img","ins","label","legend","map","q","samp","select","small","span","strong","sub","sup","tt","var"],o=["h1","h2","h3","h4","h5","h6","p","th","td"],p=["th","td"],q=[null,"li",["ul","ol"],"dt",["dl"],"dd",["dl"],"td",["tr"],"th",["tr"],"tr",["table","thead","tbody","tfoot"],"thead",["table"],"tbody",["table"],"tfoot",["table"]],r=["script","style","pre","code"],s=["br","hr","img","link","meta"],t=["!doctype","?xml"],u=[["class"],"?xml",[],"!doctype",[],"a",["accesskey","class","href","name","title","rel","rev","type","tabindex"],"abbr",["class","title"],"acronym",["class","title"],"blockquote",["cite","class"],"button",["class","disabled","name","type","value"],"del",["cite","class","datetime"],"form",["accept","action","class","enctype","method","name"],"input",["accept","accesskey","alt","checked","class","disabled","ismap","maxlength","name","size","readonly","src","tabindex","type","usemap","value"],"img",["alt","class","height","src","width"],"ins",["cite","class","datetime"],"label",["accesskey","class","for"],"legend",["accesskey","class"],"link",["href","rel","type"],"meta",["content","http-equiv","name","scheme"],"map",["name"],"optgroup",["class","disabled","label"],"option",["class","disabled","label","selected","value"],"q",["class","cite"],"td",["colspan","rowspan"],"th",["colspan","rowspan"],"script",["src","type"],"select",["class","disabled","multiple","name","size","tabindex"],"style",["type"],"table",["class","summary"],"textarea",["accesskey","class","cols","disabled","name","readonly","rows","tabindex"]],v=[[],"img",["alt"]],w=[" "," ","	","\n","\r","\f"]}(jQuery);var LiquidMetal=function(){function f(a,b){var c=a.charAt(b);return"A"<=c&&c<="Z"}function g(a,b){var c=a.charAt(b-1);return c==" "||c=="	"}function h(a,b,c,d){c=Math.max(c||0,0),d=Math.min(d||a.length,a.length);for(var e=c;e<d;e++)a[e]=b;return a}var a=0,b=1,c=.8,d=.9,e=.85;return{score:function(b,d){if(d.length==0)return c;if(d.length>b.length)return a;var e=this.buildScoreArray(b,d),f=0;for(var g=0;g<e.length;g++)f+=e[g];return f/e.length},buildScoreArray:function(i,j){var k=new Array(i.length),l=i.toLowerCase(),m=j.toLowerCase().split(""),n=-1,o=!1;for(var p=0;p<m.length;p++){var q=m[p],r=l.indexOf(q,n+1);if(r<0)return h(k,a);r==0&&(o=!0),g(i,r)?(k[r-1]=1,h(k,e,n+1,r-1)):f(i,r)?h(k,e,n+1,r):h(k,a,n+1,r),k[r]=b,n=r}var s=o?d:c;return h(k,s,n+1),k}}}(),Showdown={};Showdown.converter=function(){var a,b,c,d=0;this.makeHtml=function(d){return a=new Array,b=new Array,c=new Array,d=d.replace(/~/g,"~T"),d=d.replace(/\$/g,"~D"),d=d.replace(/\r\n/g,"\n"),d=d.replace(/\r/g,"\n"),d="\n\n"+d+"\n\n",d=F(d),d=d.replace(/^[ \t]+$/mg,""),d=g(d),d=f(d),d=i(d),d=D(d),d=d.replace(/~D/g,"$$"),d=d.replace(/~T/g,"~"),d=d.replace(/https?\:\/\/[^"\s\<\>]*[^.,;'">\:\s\<\>\)\]\!]/g,function(a,b){var c=d.slice(0,b),e=d.slice(b);if(c.match(/<[^>]+$/)&&e.match(/^[^>]*>/))return a;var f=a.replace(/^http:\/\/github.com\//,"https://github.com/");return"<a href='"+f+"'>"+a+"</a>"}),d=d.replace(/[a-z0-9_\-+=.]+@[a-z0-9\-]+(\.[a-z0-9-]+)+/ig,function(a){return"<a href='mailto:"+a+"'>"+a+"</a>"}),d=d.replace(/[a-f0-9]{40}/ig,function(a,b){if(typeof GitHub=="undefined"||typeof GitHub.nameWithOwner=="undefined")return a;var c=d.slice(0,b),e=d.slice(b);return c.match(/@$/)||c.match(/<[^>]+$/)&&e.match(/^[^>]*>/)?a:"<a href='http://github.com/"+GitHub.nameWithOwner+"/commit/"+a+"'>"+a.substring(0,7)+"</a>"}),d=d.replace(/([a-z0-9_\-+=.]+)@([a-f0-9]{40})/ig,function(a,b,c,f){if(typeof GitHub=="undefined"||typeof GitHub.nameWithOwner=="undefined")return a;GitHub.repoName=GitHub.repoName||e();var g=d.slice(0,f),h=d.slice(f);return g.match(/\/$/)||g.match(/<[^>]+$/)&&h.match(/^[^>]*>/)?a:"<a href='http://github.com/"+b+"/"+GitHub.repoName+"/commit/"+c+"'>"+b+"@"+c.substring(0,7)+"</a>"}),d=d.replace(/([a-z0-9_\-+=.]+\/[a-z0-9_\-+=.]+)@([a-f0-9]{40})/ig,function(a,b,c){return"<a href='http://github.com/"+b+"/commit/"+c+"'>"+b+"@"+c.substring(0,7)+"</a>"}),d=d.replace(/#([0-9]+)/ig,function(a,b,c){if(typeof GitHub=="undefined"||typeof GitHub.nameWithOwner=="undefined")return a;var e=d.slice(0,c),f=d.slice(c);return e==""||e.match(/[a-z0-9_\-+=.]$/)||e.match(/<[^>]+$/)&&f.match(/^[^>]*>/)?a:"<a href='http://github.com/"+GitHub.nameWithOwner+"/issues/#issue/"+b+"'>"+a+"</a>"}),d=d.replace(/([a-z0-9_\-+=.]+)#([0-9]+)/ig,function(a,b,c,f){if(typeof GitHub=="undefined"||typeof GitHub.nameWithOwner=="undefined")return a;GitHub.repoName=GitHub.repoName||e();var g=d.slice(0,f),h=d.slice(f);return g.match(/\/$/)||g.match(/<[^>]+$/)&&h.match(/^[^>]*>/)?a:"<a href='http://github.com/"+b+"/"+GitHub.repoName+"/issues/#issue/"+c+"'>"+a+"</a>"}),d=d.replace(/([a-z0-9_\-+=.]+\/[a-z0-9_\-+=.]+)#([0-9]+)/ig,function(a,b,c){return"<a href='http://github.com/"+
b+"/issues/#issue/"+c+"'>"+a+"</a>"}),d};var e=function(){return GitHub.nameWithOwner.match(/^.+\/(.+)$/)[1]},f=function(c){var c=c.replace(/^[ ]{0,3}\[(.+)\]:[ \t]*\n?[ \t]*<?(\S+?)>?[ \t]*\n?[ \t]*(?:(\n*)["(](.+?)[")][ \t]*)?(?:\n+|\Z)/gm,function(c,d,e,f,g){return d=d.toLowerCase(),a[d]=z(e),f?f+g:(g&&(b[d]=g.replace(/"/g,"&quot;")),"")});return c},g=function(a){a=a.replace(/\n/g,"\n\n");var b="p|div|h[1-6]|blockquote|pre|table|dl|ol|ul|script|noscript|form|fieldset|iframe|math|ins|del",c="p|div|h[1-6]|blockquote|pre|table|dl|ol|ul|script|noscript|form|fieldset|iframe|math";return a=a.replace(/^(<(p|div|h[1-6]|blockquote|pre|table|dl|ol|ul|script|noscript|form|fieldset|iframe|math|ins|del)\b[^\r]*?\n<\/\2>[ \t]*(?=\n+))/gm,h),a=a.replace(/^(<(p|div|h[1-6]|blockquote|pre|table|dl|ol|ul|script|noscript|form|fieldset|iframe|math)\b[^\r]*?.*<\/\2>[ \t]*(?=\n+)\n)/gm,h),a=a.replace(/(\n[ ]{0,3}(<(hr)\b([^<>])*?\/?>)[ \t]*(?=\n{2,}))/g,h),a=a.replace(/(\n\n[ ]{0,3}<!(--[^\r]*?--\s*)+>[ \t]*(?=\n{2,}))/g,h),a=a.replace(/(?:\n\n)([ ]{0,3}(?:<([?%])[^\r]*?\2>)[ \t]*(?=\n{2,}))/g,h),a=a.replace(/\n\n/g,"\n"),a},h=function(a,b){var d=b;return d=d.replace(/\n\n/g,"\n"),d=d.replace(/^\n/,""),d=d.replace(/\n+$/g,""),d="\n\n~K"+(c.push(d)-1)+"K\n\n",d},i=function(a){a=p(a);var b=t("<hr />");return a=a.replace(/^[ ]{0,2}([ ]?\*[ ]?){3,}[ \t]*$/gm,b),a=a.replace(/^[ ]{0,2}([ ]?\-[ ]?){3,}[ \t]*$/gm,b),a=a.replace(/^[ ]{0,2}([ ]?\_[ ]?){3,}[ \t]*$/gm,b),a=r(a),a=s(a),a=x(a),a=g(a),a=y(a),a},j=function(a){return a=u(a),a=k(a),a=A(a),a=n(a),a=l(a),a=B(a),a=z(a),a=w(a),a=a.replace(/  +\n/g," <br />\n"),a},k=function(a){var b=/(<[a-z\/!$]("[^"]*"|'[^']*'|[^'">])*>|<!(--.*?--\s*)+>)/gi;return a=a.replace(b,function(a){var b=a.replace(/(.)<\/?code>(?=.)/g,"$1`");return b=G(b,"\\`*_"),b}),a},l=function(a){return a=a.replace(/(\[((?:\[[^\]]*\]|[^\[\]])*)\][ ]?(?:\n[ ]*)?\[(.*?)\])()()()()/g,m),a=a.replace(/(\[((?:\[[^\]]*\]|[^\[\]])*)\]\([ \t]*()<?(.*?)>?[ \t]*((['"])(.*?)\6[ \t]*)?\))/g,m),a=a.replace(/(\[([^\[\]]+)\])()()()()()/g,m),a},m=function(c,d,e,f,g,h,i,j){j==undefined&&(j="");var k=d,l=e,m=f.toLowerCase(),n=g,o=j;if(n==""){m==""&&(m=l.toLowerCase().replace(/ ?\n/g," ")),n="#"+m;if(a[m]!=undefined)n=a[m],b[m]!=undefined&&(o=b[m]);else{if(!(k.search(/\(\s*\)$/m)>-1))return k;n=""}}n=G(n,"*_");var p='<a href="'+n+'"';return o!=""&&(o=o.replace(/"/g,"&quot;"),o=G(o,"*_"),p+=' title="'+o+'"'),p+=">"+l+"</a>",p},n=function(a){return a=a.replace(/(!\[(.*?)\][ ]?(?:\n[ ]*)?\[(.*?)\])()()()()/g,o),a=a.replace(/(!\[(.*?)\]\s?\([ \t]*()<?(\S+?)>?[ \t]*((['"])(.*?)\6[ \t]*)?\))/g,o),a},o=function(c,d,e,f,g,h,i,j){var k=d,l=e,m=f.toLowerCase(),n=g,o=j;o||(o="");if(n==""){m==""&&(m=l.toLowerCase().replace(/ ?\n/g," ")),n="#"+m;if(a[m]==undefined)return k;n=a[m],b[m]!=undefined&&(o=b[m])}l=l.replace(/"/g,"&quot;"),n=G(n,"*_");var p='<img src="'+n+'" alt="'+l+'"';return o=o.replace(/"/g,"&quot;"),o=G(o,"*_"),p+=' title="'+o+'"',p+=" />",p},p=function(a){return a=a.replace(/^(.+)[ \t]*\n=+[ \t]*\n+/gm,function(a,b){return t("<h1>"+j(b)+"</h1>")}),a=a.replace(/^(.+)[ \t]*\n-+[ \t]*\n+/gm,function(a,b){return t("<h2>"+j(b)+"</h2>")}),a=a.replace(/^(\#{1,6})[ \t]*(.+?)[ \t]*\#*\n+/gm,function(a,b,c){var d=b.length;return t("<h"+d+">"+j(c)+"</h"+d+">")}),a},q,r=function(a){a+="~0";var b=/^(([ ]{0,3}([*+-]|\d+[.])[ \t]+)[^\r]+?(~0|\n{2,}(?=\S)(?![ \t]*(?:[*+-]|\d+[.])[ \t]+)))/gm;return d?a=a.replace(b,function(a,b,c){var d=b,e=c.search(/[*+-]/g)>-1?"ul":"ol";d=d.replace(/\n{2,}/g,"\n\n\n");var f=q(d);return f=f.replace(/\s+$/,""),f="<"+e+">"+f+"</"+e+">\n",f}):(b=/(\n\n|^\n?)(([ ]{0,3}([*+-]|\d+[.])[ \t]+)[^\r]+?(~0|\n{2,}(?=\S)(?![ \t]*(?:[*+-]|\d+[.])[ \t]+)))/g,a=a.replace(b,function(a,b,c,d){var e=b,f=c,g=d.search(/[*+-]/g)>-1?"ul":"ol",f=f.replace(/\n{2,}/g,"\n\n\n"),h=q(f);return h=e+"<"+g+">\n"+h+"</"+g+">\n",h})),a=a.replace(/~0/,""),a};q=function(a){return d++,a=a.replace(/\n{2,}$/,"\n"),a+="~0",a=a.replace(/(\n)?(^[ \t]*)([*+-]|\d+[.])[ \t]+([^\r]+?(\n{1,2}))(?=\n*(~0|\2([*+-]|\d+[.])[ \t]+))/gm,function(a,b,c,d,e){var f=e,g=b,h=c;return g||f.search(/\n{2,}/)>-1?f=i(E(f)):(f=r(E(f)),f=f.replace(/\n$/,""),f=j(f)),"<li>"+f+"</li>\n"}),a=a.replace(/~0/g,""),d--,a};var s=function(a){return a+="~0",a=a.replace(/(?:\n\n|^)((?:(?:[ ]{4}|\t).*\n+)+)(\n*[ ]{0,3}[^ \t\n]|(?=~0))/g,function(a,b,c){var d=b,e=c;return d=v(E(d)),d=F(d),d=d.replace(/^\n+/g,""),d=d.replace(/\n+$/g,""),d="<pre><code>"+d+"\n</code></pre>",t(d)+e}),a=a.replace(/~0/,""),a},t=function(a){return a=a.replace(/(^\n+|\n+$)/g,""),"\n\n~K"+(c.push(a)-1)+"K\n\n"},u=function(a){return a=a.replace(/(^|[^\\])(`+)([^\r]*?[^`])\2(?!`)/gm,function(a,b,c,d,e){var f=d;return f=f.replace(/^([ \t]*)/g,""),f=f.replace(/[ \t]*$/g,""),f=v(f),b+"<code>"+f+"</code>"}),a},v=function(a){return a=a.replace(/&/g,"&amp;"),a=a.replace(/</g,"&lt;"),a=a.replace(/>/g,"&gt;"),a=G(a,"*_{}[]\\",!1),a},w=function(a){return a=a.replace(/(\*\*|__)(?=\S)([^\r]*?\S[*_]*)\1/g,"<strong>$2</strong>"),a=a.replace(/(\w)_(\w)/g,"$1~E95E$2"),a=a.replace(/(\*|_)(?=\S)([^\r]*?\S)\1/g,"<em>$2</em>"),a},x=function(a){return a=a.replace(/((^[ \t]*>[ \t]?.+\n(.+\n)*\n*)+)/gm,function(a,b){var c=b;return c=c.replace(/^[ \t]*>[ \t]?/gm,"~0"),c=c.replace(/~0/g,""),c=c.replace(/^[ \t]+$/gm,""),c=i(c),c=c.replace(/(^|\n)/g,"$1  "),c=c.replace(/(\s*<pre>[^\r]+?<\/pre>)/gm,function(a,b){var c=b;return c=c.replace(/^  /mg,"~0"),c=c.replace(/~0/g,""),c}),t("<blockquote>\n"+c+"\n</blockquote>")}),a},y=function(a){a=a.replace(/^\n+/g,""),a=a.replace(/\n+$/g,"");var b=a.split(/\n{2,}/g),d=new Array,e=b.length;for(var f=0;f<e;f++){var g=b[f];g.search(/~K(\d+)K/g)>=0?d.push(g):g.search(/\S/)>=0&&(g=j(g),g=g.replace(/\n/g,"<br />"),g=g.replace(/^([ \t]*)/g,"<p>"),g+="</p>",d.push(g))}e=d.length;for(var f=0;f<e;f++)while(d[f].search(/~K(\d+)K/)>=0){var h=c[RegExp.$1];h=h.replace(/\$/g,"$$$$"),d[f]=d[f].replace(/~K\d+K/,h)}return d.join("\n\n")},z=function(a){return a=a.replace(/&(?!#?[xX]?(?:[0-9a-fA-F]+|\w+);)/g,"&amp;"),a=a.replace(/<(?![a-z\/?\$!])/gi,"&lt;"),a},A=function(a){return a=a.replace(/\\(\\)/g,H),a=a.replace(/\\([`*_{}\[\]()>#+-.!])/g,H),a},B=function(a){return a=a.replace(/<((https?|ftp|dict):[^'">\s]+)>/gi,'<a href="$1">$1</a>'),a=a.replace(/<(?:mailto:)?([-.\w]+\@[-a-z0-9]+(\.[-a-z0-9]+)*\.[a-z]+)>/gi,function(a,b){return C(D(b))}),a},C=function(a){function b(a){var b="0123456789ABCDEF",c=a.charCodeAt(0);return b.charAt(c>>4)+b.charAt(c&15)}var c=[function(a){return"&#"+a.charCodeAt(0)+";"},function(a){return"&#x"+b(a)+";"},function(a){return a}];return a="mailto:"+a,a=a.replace(/./g,function(a){if(a=="@")a=c[Math.floor(Math.random()*2)](a);else if(a!=":"){var b=Math.random();a=b>.9?c[2](a):b>.45?c[1](a):c[0](a)}return a}),a='<a href="'+a+'">'+a+"</a>",a=a.replace(/">.+:/g,'">'),a},D=function(a){return a=a.replace(/~E(\d+)E/g,function(a,b){var c=parseInt(b);return String.fromCharCode(c)}),a},E=function(a){return a=a.replace(/^(\t|[ ]{1,4})/gm,"~0"),a=a.replace(/~0/g,""),a},F=function(a){return a=a.replace(/\t(?=\t)/g,"    "),a=a.replace(/\t/g,"~A~B"),a=a.replace(/~B(.+?)~A/g,function(a,b,c){var d=b,e=4-d.length%4;for(var f=0;f<e;f++)d+=" ";return d}),a=a.replace(/~A/g,"    "),a=a.replace(/~B/g,""),a},G=function(a,b,c){var d="(["+b.replace(/([\[\]\\])/g,"\\$1")+"])";c&&(d="\\\\"+d);var e=new RegExp(d,"g");return a=a.replace(e,H),a},H=function(a,b){var c=b.charCodeAt(0);return"~E"+c+"E"}},function(){var a=Array.prototype.slice;this.Mercury||(this.Mercury={}),jQuery.extend(this.Mercury,{version:"0.6.0",Regions:Mercury.Regions||{},modalHandlers:Mercury.modalHandlers||{},lightviewHandlers:Mercury.lightviewHandlers||{},dialogHandlers:Mercury.dialogHandlers||{},preloadedViews:Mercury.preloadedViews||{},ajaxHeaders:function(){var a;return a={},a[Mercury.config.csrfHeader]=Mercury.csrfToken,a},on:function(a,b){return jQuery(window).on("mercury:"+a,b)},off:function(a,b){return jQuery(window).off("mercury:"+a,b)},one:function(a,b){return jQuery(window).one("mercury:"+a,b)},trigger:function(a,b){return Mercury.log(a,b),jQuery(window).trigger("mercury:"+a,b)},notify:function(){var b;return b=1<=arguments.length?a.call(arguments,0):[],window.alert(Mercury.I18n.apply(this,b))},warn:function(a,b){b==null&&(b=0);if(console)try{return console.warn(a)}catch(c){if(b>=1)try{return console.debug(a)}catch(d){}}else if(b>=1)return Mercury.notify(a)},deprecated:function(a){return console&&console.trace&&(a=""+a+" -- "+console.trace()),Mercury.warn("deprecated: "+a,1)},log:function(){if(Mercury.debug&&console){if(arguments[0]==="hide:toolbar"||arguments[0]==="show:toolbar")return;try{return console.debug(arguments)}catch(a){}}},locale:function(){var a,b,c;return Mercury.determinedLocale?Mercury.determinedLocale:(Mercury.config.localization.enabled&&(a=[],navigator.language&&(a=navigator.language.toString().split("-")).length&&(c=Mercury.I18n[a[0]]||{},b=a.length>1?c["_"+a[1].toUpperCase()+"_"]:void 0),Mercury.I18n[a[0]]||(a=Mercury.config.localization.preferredLocale.split("-"),c=Mercury.I18n[a[0]]||{},b=a.length>1?c["_"+a[1].toUpperCase()+"_"]:void 0)),Mercury.determinedLocale={top:c||{},sub:b||{}})},I18n:function(){var b,c,d,e;return d=arguments[0],b=2<=arguments.length?a.call(arguments,1):[],c=Mercury.locale(),e=(c.sub[d]||c.top[d]||d||"").toString(),b.length?e.printf.apply(e,b):e}})}.call(this),function(){String.prototype.titleize=function(){return this[0].toUpperCase()+this.slice(1)},String.prototype.toHex=function(){return this[0]==="#"?this:this.replace(/rgb(a)?\(([0-9|%]+)[\s|,]?\s?([0-9|%]+)[\s|,]?\s?([0-9|%]+)[\s|,]?\s?([0-9|.|%]+\s?)?\)/gi,function(a,b,c,d,e,f){return"#"+parseInt(c).toHex()+parseInt(d).toHex()+parseInt(e).toHex()})},String.prototype.regExpEscape=function(){var a,b;return b=["/",".","*","+","?","|","(",")","[","]","{","}","\\"],a=new RegExp("(\\"+b.join("|\\")+")","g"),this.replace(a,"\\$1")},String.prototype.printf=function(){var a,b,c,d,e,f,g,h,i;c=this.split("%"),h=c[0],g=/^([sdf])([\s\S%]*)$/,e=0;for(d=0,i=c.length;d<i;d++){b=c[d],f=g.exec(b);if(d===0||!f||arguments[d]===null){d>1&&(e+=2,h+="%"+b);continue}a=arguments[d-1-e];switch(f[1]){case"s":h+=a;break;case"d":case"i":h+=parseInt(a.toString(),10);break;case"f":h+=parseFloat(a)}h+=f[2]}return h},Number.prototype.toHex=function(){var a;return a=this.toString(16).toUpperCase(),a[1]?a:"0"+a},Number.prototype.toBytes=function(){var a,b;a=parseInt(this),b=0;while(1023<a)a/=1024,b+=1;return b?""+a.toFixed(2)+[""," kb"," Mb"," Gb"," Tb"," Pb"," Eb"][b]:""+a+" bytes"}}.call(this),function(){this.Mercury.PageEditor=function(){function a(a,b){var c;this.saveUrl=a!=null?a:null,this.options=b!=null?b:{};if(window.mercuryInstance)throw Mercury.I18n("Mercury.PageEditor can only be instantiated once.");this.options.visible!==!1&&this.options.visible!=="false"&&(this.options.visible=!0),this.visible=this.options.visible,this.options.saveDataType!==!1&&!this.options.saveDataType&&(this.options.saveDataType="json"),window.mercuryInstance=this,this.regions=[],this.initializeInterface();if(c=jQuery(Mercury.config.csrfSelector).attr("content"))Mercury.csrfToken=c}return a.prototype.initializeInterface=function(){var a,b,c=this;return this.focusableElement=jQuery("<input>",{"class":"mercury-focusable",type:"text"}).appendTo((a=this.options.appendTo)!=null?a:"body"),this.iframe=jQuery("<iframe>",{id:"mercury_iframe","class":"mercury-iframe",seamless:"true",frameborder:"0",src:"about:blank"}),this.iframe.appendTo((b=jQuery(this.options.appendTo).get(0))!=null?b:"body"),this.toolbar=new Mercury.Toolbar(this.options),this.statusbar=new Mercury.Statusbar(this.options),this.resize(),this.iframe.on("load",function(){return c.initializeFrame()}),this.iframe.one("load",function(){return c.bindEvents()}),this.loadIframeSrc(null)},a.prototype.initializeFrame=function(){var a;try{if(this.iframe.data("loaded"))return;return this.iframe.data("loaded",!0),jQuery.browser.opera&&Mercury.notify("Opera isn't a fully supported browser, your results may not be optimal."),this.document=jQuery(this.iframe.get(0).contentWindow.document),jQuery('<style mercury-styles="true">').html(Mercury.config.injectedStyles).appendTo(this.document.find("head")),a=this.iframe.get(0).contentWindow,jQuery.globalEval=function(b){if(b&&/\S/.test(b))return(a.execScript||function(b){return a.eval.call(a,b)})(b)},a.Mercury=Mercury,window.History&&History.Adapter&&(a.History=History),this.bindDocumentEvents(),this.resize(),this.initializeRegions(),this.finalizeInterface(),Mercury.trigger("ready"),a.jQuery&&a.jQuery(a).trigger("mercury:ready"),a.Event&&a.Event.fire&&a.Event.fire(a,"mercury:ready"),a.onMercuryReady&&a.onMercuryReady(),this.iframe.css({visibility:"visible"})}catch(b){return Mercury.notify("Mercury.PageEditor failed to load: %s\n\nPlease try refreshing.",b)}},a.prototype.initializeRegions=function(){var a,b,c,d,e,f,g,h;this.regions=[],f=jQuery("["+Mercury.config.regions.attribute+"]",this.document);for(b=0,d=f.length;b<d;b++)a=f[b],this.buildRegion(jQuery(a));if(!this.visible)return;g=this.regions,h=[];for(c=0,e=g.length;c<e;c++){a=g[c];if(a.focus){a.focus();break}h.push(void 0)}return h},a.prototype.buildRegion=function(a){var b,c;if(a.data("region"))a=a.data("region");else{b=(a.attr(Mercury.config.regions.attribute)||(typeof (c=Mercury.config.regions).determineType=="function"?c.determineType(a):void 0)||"unknown").titleize();if(b==="Unknown"||!Mercury.Regions[b])throw Mercury.I18n('Region type is malformed, no data-type provided, or "%s" is unknown for the "%s" region.',b,a.attr("id")||"unknown");if(!Mercury.Regions[b].supported)return Mercury.notify("Mercury.Regions.%s is unsupported in this client. Supported browsers are %s.",b,Mercury.Regions[b].supportedText),!1;a=new Mercury.Regions[b](a,this.iframe.get(0).contentWindow),this.previewing&&a.togglePreview()}return this.regions.push(a)},a.prototype.finalizeInterface=function(){var a;this.santizerElement=jQuery("<div>",{id:"mercury_sanitizer",contenteditable:"true",style:"position:fixed;width:100px;height:100px;top:0;left:-100px;opacity:0;overflow:hidden"}),this.santizerElement.appendTo((a=this.options.appendTo)!=null?a:this.document.find("body")),this.snippetToolbar&&this.snippetToolbar.release(),this.snippetToolbar=new Mercury.SnippetToolbar(this.document),this.hijackLinksAndForms();if(!this.visible)return Mercury.trigger("mode",{mode:"preview"})},a.prototype.bindDocumentEvents=function(){var a=this;return this.document.on("mousedown",function(a){Mercury.trigger("hide:dialogs");if(Mercury.region&&jQuery(a.target).closest("["+Mercury.config.regions.attribute+"]").get(0)!==Mercury.region.element.get(0))return Mercury.trigger("unfocus:regions")}),jQuery(this.document).bind("keydown",function(a){if(!a.ctrlKey&&!a.metaKey)return;if(a.keyCode===83)return Mercury.trigger("action",{action:"save"}),a.preventDefault()})},a.prototype.bindEvents=function(){var a=this;return Mercury.on("initialize:frame",function(){return setTimeout(a.initializeFrame,100)}),Mercury.on("focus:frame",function(){return a.iframe.focus()}),Mercury.on("focus:window",function(){return setTimeout(function(){return a.focusableElement.focus()},10)}),Mercury.on("toggle:interface",function(){return a.toggleInterface()}),Mercury.on("reinitialize",function(){return a.initializeRegions()}),Mercury.on("mode",function(b,c){if(c.mode==="preview")return a.previewing=!a.previewing}),Mercury.on("action",function(b,c){var d;d=Mercury.config.globalBehaviors[c.action]||a[c.action];if(typeof d!="function")return;return c.already_handled=!0,d.call(a,c)}),jQuery(window).on("resize",function(){return a.resize()}),jQuery(window).bind("keydown",function(a){if(!a.ctrlKey&&!a.metaKey)return;if(a.keyCode===83)return Mercury.trigger("action",{action:"save"}),a.preventDefault()}),window.onbeforeunload=this.beforeUnload},a.prototype.toggleInterface=function(){return this.visible?(this.visible=!1,this.toolbar.hide(),this.statusbar.hide(),this.previewing||Mercury.trigger("mode",{mode:"preview"}),this.previewing=!0):(this.visible=!0,this.toolbar.show(),this.statusbar.show(),Mercury.trigger("mode",{mode:"preview"}),this.previewing=!1),this.resize()},a.prototype.resize=function(){var a,b,c;return c=jQuery(window).width(),a=this.statusbar.top(),b=this.toolbar.height(),Mercury.displayRect={top:b,left:0,width:c,height:a-b,fullHeight:a},this.iframe.css({top:b,left:0,height:a-b}),Mercury.trigger("resize")},a.prototype.iframeSrc=function(a,b){var c,d;return a==null&&(a=null),b==null&&(b=!1),a=(a!=null?a:window.location.href).replace((d=(c=Mercury.config).editorUrlRegEx)!=null?d:c.editorUrlRegEx=/([http|https]:\/\/.[^\/]*)\/editor\/?(.*)/i,"$1/$2"),a=a.replace(/[\?|\&]mercury_frame=true/gi,""),a=a.replace(/\&_=i\d+/gi,""),b?""+a+(a.indexOf("?")>-1?"&":"?")+"mercury_frame=true&_="+(new Date).getTime():a},a.prototype.loadIframeSrc=function(a){return this.document&&this.document.off(),this.iframe.data("loaded",!1),this.iframe.get(0).contentWindow.document.location.href=this.iframeSrc(a,!0)},a.prototype.hijackLinksAndForms=function(){var a,b,c,d,e,f,g,h,i,j;h=jQuery("a, form",this.document),j=[];for(d=0,f=h.length;d<f;d++){b=h[d],c=!1,i=Mercury.config.nonHijackableClasses||[];for(e=0,g=i.length;e<g;e++){a=i[e];if(jQuery(b).hasClass(a)){c=!0;continue}}!c&&(b.target===""||b.target==="_self")&&!jQuery(b).closest("["+Mercury.config.regions.attribute+"]").length?j.push(jQuery(b).attr("target","_parent")):j.push(void 0)}return j},a.prototype.beforeUnload=function(){return Mercury.changes&&!Mercury.silent?Mercury.I18n("You have unsaved changes.  Are you sure you want to leave without saving them first?"):null},a.prototype.getRegionByName=function(a){var b,c,d,e;e=this.regions;for(c=0,d=e.length;c<d;c++){b=e[c];if(b.name===a)return b}return null},a.prototype.save=function(a){var b,c,d,e,f,g=this;return d=(e=(f=this.saveUrl)!=null?f:Mercury.saveUrl)!=null?e:this.iframeSrc(),b=this.serialize(),Mercury.log("saving",b),this.options.saveStyle!=="form"&&(b=jQuery.toJSON(b)),this.options.saveMethod==="PUT"&&(c="PUT"),jQuery.ajax(d,{headers:Mercury.ajaxHeaders(),type:c||"POST",dataType:this.options.saveDataType,data:{content:b,_method:c},success:function(){Mercury.changes=!1,Mercury.trigger("saved");if(typeof a=="function")return a()},error:function(a){return Mercury.trigger("save_failed",a),Mercury.notify("Mercury was unable to save to the url: %s",d)}})},a.prototype.serialize=function(){var a,b,c,d,e;b={},e=this.regions;for(c=0,d=e.length;c<d;c++)a=e[c],b[a.name]=a.serialize();return b},a}()}.call(this),function(){this.Mercury.HistoryBuffer=function(){function a(a){this.maxLength=a!=null?a:200,this.index=0,this.stack=[],this.markerRegExp=/<em class="mercury-marker"><\/em>/g}return a.prototype.push=function(a){if(jQuery.type(a)==="string"){if(this.stack[this.index]&&this.stack[this.index].replace(this.markerRegExp,"")===a.replace(this.markerRegExp,""))return}else if(jQuery.type(a)==="object"&&a.html&&this.stack[this.index]&&this.stack[this.index].html===a.html)return;return this.stack=this.stack.slice(0,this.index+1),this.stack.push(a),this.stack.length>this.maxLength&&this.stack.shift(),this.index=this.stack.length-1},a.prototype.undo=function(){return this.index<1?null:(this.index-=1,this.stack[this.index])},a.prototype.redo=function(){return this.index>=this.stack.length-1?null:(this.index+=1,this.stack[this.index])},a}()}.call(this),function(){this.Mercury.tableEditor=function(a,b,c){return Mercury.tableEditor.load(a,b,c),Mercury.tableEditor},jQuery.extend(Mercury.tableEditor,{load:function(a,b,c){return this.table=a,this.cell=b,this.cellContent=c!=null?c:"",this.row=this.cell.parent("tr"),this.columnCount=this.getColumnCount(),this.rowCount=this.getRowCount()},addColumn:function(a){var b,c,d,e,f,g,h,i,j,k,l;a==null&&(a="after"),i=this.cellSignatureFor(this.cell),k=this.table.find("tr"),l=[];for(b=0,j=k.length;b<j;b++)g=k[b],h=1,d=a==="after"?{right:i.right}:{left:i.left},(e=this.findCellByOptionsFor(g,d))?(f=jQuery("<"+e.cell.get(0).tagName+">").html(this.cellContent),this.setRowspanFor(f,e.height),a==="before"?e.cell.before(f):e.cell.after(f),l.push(b+=e.height-1)):(c=this.findCellByIntersectionFor(g,i))?l.push(this.setColspanFor(c.cell,c.width+1)):l.push(void 0);return l},removeColumn:function(){var a,b,c,d,e,f,g,h,i,j,k,l,m,n,o;h=this.cellSignatureFor(this.cell);if(h.width>1)return;f=[],a=[],n=this.table.find("tr");for(c=0,k=n.length;c<k;c++)g=n[c],(e=this.findCellByOptionsFor(g,{left:h.left,width:h.width}))?(f.push(e.cell),c+=e.height-1):(d=this.findCellByIntersectionFor(g,h))&&a.push(d.cell);for(i=0,l=f.length;i<l;i++)b=f[i],jQuery(b).remove();o=[];for(j=0,m=a.length;j<m;j++)b=a[j],o.push(this.setColspanFor(b,this.colspanFor(b)-1));return o},addRow:function(a){var b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r;a==null&&(a="after"),f=jQuery("<tr>"),(i=this.rowspanFor(this.cell))>1&&a==="after"&&(this.row=jQuery(this.row.nextAll("tr")[i-2])),c=0,p=this.row.find("th, td");for(j=0,m=p.length;j<m;j++){b=p[j],d=this.colspanFor(b),e=jQuery("<"+b.tagName+">").html(this.cellContent),this.setColspanFor(e,d),c+=d;if((i=this.rowspanFor(b))>1&&a==="after"){this.setRowspanFor(b,i+1);continue}f.append(e)}if(c<this.columnCount){h=0,q=this.row.prevAll("tr");for(k=0,n=q.length;k<n;k++){g=q[k],h+=1,r=jQuery(g).find("td[rowspan], th[rowspan]");for(l=0,o=r.length;l<o;l++)b=r[l],i=this.rowspanFor(b),i-1>=h&&a==="before"?this.setRowspanFor(b,i+1):i-1>=h&&a==="after"&&(i-1===h?(e=jQuery("<"+b.tagName+">").html(this.cellContent),this.setColspanFor(e,this.colspanFor(b)),f.append(e)):this.setRowspanFor(b,i+1))}}return a==="before"?this.row.before(f):this.row.after(f)},removeRow:function(){var a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w;i=!0,f=0,e=0,s=this.row.find("td, th");for(k=0,o=s.length;k<o;k++){b=s[k],h=this.rowspanFor(b),f&&h!==f&&(i=!1);if(h<e||!e)e=h;f=h}if(!i&&this.rowspanFor(this.cell)>e)return;if(e>1)for(c=0,t=e-2;0<=t?c<=t:c>=t;0<=t?c++:c--)jQuery(this.row.nextAll("tr")[c]).remove();u=this.row.find("td[rowspan], th[rowspan]");for(l=0,p=u.length;l<p;l++){b=u[l],j=this.cellSignatureFor(b);if(j.height===e)continue;if(d=this.findCellByOptionsFor(this.row.nextAll("tr")[e-1],{left:j.left,forceAdjacent:!0}))this.setRowspanFor(b,this.rowspanFor(b)-this.rowspanFor(this.cell)),d.direction==="before"?d.cell.before(jQuery(b).clone()):d.cell.after(jQuery(b).clone())}if(this.columnsFor(this.row.find("td, th"))<this.columnCount){g=0,v=this.row.prevAll("tr");for(m=0,q=v.length;m<q;m++){a=v[m],g+=1,w=jQuery(a).find("td[rowspan], th[rowspan]");for(n=0,r=w.length;n<r;n++)b=w[n],h=this.rowspanFor(b),h>g&&this.setRowspanFor(b,h-this.rowspanFor(this.cell))}}return this.row.remove()},increaseColspan:function(){var a;a=this.cell.next("td, th");if(!a.length)return;if(this.rowspanFor(a)!==this.rowspanFor(this.cell))return;if(this.cellIndexFor(a)>this.cellIndexFor(this.cell)+this.colspanFor(this.cell))return;return this.setColspanFor(this.cell,this.colspanFor(this.cell)+this.colspanFor(a)),a.remove()},decreaseColspan:function(){var a;if(this.colspanFor(this.cell)===1)return;return this.setColspanFor(this.cell,this.colspanFor(this.cell)-1),a=jQuery("<"+this.cell.get(0).tagName+">").html(this.cellContent),this.setRowspanFor(a,this.rowspanFor(this.cell)),this.cell.after(a)},increaseRowspan:function(){var a,b,c;c=this.cellSignatureFor(this.cell),b=this.row.nextAll("tr")[c.height-1];if(b&&(a=this.findCellByOptionsFor(b,{left:c.left,width:c.width})))return this.setRowspanFor(this.cell,c.height+a.height),a.cell.remove()},decreaseRowspan:function(){var a,b,c,d;d=this.cellSignatureFor(this.cell);if(d.height===1)return;c=this.row.nextAll("tr")[d.height-2];if(a=this.findCellByOptionsFor(c,{left:d.left,forceAdjacent:!0}))return b=jQuery("<"+this.cell.get(0).tagName+">").html(this.cellContent),this.setColspanFor(b,this.colspanFor(this.cell)),this.setRowspanFor(this.cell,d.height-1),a.direction==="before"?a.cell.before(b):a.cell.after(b)},getColumnCount:function(){return this.columnsFor(this.table.find("thead tr:first-child, tbody tr:first-child, tfoot tr:first-child").first().find("td, th"))},getRowCount:function(){return this.table.find("tr").length},cellIndexFor:function(a){var b,c,d,e,f,g,h,i,j,k,l,m;a=jQuery(a),f=a.parent("tr"),d=this.columnsFor(f.find("td, th")),e=this.columnsFor(a.prevAll("td, th"));if(d<this.columnCount){g=0,l=f.prevAll("tr");for(h=0,j=l.length;h<j;h++){c=l[h],g+=1,m=jQuery(c).find("td[rowspan], th[rowspan]");for(i=0,k=m.length;i<k;i++)b=m[i],this.rowspanFor(b)>g&&this.cellIndexFor(b)<=e&&(e+=this.colspanFor(b))}}return e},cellSignatureFor:function(a){var b;return b={cell:jQuery(a)},b.left=this.cellIndexFor(a),b.width=this.colspanFor(a),b.height=this.rowspanFor(a),b.right=b.left+b.width,b},findCellByOptionsFor:function(a,b){var c,d,e,f,g,h;h=jQuery(a).find("td, th");for(f=0,g=h.length;f<g;f++){c=h[f],e=this.cellSignatureFor(c);if(typeof b.right!="undefined"&&e.right===b.right)return e;if(typeof b.left!="undefined")if(b.width){if(e.left===b.left&&e.width===b.width)return e}else if(!b.forceAdjacent){if(e.left===b.left)return e}else if(b.forceAdjacent&&e.left>b.left)return d=jQuery(c).prev("td, th"),d.length?(e=this.cellSignatureFor(d),e.direction="after"):e.direction="before",e}return b.forceAdjacent?(e.direction="after",e):null},findCellByIntersectionFor:function(a,b){var c,d,e,f,g;g=jQuery(a).find("td, th");for(e=0,f=g.length;e<f;e++){c=g[e],d=this.cellSignatureFor(c);if(d.right-b.left>=0&&d.right>b.left)return d}return null},columnsFor:function(a){var b,c,d,e;c=0;for(d=0,e=a.length;d<e;d++)b=a[d],c+=this.colspanFor(b);return c},colspanFor:function(a){return parseInt(jQuery(a).attr("colspan"))||1},rowspanFor:function(a){return parseInt(jQuery(a).attr("rowspan"))||1},setColspanFor:function(a,b){return jQuery(a).attr("colspan",b>1?b:null)},setRowspanFor:function(a,b){return jQuery(a).attr("rowspan",b>1?b:null)}})}.call(this),function(){this.Mercury.Dialog=function(){function a(a,b,c){this.url=a,this.name=b,this.options=c!=null?c:{},this.button=this.options["for"],this.build(),this.bindEvents(),this.preload()}return a.prototype.build=function(){var a;return this.element=jQuery("<div>",{"class":"mercury-dialog mercury-"+this.name+"-dialog loading",style:"display:none"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},a.prototype.bindEvents=function(){return this.element.on("mousedown",function(a){return a.stopPropagation()})},a.prototype.preload=function(){if(this.options.preload)return this.load()},a.prototype.toggle=function(){return this.visible?this.hide():this.show()},a.prototype.resize=function(){return this.show()},a.prototype.show=function(){return Mercury.trigger("hide:dialogs",this),this.visible=!0,this.loaded?(this.element.css({width:"auto",height:"auto"}),this.position(this.visible)):this.position(),this.appear()},a.prototype.position=function(a){},a.prototype.appear=function(){var a=this;return this.element.css({display:"block",opacity:0}),this.element.animate({opacity:.95},200,"easeInOutSine",function(){if(!a.loaded)return a.load(function(){return a.resize()})})},a.prototype.hide=function(){return this.element.hide(),this.visible=!1},a.prototype.load=function(a){var b=this;if(!this.url)return;if(!Mercury.preloadedViews[this.url])return jQuery.ajax(this.url,{success:function(c){b.loadContent(c),Mercury.dialogHandlers[b.name]&&Mercury.dialogHandlers[b.name].call(b);if(a)return a()},error:function(){return b.hide(),b.button&&b.button.removeClass("pressed"),Mercury.notify('Mercury was unable to load %s for the "%s" dialog.',b.url,b.name)}});this.loadContent(Mercury.preloadedViews[this.url]),Mercury.dialogHandlers[this.name]&&Mercury.dialogHandlers[this.name].call(this);if(a)return a()},a.prototype.loadContent=function(a){this.loaded=!0,this.element.removeClass("loading"),this.element.html(a);if(Mercury.config.localization.enabled)return this.element.localize(Mercury.locale())},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b};this.Mercury.Palette=function(a){function c(a,b,d){this.url=a,this.name=b,this.options=d!=null?d:{},c.__super__.constructor.apply(this,arguments)}return b(c,a),c.prototype.build=function(){var a;return this.element=jQuery("<div>",{"class":"mercury-palette mercury-"+this.name+"-palette loading",style:"display:none"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},c.prototype.bindEvents=function(){var a=this;return Mercury.on("hide:dialogs",function(b,c){if(c!==a)return a.hide()}),c.__super__.bindEvents.apply(this,arguments)},c.prototype.position=function(a){var b,c;return this.element.css({top:0,left:0,display:"block",visibility:"hidden"}),b=this.button.offset(),c=this.element.width(),b.left+c>jQuery(window).width()&&(b.left=b.left-c+this.button.width()),this.element.css({top:b.top+this.button.height(),left:b.left,display:a?"block":"none",visibility:"visible"})},c}(Mercury.Dialog)}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b};this.Mercury.Select=function(a){function c(a,b,d){this.url=a,this.name=b,this.options=d!=null?d:{},c.__super__.constructor.apply(this,arguments)}return b(c,a),c.prototype.build=function(){var a;return this.element=jQuery("<div>",{"class":"mercury-select mercury-"+this.name+"-select loading",style:"display:none"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},c.prototype.bindEvents=function(){var a=this;return Mercury.on("hide:dialogs",function(b,c){if(c!==a)return a.hide()}),this.element.on("mousedown",function(a){return a.preventDefault()}),c.__super__.bindEvents.apply(this,arguments)},c.prototype.position=function(a){var b,c,d,e,f,g,h;return this.element.css({top:0,left:0,display:"block",visibility:"hidden"}),g=this.button.offset(),d=this.element.width(),c=this.element.height(),b=jQuery(document).height(),h=g.top+this.button.height()/2-c/2,h<g.top-100&&(h=g.top-100),h<20&&(h=20),e=this.loaded?"auto":c,h+c>=b-20&&(e=b-h-20),f=g.left,f+d>jQuery(window).width()&&(f=f-d+this.button.width()),this.element.css({top:h,left:f,height:e,display:a?"block":"none",visibility:"visible"})},c}(Mercury.Dialog)}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b};this.Mercury.Panel=function(a){function c(a,b,d){this.url=a,this.name=b,this.options=d!=null?d:{},c.__super__.constructor.apply(this,arguments)}return b(c,a),c.prototype.build=function(){var a;return this.element=jQuery("<div>",{"class":"mercury-panel loading",style:"display:none;"}),this.titleElement=jQuery("<h1><span>"+Mercury.I18n(this.options.title)+"</span></h1>").appendTo(this.element),this.paneElement=jQuery("<div>",{"class":"mercury-panel-pane"}).appendTo(this.element),this.options.closeButton&&jQuery("<a/>",{"class":"mercury-panel-close"}).appendTo(this.titleElement).css({opacity:0}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},c.prototype.bindEvents=function(){var a=this;return Mercury.on("resize",function(){return a.position(a.visible)}),Mercury.on("hide:panels",function(b,c){if(c===a)return;return a.button.removeClass("pressed"),a.hide()}),this.titleElement.find(".mercury-panel-close").on("click",function(a){return a.preventDefault(),Mercury.trigger("hide:panels")}),this.element.on("mousedown",function(a){return a.stopPropagation()}),this.element.on("ajax:beforeSend",function(b,c,d){return d.success=function(b){return a.loadContent(b),a.resize()}}),c.__super__.bindEvents.apply(this,arguments)},c.prototype.show=function(){return Mercury.trigger("hide:panels",this),c.__super__.show.apply(this,arguments)},c.prototype.resize=function(){var a,b,c,d=this;this.titleElement.find(".mercury-panel-close").css({opacity:0}),this.paneElement.css({display:"none"}),c=this.element.width(),this.paneElement.css({visibility:"hidden",width:"auto",display:"block"}),b=this.element.width(),this.paneElement.css({visibility:"visible",display:"none"}),a=this.element.offset(),this.element.animate({left:a.left-(b-c),width:b},200,"easeInOutSine",function(){return d.titleElement.find(".mercury-panel-close").animate({opacity:1},100),d.paneElement.css({display:"block",width:b}),d.makeDraggable()});if(!this.visible)return this.hide()},c.prototype.position=function(a){var b,c,d,e,f;this.element.css({display:"block",visibility:"hidden"}),e=this.element.offset(),b=this.element.width(),c=Mercury
.displayRect.height-16,f=c-this.titleElement.outerHeight(),this.paneElement.css({height:f,overflowY:f<30?"hidden":"auto"}),this.moved||(d=Mercury.displayRect.width-b-20),d<=8&&(d=8);if(this.pinned||b+e.left>Mercury.displayRect.width-20)d=Mercury.displayRect.width-b-20;this.element.css({top:Mercury.displayRect.top+8,left:d,height:c,display:a?"block":"none",visibility:"visible"}),this.makeDraggable();if(!a)return this.element.hide()},c.prototype.loadContent=function(a){this.loaded=!0,this.element.removeClass("loading"),this.paneElement.css({visibility:"hidden"}),this.paneElement.html(a);if(Mercury.config.localization.enabled)return this.paneElement.localize(Mercury.locale())},c.prototype.makeDraggable=function(){var a,b=this;return a=this.element.width(),this.element.draggable({handle:"h1 span",axis:"x",opacity:.7,scroll:!1,addClasses:!1,iframeFix:!0,containment:[8,0,Mercury.displayRect.width-a-20,0],stop:function(){var c;return c=b.element.offset().left,b.moved=!0,b.pinned=c>Mercury.displayRect.width-a-30?!0:!1,!0}})},c}(Mercury.Dialog)}.call(this),function(){this.Mercury.modal=function(a,b){return b==null&&(b={}),Mercury.modal.show(a,b),Mercury.modal},jQuery.extend(Mercury.modal,{minWidth:400,show:function(a,b){var c=this;this.url=a,this.options=b!=null?b:{},Mercury.trigger("focus:window"),this.initialize(),this.visible?this.update():this.appear();if(this.options.content)return setTimeout(500,function(){return c.loadContent(c.options.content)})},initialize:function(){if(this.initialized)return;return this.build(),this.bindEvents(),this.initialized=!0},build:function(){var a,b;return this.element=jQuery("<div>",{"class":"mercury-modal loading"}),this.element.html('<h1 class="mercury-modal-title"><span></span><a>&times;</a></h1>'),this.element.append('<div class="mercury-modal-content-container"><div class="mercury-modal-content"></div></div>'),this.overlay=jQuery("<div>",{"class":"mercury-modal-overlay"}),this.titleElement=this.element.find(".mercury-modal-title"),this.contentContainerElement=this.element.find(".mercury-modal-content-container"),this.contentElement=this.element.find(".mercury-modal-content"),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body"),this.overlay.appendTo((b=jQuery(this.options.appendTo).get(0))!=null?b:"body")},bindEvents:function(){var a=this;return Mercury.on("refresh",function(){return a.resize(!0)}),Mercury.on("resize",function(){return a.position()}),this.overlay.on("click",function(){if(a.options.allowHideUsingOverlay)return a.hide()}),this.titleElement.find("a").on("click",function(){return a.hide()}),this.element.on("ajax:beforeSend",function(b,c,d){return d.success=function(b){return a.loadContent(b)}}),jQuery(document).on("keydown",function(b){if(b.keyCode===27&&a.visible)return a.hide()})},appear:function(){var a=this;return this.showing=!0,this.position(),this.overlay.show(),this.overlay.animate({opacity:1},200,"easeInOutSine",function(){return a.element.css({top:-a.element.height()}),a.setTitle(),a.element.show(),a.element.animate({top:0},200,"easeInOutSine",function(){return a.visible=!0,a.showing=!1,a.load()})})},resize:function(a){var b,c,d,e,f=this;d=a?"visible":"hidden",c=this.titleElement.outerHeight(),e=this.contentElement.outerWidth(),this.contentPane&&this.contentPane.css({height:"auto"}),this.contentElement.css({height:"auto",visibility:d,display:"block"}),b=this.contentElement.outerHeight()+c,e<this.minWidth&&(e=this.minWidth);if(b>Mercury.displayRect.fullHeight-20||this.options.fullHeight)b=Mercury.displayRect.fullHeight-20;return this.element.stop().animate({left:(Mercury.displayRect.width-e)/2,width:e,height:b},200,"easeInOutSine",function(){var a;return f.contentElement.css({visibility:"visible",display:"block"}),f.contentPane.length?(f.contentElement.css({height:b-c,overflow:"visible"}),a=f.contentControl.length?f.contentControl.outerHeight():0,f.contentPane.css({height:b-c-a-40}),f.contentPane.find(".mercury-display-pane").css({width:e-40})):f.contentElement.css({height:b-c,overflow:"auto"})})},position:function(){var a,b,c,d,e;d=Mercury.displayRect.width,this.contentPane&&this.contentPane.css({height:"auto"}),this.contentElement.css({height:"auto"}),this.element.css({width:"auto",height:"auto",display:"block",visibility:"hidden"}),e=this.element.width(),b=this.element.height(),e<this.minWidth&&(e=this.minWidth);if(b>Mercury.displayRect.fullHeight-20||this.options.fullHeight)b=Mercury.displayRect.fullHeight-20;return c=this.titleElement.outerHeight(),this.contentPane&&this.contentPane.length?(this.contentElement.css({height:b-c,overflow:"visible"}),a=this.contentControl.length?this.contentControl.outerHeight():0,this.contentPane.css({height:b-c-a-40}),this.contentPane.find(".mercury-display-pane").css({width:e-40})):this.contentElement.css({height:b-c,overflow:"auto"}),this.element.css({left:(d-e)/2,width:e,height:b,display:this.visible?"block":"none",visibility:"visible"})},update:function(){return this.reset(),this.resize(),this.load()},load:function(){var a=this;this.setTitle();if(!this.url)return;return this.element.addClass("loading"),Mercury.preloadedViews[this.url]?setTimeout(function(){return a.loadContent(Mercury.preloadedViews[a.url])},10):jQuery.ajax(this.url,{headers:Mercury.ajaxHeaders(),type:this.options.loadType||"GET",data:this.options.loadData,success:function(b){return a.loadContent(b)},error:function(){return a.hide(),Mercury.notify("Mercury was unable to load %s for the modal.",a.url)}})},loadContent:function(a,b){return b==null&&(b=null),this.initialize(),this.options=b||this.options,this.setTitle(),this.loaded=!0,this.element.removeClass("loading"),this.contentElement.html(a),this.contentElement.css({display:"none",visibility:"hidden"}),this.contentPane=this.element.find(".mercury-display-pane-container"),this.contentControl=this.element.find(".mercury-display-controls"),this.options.afterLoad&&this.options.afterLoad.call(this),this.options.handler&&(Mercury.modalHandlers[this.options.handler]?Mercury.modalHandlers[this.options.handler].call(this):Mercury.lightviewHandlers[this.options.handler]&&Mercury.lightviewHandlers[this.options.handler].call(this)),Mercury.config.localization.enabled&&this.element.localize(Mercury.locale()),this.resize()},setTitle:function(){var a;return this.titleElement.find("span").html(Mercury.I18n(this.options.title)),a=this.titleElement.find("a"),this.options.closeButton===!1?a.hide():a.show()},reset:function(){return this.titleElement.find("span").html(""),this.contentElement.html("")},hide:function(){if(this.showing)return;return this.options={},this.initialized=!1,Mercury.trigger("focus:frame"),this.element.hide(),this.overlay.hide(),this.reset(),this.visible=!1}})}.call(this),function(){this.Mercury.lightview=function(a,b){return b==null&&(b={}),Mercury.lightview.show(a,b),Mercury.lightview},jQuery.extend(Mercury.lightview,{minWidth:400,show:function(a,b){var c=this;this.url=a,this.options=b!=null?b:{},Mercury.trigger("focus:window"),this.initialize(),this.visible?this.update():this.appear();if(this.options.content)return setTimeout(500,function(){return c.loadContent(c.options.content)})},initialize:function(){if(this.initialized)return;return this.build(),this.bindEvents(),this.initialized=!0},build:function(){var a,b;return this.element=jQuery("<div>",{"class":"mercury-lightview loading"}),this.element.html('<h1 class="mercury-lightview-title"><span></span></h1>'),this.element.append('<div class="mercury-lightview-content"></div>'),this.overlay=jQuery("<div>",{"class":"mercury-lightview-overlay"}),this.titleElement=this.element.find(".mercury-lightview-title"),this.options.closeButton&&this.titleElement.append('<a class="mercury-lightview-close"></a>'),this.contentElement=this.element.find(".mercury-lightview-content"),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body"),this.overlay.appendTo((b=jQuery(this.options.appendTo).get(0))!=null?b:"body")},bindEvents:function(){var a=this;return Mercury.on("refresh",function(){return a.resize(!0)}),Mercury.on("resize",function(){if(a.visible)return a.position()}),this.overlay.on("click",function(){if(!a.options.closeButton)return a.hide()}),this.titleElement.find(".mercury-lightview-close").on("click",function(){return a.hide()}),this.element.on("ajax:beforeSend",function(b,c,d){return d.success=function(b){return a.loadContent(b)}}),jQuery(document).on("keydown",function(b){if(b.keyCode===27&&a.visible)return a.hide()})},appear:function(){var a=this;return this.showing=!0,this.position(),this.overlay.show().css({opacity:0}),this.overlay.animate({opacity:1},200,"easeInOutSine",function(){return a.setTitle(),a.element.show().css({opacity:0}),a.element.stop().animate({opacity:1},200,"easeInOutSine",function(){return a.visible=!0,a.showing=!1,a.load()})})},resize:function(a){var b,c,d,e,f,g,h=this;f=a?"visible":"hidden",e=Mercury.displayRect.width,d=Mercury.displayRect.fullHeight,c=this.titleElement.outerHeight(),g=this.contentElement.outerWidth();if(g>e-40||this.options.fullSize)g=e-40;this.contentPane&&this.contentPane.css({height:"auto"}),this.contentElement.css({height:"auto",visibility:f,display:"block"}),b=this.contentElement.outerHeight()+c;if(b>d-20||this.options.fullSize)b=d-20;return g<300&&(g=300),b<150&&(b=150),this.element.stop().animate({top:(d-b)/2+10,left:(Mercury.displayRect.width-g)/2,width:g,height:b},200,"easeInOutSine",function(){var a;return h.contentElement.css({visibility:"visible",display:"block"}),h.contentPane.length?(h.contentElement.css({height:b-c,overflow:"visible"}),a=h.contentControl.length?h.contentControl.outerHeight():0,h.contentPane.css({height:b-c-a-40}),h.contentPane.find(".mercury-display-pane").css({width:g-40})):h.contentElement.css({height:b-c-30,overflow:"auto"})})},position:function(){var a,b,c,d,e,f;e=Mercury.displayRect.width,d=Mercury.displayRect.fullHeight,this.contentPane&&this.contentPane.css({height:"auto"}),this.contentElement.css({height:"auto"}),this.element.css({width:"auto",height:"auto",display:"block",visibility:"hidden"}),f=this.contentElement.width()+40,b=this.contentElement.height()+this.titleElement.outerHeight()+30;if(f>e-40||this.options.fullSize)f=e-40;if(b>d-20||this.options.fullSize)b=d-20;return f<300&&(f=300),b<150&&(b=150),c=this.titleElement.outerHeight(),this.contentPane&&this.contentPane.length?(this.contentElement.css({height:b-c,overflow:"visible"}),a=this.contentControl.length?this.contentControl.outerHeight():0,this.contentPane.css({height:b-c-a-40}),this.contentPane.find(".mercury-display-pane").css({width:f-40})):this.contentElement.css({height:b-c-30,overflow:"auto"}),this.element.css({top:(d-b)/2+10,left:(e-f)/2,width:f,height:b,display:this.visible?"block":"none",visibility:"visible"})},update:function(){return this.reset(),this.resize(),this.load()},load:function(){var a=this;this.setTitle();if(!this.url)return;return this.element.addClass("loading"),Mercury.preloadedViews[this.url]?setTimeout(function(){return a.loadContent(Mercury.preloadedViews[a.url])},10):jQuery.ajax(this.url,{headers:Mercury.ajaxHeaders(),type:this.options.loadType||"GET",data:this.options.loadData,success:function(b){return a.loadContent(b)},error:function(){return a.hide(),Mercury.notify("Mercury was unable to load %s for the lightview.",a.url)}})},loadContent:function(a,b){return b==null&&(b=null),this.initialize(),this.options=b||this.options,this.setTitle(),this.loaded=!0,this.element.removeClass("loading"),this.contentElement.html(a),this.contentElement.css({display:"none",visibility:"hidden"}),this.contentPane=this.element.find(".mercury-display-pane-container"),this.contentControl=this.element.find(".mercury-display-controls"),this.options.afterLoad&&this.options.afterLoad.call(this),this.options.handler&&(Mercury.modalHandlers[this.options.handler]?Mercury.modalHandlers[this.options.handler].call(this):Mercury.lightviewHandlers[this.options.handler]&&Mercury.lightviewHandlers[this.options.handler].call(this)),Mercury.config.localization.enabled&&this.element.localize(Mercury.locale()),this.resize()},setTitle:function(){return this.titleElement.find("span").html(Mercury.I18n(this.options.title))},reset:function(){return this.titleElement.find("span").html(""),this.contentElement.html("")},hide:function(){if(this.showing)return;return this.options={},this.initialized=!1,Mercury.trigger("focus:frame"),this.element.hide(),this.overlay.hide(),this.reset(),this.visible=!1}})}.call(this),function(){this.Mercury.Statusbar=function(){function a(a){this.options=a!=null?a:{},this.visible=this.options.visible,this.build(),this.bindEvents()}return a.prototype.build=function(){var a;return this.element=jQuery("<div>",{"class":"mercury-statusbar"}),this.aboutElement=jQuery("<a>",{"class":"mercury-statusbar-about"}).appendTo(this.element).html("Mercury Editor v"+Mercury.version),this.pathElement=jQuery("<div>",{"class":"mercury-statusbar-path"}).appendTo(this.element),this.visible||this.element.css({visibility:"hidden"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},a.prototype.bindEvents=function(){var a=this;return Mercury.on("region:update",function(b,c){if(c.region&&jQuery.type(c.region.path)==="function")return a.setPath(c.region.path())}),this.aboutElement.on("click",function(){return Mercury.lightview("/mercury/lightviews/about.html",{title:"Mercury Editor v"+Mercury.version})})},a.prototype.height=function(){return this.element.outerHeight()},a.prototype.top=function(){var a,b;return b=this.element.offset().top,a=parseInt(this.element.css("bottom"))<0?b-this.element.outerHeight():b,this.visible?a:b+this.element.outerHeight()},a.prototype.setPath=function(a){var b,c,d,e;c=[];for(d=0,e=a.length;d<e;d++)b=a[d],c.push("<a>"+b.tagName.toLowerCase()+"</a>");return this.pathElement.html("<span><strong>"+Mercury.I18n("Path:")+" </strong>"+c.reverse().join(" &raquo; ")+"</span>")},a.prototype.show=function(){return this.visible=!0,this.element.css({opacity:0,visibility:"visible"}),this.element.animate({opacity:1},200,"easeInOutSine")},a.prototype.hide=function(){return this.visible=!1,this.element.css({visibility:"hidden"})},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty;this.Mercury.Toolbar=function(){function b(a){this.options=a!=null?a:{},this.visible=this.options.visible,this.build(),this.bindEvents()}return b.prototype.build=function(){var b,c,d,e,f,g,h,i,j,k;this.element=jQuery("<div>",{"class":"mercury-toolbar-container",style:"width:10000px"}),this.visible||this.element.css({display:"none"}),this.element.appendTo((j=jQuery(this.options.appendTo).get(0))!=null?j:"body"),k=Mercury.config.toolbars;for(i in k){if(!a.call(k,i))continue;d=k[i];if(d._custom)continue;h=jQuery("<div>",{"class":"mercury-toolbar mercury-"+i+"-toolbar"}).appendTo(this.element),d._regions&&h.attr("data-regions",d._regions),e=jQuery("<div>",{"class":"mercury-toolbar-button-container"}).appendTo(h);for(c in d){if(!a.call(d,c))continue;g=d[c];if(c==="_regions")continue;b=this.buildButton(c,g),b&&b.appendTo(e)}e.css("white-space")==="nowrap"&&(f=new Mercury.Toolbar.Expander(i,{appendTo:h,"for":e}),f.appendTo(this.element)),Mercury.config.toolbars.primary&&i!=="primary"&&h.addClass("disabled")}return this.element.css({width:"100%"})},b.prototype.buildButton=function(b,c){var d,e,f,g,h,i,j;if(b[0]==="_")return!1;switch(jQuery.type(c)){case"array":return j=c[0],i=c[1],g=c[2],new Mercury.Toolbar.Button(b,j,i,g,{appendDialogsTo:this.element});case"object":f=new Mercury.Toolbar.ButtonGroup(b,c);for(d in c){if(!a.call(c,d))continue;h=c[d],e=this.buildButton(d,h),e&&e.appendTo(f)}return f;case"string":return jQuery("<hr>",{"class":"mercury-"+(c==="-"?"line-separator":"separator")});default:throw Mercury.I18n('Unknown button structure -- please provide an array, object, or string for "%s".',b)}},b.prototype.bindEvents=function(){var a=this;return Mercury.on("region:focused",function(b,c){var d,e,f,g,h,i;h=a.element.find(".mercury-toolbar"),i=[];for(f=0,g=h.length;f<g;f++)e=h[f],e=jQuery(e),(d=e.data("regions"))?d.split(",").indexOf(c.region.type())>-1?i.push(e.removeClass("disabled")):i.push(void 0):i.push(void 0);return i}),Mercury.on("region:blurred",function(b,c){var d,e,f,g,h,i;h=a.element.find(".mercury-toolbar"),i=[];for(f=0,g=h.length;f<g;f++)e=h[f],e=jQuery(e),(d=e.data("regions"))?d.split(",").indexOf(c.region.type())>-1?i.push(e.addClass("disabled")):i.push(void 0):i.push(void 0);return i}),this.element.on("click",function(){return Mercury.trigger("hide:dialogs")}),this.element.on("mousedown",function(a){return a.preventDefault()})},b.prototype.height=function(){return this.visible?this.element.outerHeight():0},b.prototype.show=function(){return this.visible=!0,this.element.css({top:-this.element.outerHeight(),display:"block"}),this.element.animate({top:0},200,"easeInOutSine")},b.prototype.hide=function(){return this.visible=!1,this.element.hide()},b}()}.call(this),function(){var a=Object.prototype.hasOwnProperty;this.Mercury.Toolbar.Button=function(){function b(a,b,c,d,e){return this.name=a,this.title=b,this.summary=c!=null?c:null,this.types=d!=null?d:{},this.options=e!=null?e:{},this.title&&(this.title=Mercury.I18n(this.title)),this.summary&&(this.summary=Mercury.I18n(this.summary)),this.build(),this.bindEvents(),this.element}return b.prototype.build=function(){var b,c,d,e,f,g;this.element=jQuery("<div>",{title:(e=this.summary)!=null?e:this.title,"class":"mercury-button mercury-"+this.name+"-button"}).html("<em>"+this.title+"</em>"),this.element.data("expander",'<div class="mercury-expander-button" data-button="'+this.name+'"><em></em><span>'+this.title+"</span></div>"),this.handled={},f=this.types,g=[];for(d in f){if(!a.call(f,d))continue;b=f[d];switch(d){case"preload":g.push(!0);break;case"regions":this.element.addClass("disabled"),g.push(this.handled[d]=jQuery.isFunction(b)?b.call(this,this.name):b);break;case"toggle":g.push(this.handled[d]=!0);break;case"mode":g.push(this.handled[d]=b===!0?this.name:b);break;case"context":g.push(this.handled[d]=jQuery.isFunction(b)?b:Mercury.Toolbar.Button.contexts[this.name]);break;case"palette":this.element.addClass("mercury-button-palette"),c=jQuery.isFunction(b)?b.call(this,this.name):b,g.push(this.handled[d]=typeof c=="string"?new Mercury.Palette(c,this.name,this.defaultDialogOptions()):c);break;case"select":this.element.addClass("mercury-button-select").find("em").html(this.title),c=jQuery.isFunction(b)?b.call(this,this.name):b,g.push(this.handled[d]=typeof c=="string"?new Mercury.Select(c,this.name,this.defaultDialogOptions()):c);break;case"panel":this.element.addClass("mercury-button-panel"),this.handled.toggle=!0,c=jQuery.isFunction(b)?b.call(this,this.name):b,g.push(this.handled[d]=typeof c=="string"?new Mercury.Panel(c,this.name,this.defaultDialogOptions()):c);break;case"modal":g.push(this.handled[d]=jQuery.isFunction(b)?b.call(this,this.name):b);break;case"lightview":g.push(this.handled[d]=jQuery.isFunction(b)?b.call(this,this.name):b);break;default:throw Mercury.I18n('Unknown button type "%s" used for the "%s" button.',d,this.name)}}return g},b.prototype.bindEvents=function(){var b=this;return Mercury.on("button",function(a,c){if(c.action===b.name)return b.element.click()}),Mercury.on("mode",function(a,c){if(b.handled.mode===c.mode&&b.handled.toggle)return b.togglePressed()}),Mercury.on("region:update",function(a,c){var d;return b.handled.context&&c.region&&jQuery.type(c.region.currentElement)==="function"?(d=c.region.currentElement(),d.length&&b.handled.context.call(b,d,c.region.element)?b.element.addClass("active"):b.element.removeClass("active")):b.element.removeClass("active")}),Mercury.on("region:focused",function(a,c){if(b.handled.regions&&c.region&&c.region.type())return b.handled.regions.indexOf(c.region.type())>-1?b.element.removeClass("disabled"):b.element.addClass("disabled")}),Mercury.on("region:blurred",function(){if(b.handled.regions)return b.element.addClass("disabled")}),this.element.on("mousedown",function(){return b.element.addClass("active")}),this.element.on("mouseup",function(){return b.element.removeClass("active")}),this.element.on("click",function(c){var d,e,f,g;if(b.element.closest(".disabled").length)return;d=!1,g=b.handled;for(f in g){if(!a.call(g,f))continue;e=g[f];switch(f){case"toggle":b.handled.mode||b.togglePressed();break;case"mode":d=!0,Mercury.trigger("mode",{mode:e});break;case"modal":d=!0,Mercury.modal(b.handled.modal,{title:b.summary||b.title,handler:b.name});break;case"lightview":d=!0,Mercury.lightview(b.handled.lightview,{title:b.summary||b.title,handler:b.name,closeButton:!0});break;case"palette":case"select":case"panel":c.stopPropagation(),d=!0,b.handled[f].toggle()}}d||Mercury.trigger("action",{action:b.name});if(b.options.regions&&b.options.regions.length)return Mercury.trigger("focus:frame")})},b.prototype.defaultDialogOptions=function(){return{title:this.summary||this.title,preload:this.types.preload,appendTo:this.options.appendDialogsTo||"body",closeButton:!0,"for":this.element}},b.prototype.togglePressed=function(){return this.element.toggleClass("pressed")},b}(),this.Mercury.Toolbar.Button.contexts={backColor:function(a){return this.element.css("background-color",a.css("background-color"))},foreColor:function(a){return this.element.css("background-color",a.css("color"))},bold:function(a){var b;return b=a.css("font-weight"),b==="bold"||b>400},italic:function(a){return a.css("font-style")==="italic"},overline:function(a){var b,c,d,e;if(a.css("text-decoration")==="overline")return!0;e=a.parentsUntil(this.element);for(c=0,d=e.length;c<d;c++){b=e[c];if(jQuery(b).css("text-decoration")==="overline")return!0}return!1},strikethrough:function(a,b){return a.css("text-decoration")==="line-through"||!!a.closest("strike",b).length},underline:function(a,b){return a.css("text-decoration")==="underline"||!!a.closest("u",b).length},subscript:function(a,b){return!!a.closest("sub",b).length},superscript:function(a,b){return!!a.closest("sup",b).length},justifyLeft:function(a){return a.css("text-align").indexOf("left")>-1},justifyCenter:function(a){return a.css("text-align").indexOf("center")>-1},justifyRight:function(a){return a.css("text-align").indexOf("right")>-1},justifyFull:function(a){return a.css("text-align").indexOf("justify")>-1},insertOrderedList:function(a,b){return!!a.closest("ol",b.element).length},insertUnorderedList:function(a,b){return!!a.closest("ul",b.element).length}}}.call(this),function(){this.Mercury.Toolbar.ButtonGroup=function(){function a(a,b){return this.name=a,this.options=b!=null?b:{},this.build(),this.bindEvents(),this.regions=this.options._regions,this.element}return a.prototype.build=function(){this.element=jQuery("<div>",{"class":"mercury-button-group mercury-"+this.name+"-group"});if(this.options._context||this.options._regions)return this.element.addClass("disabled")},a.prototype.bindEvents=function(){var a=this;return Mercury.on("region:update",function(b,c){var d,e;d=Mercury.Toolbar.ButtonGroup.contexts[a.name];if(d&&c.region&&jQuery.type(c.region.currentElement)==="function")return e=c.region.currentElement(),e.length&&d.call(a,e,c.region.element)?a.element.removeClass("disabled"):a.element.addClass("disabled")}),Mercury.on("region:focused",function(b,c){if(a.regions&&c.region&&c.region.type()){if(!(a.regions.indexOf(c.region.type())>-1))return a.element.addClass("disabled");if(!a.options._context)return a.element.removeClass("disabled")}}),Mercury.on("region:blurred",function(b,c){if(a.options.regions)return a.element.addClass("disabled")})},a}(),this.Mercury.Toolbar.ButtonGroup.contexts={table:function(a,b){return!!a.closest("table",b).length}}}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b};this.Mercury.Toolbar.Expander=function(a){function c(a,b){return this.name=a,this.options=b,this.container=this.options["for"],this.containerWidth=this.container.outerWidth(),c.__super__.constructor.call(this,null,this.name,this.options),this.element}return b(c,a),c.prototype.build=function(){var a;return this.container.css({whiteSpace:"normal"}),this.trigger=jQuery("<div>",{"class":"mercury-toolbar-expander"}).appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body"),this.element=jQuery("<div>",{"class":"mercury-palette mercury-expander mercury-"+this.name+"-expander",style:"display:none"}),this.windowResize()},c.prototype.bindEvents=function(){var a=this;return Mercury.on("hide:dialogs",function(b,c){if(c!==a)return a.hide()}),Mercury.on("resize",function(){return a.windowResize()}),c.__super__.bindEvents.apply(this,arguments),this.trigger.click(function(b){var c,d,e,f,g;b.stopPropagation(),d=[],g=a.container.find(".mercury-button");for(e=0,f=g.length;e<f;e++)c=g[e],c=jQuery(c),c.position().top>5&&d.push(c.data("expander"));return a.loadContent(d.join("")),a.toggle()}),this.element.click(function(b){var c,d;return d=jQuery(b.target).closest("[data-button]").data("button"),c=a.container.find(".mercury-"+d+"-button"),c.click()})},c.prototype.windowResize=function(){return this.containerWidth>jQuery(window).width()?this.trigger.show():this.trigger.hide(),this.hide()},c.prototype.position=function(a){var b,c;return this.element.css({top:0,left:0,display:"block",visibility:"hidden"}),b=this.trigger.offset(),c=this.element.width(),b.left+c>jQuery(window).width()&&(b.left=b.left-c+this.trigger.width()),this.element.css({top:b.top+this.trigger.height(),left:b.left,display:a?"block":"none",visibility:"visible"})},c}(Mercury.Palette)}.call(this),function(){this.Mercury.tooltip=function(a,b,c){return c==null&&(c={}),Mercury.tooltip.show(a,b,c),Mercury.tooltip},jQuery.extend(Mercury.tooltip,{show:function(a,b,c){return this.forElement=a,this.content=b,this.options=c!=null?c:{},this.document=this.forElement.get(0).ownerDocument,this.initialize(),this.visible?this.update():this.appear()},initialize:function(){if(this.initialized)return;return this.build(),this.bindEvents(),this.initialized=!0},build:function(){var a;return this.element=jQuery("<div>",{"class":"mercury-tooltip"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body")},bindEvents:function(){var a,b,c,d,e=this;Mercury.on("resize",function(){if(e.visible)return e.position()}),this.element.on("mousedown",function(a){return a.preventDefault(),a.stopPropagation()}),d=this.forElement.parentsUntil(jQuery("body",this.document));for(b=0,c=d.length;b<c;b++){a=d[b];if(!(a.scrollHeight>a.clientHeight))continue;jQuery(a).on("scroll",function(){if(e.visible)return e.position()})}return jQuery(this.document).on("scroll",function(){if(e.visible)return e.position()})},appear:function(){var a=this;return this.update(),this.element.show(),this.element.animate({opacity:1},200,"easeInOutSine",function(){return a.visible=!0})},update:function(){return this.element.html(this.content),this.position()},position:function(){var a,b,c,d;return b=this.forElement.offset(),d=this.element.width(),c=b.top+(Mercury.displayRect.top-jQuery(this.document).scrollTop())+this.forElement.outerHeight(),a=b.left-jQuery(this.document).scrollLeft(),a+d+25>Mercury.displayRect.width&&(a=a-(a+d+25)-Mercury.displayRect.width),a=a<=0?0:a,this.element.css({top:c,left:a})},hide:function(){if(!this.initialized)return;return this.element.hide(),this.visible=!1}})}.call(this),function(){var a=Object.prototype.hasOwnProperty;this.Mercury.Snippet=function(){function b(a,b,c){this.name=a,this.identity=b,c==null&&(c={}),this.version=0,this.data="",this.wrapperTag="div",this.history=new Mercury.HistoryBuffer,this.setOptions(c)}return b.all=[],b.displayOptionsFor=function(a,b){return b==null&&(b={}),Mercury.modal(Mercury.config.snippets.optionsUrl.replace(":name",a),jQuery.extend({title:"Snippet Options",handler:"insertSnippet",snippetName:a},b)),Mercury.snippet=null},b.create=function(a,b){var c,d,e,f,g,h;if(this.all.length>0){d="snippet_0",h=this.all;for(c=0,g=h.length;c<g;c++)f=h[c],f.identity===d&&(d="snippet_"+(c+1))}else d="snippet_"+this.all.length;return e=new Mercury.Snippet(a,d,b),this.all.push(e),e},b.find=function(a){var b,c,d,e;e=this.all;for(c=0,d=e.length;c<d;c++){b=e[c];if(b.identity===a)return b}return null},b.load=function(b){var c,d,e,f;f=[];for(d in b){if(!a.call(b,d))continue;c=b[d],e=new Mercury.Snippet(c.name,d,c.options),f.push(this.all.push(e))}return f},b.clearAll=function(){return delete this.all,this.all=[]},b.prototype.getHTML=function(a,b){var c;return b==null&&(b=null),c=jQuery("<"+this.wrapperTag+">",{"class":""+this.name+"-snippet",contenteditable:"false","data-snippet":this.identity,"data-version":this.version},a),c.html("["+this.identity+"]"),this.loadPreview(c,b),c},b.prototype.getText=function(a){return"[--"+this.identity+"--]"},b.prototype.loadPreview=function(a,b){var c=this;return b==null&&(b=null),jQuery.ajax(Mercury.config.snippets.previewUrl.replace(":name",this.name),{headers:Mercury.ajaxHeaders(),type:Mercury.config.snippets.method,data:this.options,success:function(d){c.data=d,a.html(d);if(b)return b()},error:function(){return Mercury.notify('Error loading the preview for the "%s" snippet.',c.name)}})},b.prototype.displayOptions=function(){return Mercury.snippet=this,Mercury.modal(Mercury.config.snippets.optionsUrl.replace(":name",this.name),{title:"Snippet Options",handler:"insertSnippet",loadType:Mercury.config.snippets.method,loadData:this.options})},b.prototype.setOptions=function(a){return this.options=a,delete this.options.authenticity_token,delete this.options.utf8,this.options.wrapperTag&&(this.wrapperTag=this.options.wrapperTag),this.version+=1,this.history.push(this.options)},b.prototype.setVersion=function(a){return a==null&&(a=null),a=parseInt(a),a&&this.history.stack[a-1]?(this.version=a-1,this.options=this.history.stack[this.version],!0):!1},b.prototype.serialize=function(){return{name:this.name,options:this.options}},b}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b};this.Mercury.SnippetToolbar=function(c){function d(a,b){this.document=a,this.options=b!=null?b:{},this._boundEvents=[],d.__super__.constructor.call(this,this.options)}return b(d,c),d.prototype.build=function(){var b,c,d,e,f,g;this.element=jQuery("<div>",{"class":"mercury-toolbar mercury-snippet-toolbar",style:"display:none"}),this.element.appendTo((e=jQuery(this.options.appendTo).get(0))!=null?e:"body"),f=Mercury.config.toolbars.snippets,g=[];for(c in f){if(!a.call(f,c))continue;d=f[c],b=this.buildButton(c,d),b?g.push(b.appendTo(this.element)):g.push(void 0)}return g},d.prototype.bindEvents=function(){var a=this;return this.bindReleasableEvent(Mercury,"show:toolbar",function(b,c){if(!c.snippet)return;return c.snippet.mouseout(function(){return a.hide()}),a.show(c.snippet)}),this.bindReleasableEvent(Mercury,"hide:toolbar",function(b,c){if(!c.type||c.type!=="snippet")return;return a.hide(c.immediately)}),this.bindReleasableEvent(jQuery(this.document),"scroll",function(){if(a.visible)return a.position()}),this.element.mousemove(function(){return clearTimeout(a.hideTimeout)}),this.element.mouseout(function(){return a.hide()})},d.prototype.bindReleasableEvent=function(a,b,c){return a.on(b,c),this._boundEvents.push([a,b,c])},d.prototype.show=function(a){return this.snippet=a,Mercury.tooltip.hide(),this.position(),this.appear()},d.prototype.position=function(){var a,b,c;return b=this.snippet.offset(),c=b.top+Mercury.displayRect.top-jQuery(this.document).scrollTop()-this.height()+10,a=b.left-jQuery(this.document).scrollLeft(),this.element.css({top:c,left:a})},d.prototype.appear=function(){clearTimeout(this.hideTimeout);if(this.visible)return;return this.visible=!0,this.element.css({display:"block",opacity:0}),this.element.stop().animate({opacity:1},200,"easeInOutSine")},d.prototype.hide=function(a){var b=this;return a==null&&(a=!1),clearTimeout(this.hideTimeout),a?(this.element.hide(),this.visible=!1):this.hideTimeout=setTimeout(function(){return b.element.stop().animate({opacity:0},300,"easeInOutSine",function(){return b.element.hide()}),b.visible=!1},500)},d.prototype.release=function(){var a,b,c,d,e,f,g;this.element.off(),this.element.remove(),f=this._boundEvents;for(d=0,e=f.length;d<e;d++)g=f[d],c=g[0],a=g[1],b=g[2],c.off(a,b);return this._boundEvents=[]},d}(Mercury.Toolbar)}.call(this),function(){this.Mercury.Region=function(){function a(a,b,c){this.element=a,this.window=b,this.options=c!=null?c:{},Mercury.log("building "+this.type(),this.element,this.options
),this.document=this.window.document,this.name=this.element.attr(Mercury.config.regions.identifier),this.history=new Mercury.HistoryBuffer,this.build(),this.bindEvents(),this.pushHistory(),this.element.data("region",this)}return a.prototype.type=function(){return"unknown"},a.prototype.build=function(){},a.prototype.focus=function(){},a.prototype.bindEvents=function(){var a=this;return Mercury.on("mode",function(b,c){if(c.mode==="preview")return a.togglePreview()}),Mercury.on("focus:frame",function(){if(a.previewing||Mercury.region!==a)return;return a.focus()}),Mercury.on("action",function(b,c){if(a.previewing||Mercury.region!==a)return;if(c.action)return a.execCommand(c.action,c)}),this.element.on("mousemove",function(b){var c;if(a.previewing||Mercury.region!==a)return;c=jQuery(b.target).closest("[data-snippet]");if(c.length){a.snippet=c;if(a.snippet.data("snippet"))return Mercury.trigger("show:toolbar",{type:"snippet",snippet:a.snippet})}}),this.element.on("mouseout",function(){if(a.previewing)return;return Mercury.trigger("hide:toolbar",{type:"snippet",immediately:!1})})},a.prototype.content=function(a,b){var c,d,e,f,g;a==null&&(a=null),b==null&&(b=!1);if(a!==null)return this.element.html(a);c=jQuery("<div>").appendTo(this.document.createDocumentFragment()),c.html(this.element.html().replace(/^\s+|\s+$/g,""));if(b){g=c.find("[data-snippet]");for(e=0,f=g.length;e<f;e++)d=g[e],d=jQuery(d),d.attr({contenteditable:null,"data-version":null}),d.html("["+d.data("snippet")+"]")}return c.html()},a.prototype.togglePreview=function(){if(!this.previewing)return this.previewing=!0,this.element.removeAttr(Mercury.config.regions.attribute),Mercury.trigger("region:blurred",{region:this});this.previewing=!1,this.element.attr(Mercury.config.regions.attribute,this.type());if(Mercury.region===this)return this.focus()},a.prototype.execCommand=function(a,b){b==null&&(b={}),this.focus(),a!=="redo"&&this.pushHistory(),Mercury.log("execCommand",a,b.value);if(!b.already_handled)return Mercury.changes=!0},a.prototype.pushHistory=function(){return this.history.push(this.content())},a.prototype.snippets=function(){var a,b,c,d,e,f;c={},f=this.element.find("[data-snippet]");for(d=0,e=f.length;d<e;d++){a=f[d],b=Mercury.Snippet.find(jQuery(a).data("snippet"));if(!b)continue;b.setVersion(jQuery(a).data("version")),c[b.identity]=b.serialize()}return c},a.prototype.dataAttributes=function(){var a,b,c,d,e;b={},e=Mercury.config.regions.dataAttributes;for(c=0,d=e.length;c<d;c++)a=e[c],b[a]=this.element.attr("data-"+a);return b},a.prototype.serialize=function(){return{type:this.type(),data:this.dataAttributes(),value:this.content(null,!0),snippets:this.snippets()}},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty;this.Mercury.uploader=function(a,b){return Mercury.config.uploading.enabled&&Mercury.uploader.show(a,b),Mercury.uploader},jQuery.extend(Mercury.uploader,{show:function(a,b){this.options=b!=null?b:{},this.file=new Mercury.uploader.File(a);if(this.file.errors){alert("Error: "+this.file.errors);return}if(!this.supported())return;return Mercury.trigger("focus:window"),this.initialize(),this.appear()},initialize:function(){if(this.initialized)return;return this.build(),this.bindEvents(),this.initialized=!0},supported:function(){var a;return a=new XMLHttpRequest,window.Uint8Array&&window.ArrayBuffer&&!XMLHttpRequest.prototype.sendAsBinary&&(XMLHttpRequest.prototype.sendAsBinary=function(a){var b,c,d,e;d=new Uint8Array(a.length);for(c=0,e=a.length;c<e;c++)b=a[c],d[c]=a.charCodeAt(c)&255;return this.send(d.buffer)}),!(!a.upload||!a.sendAsBinary||!Mercury.uploader.fileReaderSupported()&&!Mercury.uploader.formDataSupported())},fileReaderSupported:function(){return!!window.FileReader},formDataSupported:function(){return!!window.FormData},build:function(){var a,b;return this.element=jQuery("<div>",{"class":"mercury-uploader",style:"display:none"}),this.element.append('<div class="mercury-uploader-preview"><b><img/></b></div>'),this.element.append('<div class="mercury-uploader-details"></div>'),this.element.append('<div class="mercury-uploader-progress"><span></span><div class="mercury-uploader-indicator"><div><b>0%</b></div></div></div>'),this.updateStatus("Processing..."),this.overlay=jQuery("<div>",{"class":"mercury-uploader-overlay",style:"display:none"}),this.element.appendTo((a=jQuery(this.options.appendTo).get(0))!=null?a:"body"),this.overlay.appendTo((b=jQuery(this.options.appendTo).get(0))!=null?b:"body")},bindEvents:function(){var a=this;return Mercury.on("resize",function(){return a.position()})},appear:function(){var a=this;return this.fillDisplay(),this.position(),this.overlay.show(),this.overlay.animate({opacity:1},200,"easeInOutSine",function(){return a.element.show(),a.element.animate({opacity:1},200,"easeInOutSine",function(){return a.visible=!0,a.loadImage()})})},position:function(){var a,b;return b=this.element.outerWidth(),a=this.element.outerHeight(),this.element.css({top:(Mercury.displayRect.height-a)/2,left:(Mercury.displayRect.width-b)/2})},fillDisplay:function(){var a;return a=[Mercury.I18n("Name: %s",this.file.name),Mercury.I18n("Size: %s",this.file.readableSize),Mercury.I18n("Type: %s",this.file.type)],this.element.find(".mercury-uploader-details").html(a.join("<br/>"))},loadImage:function(){var a=this;return Mercury.uploader.fileReaderSupported()?this.file.readAsDataURL(function(b){return a.element.find(".mercury-uploader-preview b").html(jQuery("<img>",{src:b})),a.upload()}):this.upload()},upload:function(){var a,b,c=this;return b=new XMLHttpRequest,jQuery.each(["onloadstart","onprogress","onload","onabort","onerror"],function(a,d){return b.upload[d]=function(a){return c.uploaderEvents[d].call(c,a)}}),b.onload=function(a){var b,d;if(a.currentTarget.status>=400)return c.updateStatus("Error: Unable to upload the file"),Mercury.notify("Unable to process response: %s",a.currentTarget.status),c.hide();try{b=Mercury.config.uploading.handler?Mercury.config.uploading.handler(a.target.responseText):jQuery.parseJSON(a.target.responseText),d=b.url||b.image.url;if(!d)throw"Malformed response from server.";return Mercury.trigger("action",{action:"insertImage",value:{src:d}}),c.hide()}catch(e){return c.updateStatus("Error: Unable to upload the file"),Mercury.notify("Unable to process response: %s",e),c.hide()}},b.open("post",Mercury.config.uploading.url,!0),b.setRequestHeader("Accept","application/json, text/javascript, text/html, application/xml, text/xml, */*"),b.setRequestHeader("X-Requested-With","XMLHttpRequest"),b.setRequestHeader(Mercury.config.csrfHeader,Mercury.csrfToken),Mercury.uploader.fileReaderSupported()?this.file.readAsBinaryString(function(a){var d;return d=new Mercury.uploader.MultiPartPost(Mercury.config.uploading.inputName,c.file,a),c.file.updateSize(d.delta),b.setRequestHeader("Content-Type","multipart/form-data; boundary="+d.boundary),b.sendAsBinary(d.body)}):(a=new FormData,a.append(Mercury.config.uploading.inputName,this.file.file,this.file.file.name),b.send(a))},updateStatus:function(a,b){var c;this.element.find(".mercury-uploader-progress span").html(Mercury.I18n(a).toString());if(b)return c=Math.floor(b*100/this.file.size)+"%",this.element.find(".mercury-uploader-indicator div").css({width:c}),this.element.find(".mercury-uploader-indicator b").html(c).show()},hide:function(a){var b=this;return a==null&&(a=0),setTimeout(function(){return b.element.animate({opacity:0},200,"easeInOutSine",function(){return b.overlay.animate({opacity:0},200,"easeInOutSine",function(){return b.overlay.hide(),b.element.hide(),b.reset(),b.visible=!1,Mercury.trigger("focus:frame")})})},a*1e3)},reset:function(){return this.element.find(".mercury-uploader-preview b").html(""),this.element.find(".mercury-uploader-indicator div").css({width:0}),this.element.find(".mercury-uploader-indicator b").html("0%").hide(),this.updateStatus("Processing...")},uploaderEvents:{onloadstart:function(){return this.updateStatus("Uploading...")},onprogress:function(a){return this.updateStatus("Uploading...",a.loaded)},onabort:function(){return this.updateStatus("Aborted"),this.hide(1)},onload:function(){return this.updateStatus("Successfully uploaded...",this.file.size)},onerror:function(){return this.updateStatus("Error: Unable to upload the file"),this.hide(3)}}}),Mercury.uploader.File=function(){function a(a){var b;this.file=a,this.fullSize=this.size=this.file.size||this.file.fileSize,this.readableSize=this.size.toBytes(),this.name=this.file.name||this.file.fileName,this.type=this.file.type||this.file.fileType,b=[],this.size>=Mercury.config.uploading.maxFileSize&&b.push(Mercury.I18n("Too large")),Mercury.config.uploading.allowedMimeTypes.indexOf(this.type)>-1||b.push(Mercury.I18n("Unsupported format")),b.length&&(this.errors=b.join(" / "))}return a.prototype.readAsDataURL=function(a){var b,c=this;return a==null&&(a=null),b=new FileReader,b.readAsDataURL(this.file),b.onload=function(){if(a)return a(b.result)}},a.prototype.readAsBinaryString=function(a){var b,c=this;return a==null&&(a=null),b=new FileReader,b.readAsBinaryString(this.file),b.onload=function(){if(a)return a(b.result)}},a.prototype.updateSize=function(a){return this.fullSize=this.size+a},a}(),Mercury.uploader.MultiPartPost=function(){function b(a,b,c,d){this.inputName=a,this.file=b,this.contents=c,this.formInputs=d!=null?d:{},this.boundary="Boundaryx20072377098235644401115438165x",this.body="",this.buildBody(),this.delta=this.body.length-this.file.size}return b.prototype.buildBody=function(){var b,c,d,e;b="--"+this.boundary,e=this.formInputs;for(c in e){if(!a.call(e,c))continue;d=e[c],this.body+=""+b+'\r\nContent-Disposition: form-data; name="'+c+'"\r\n\r\n'+unescape(encodeURIComponent(d))+"\r\n"}return this.body+=""+b+'\r\nContent-Disposition: form-data; name="'+this.inputName+'"; filename="'+this.file.name+'"\r\nContent-Type: '+this.file.type+"\r\nContent-Transfer-Encoding: binary\r\n\r\n"+this.contents+"\r\n"+b+"--"},b}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b},c=Array.prototype.indexOf||function(a){for(var b=0,c=this.length;b<c;b++)if(b in this&&this[b]===a)return b;return-1};this.Mercury.Regions.Full=function(a){function e(a,b,c){this.element=a,this.window=b,this.options=c!=null?c:{},e.__super__.constructor.apply(this,arguments)}var d;return b(e,a),e.supported=document.designMode&&!jQuery.browser.konqueror&&!jQuery.browser.msie,e.supportedText="Chrome 10+, Firefox 4+, Safari 5+",d="full",e.prototype.type=function(){return d},e.prototype.build=function(){var a,b,c,d;jQuery.browser.mozilla&&this.content()===""&&this.content("&nbsp;"),this.element.data({originalOverflow:this.element.css("overflow")}),this.element.css({overflow:"auto"}),this.specialContainer=jQuery.browser.mozilla&&this.element.get(0).tagName!=="DIV",this.element.get(0).contentEditable=!0,d=this.element.find("[data-snippet]");for(b=0,c=d.length;b<c;b++)a=d[b],a.contentEditable=!1,jQuery(a).attr("data-version","1");if(!this.document.mercuryEditing){this.document.mercuryEditing=!0;try{return this.document.execCommand("styleWithCSS",!1,!1),this.document.execCommand("insertBROnReturn",!1,!0),this.document.execCommand("enableInlineTableEditing",!1,!1),this.document.execCommand("enableObjectResizing",!1,!1)}catch(e){}}},e.prototype.bindEvents=function(){var a=this;return e.__super__.bindEvents.apply(this,arguments),Mercury.on("region:update",function(){var b,c,d;if(a.previewing||Mercury.region!==a)return;setTimeout(function(){return a.selection().forceSelection(a.element.get(0))},1),c=a.currentElement();if(c.length)return d=c.closest("table",a.element),d.length&&Mercury.tableEditor(d,c.closest("tr, td"),"<br/>"),b=c.closest("a",a.element),b.length&&b.attr("href")?Mercury.tooltip(b,'<a href="'+b.attr("href")+'" target="_blank">'+b.attr("href")+"</a>",{position:"below"}):Mercury.tooltip.hide()}),this.element.on("dragenter",function(b){if(a.previewing)return;return Mercury.snippet||b.preventDefault(),b.originalEvent.dataTransfer.dropEffect="copy"}),this.element.on("dragover",function(b){if(a.previewing)return;Mercury.snippet||b.preventDefault(),b.originalEvent.dataTransfer.dropEffect="copy";if(jQuery.browser.webkit)return clearTimeout(a.dropTimeout),a.dropTimeout=setTimeout(function(){return a.element.trigger("possible:drop")},10)}),this.element.on("drop",function(b){if(a.previewing)return;clearTimeout(a.dropTimeout),a.dropTimeout=setTimeout(function(){return a.element.trigger("possible:drop")},1);if(!b.originalEvent.dataTransfer.files.length)return;return b.preventDefault(),a.focus(),Mercury.uploader(b.originalEvent.dataTransfer.files[0])}),this.element.on("possible:drop",function(){var b;if(a.previewing)return;if(b=a.element.find("img[data-snippet]").get(0))return a.focus(),Mercury.Snippet.displayOptionsFor(jQuery(b).data("snippet")),a.document.execCommand("undo",!1,null)}),this.element.on("paste",function(b){if(a.previewing||Mercury.region!==a)return;if(a.specialContainer){b.preventDefault();return}if(a.pasting)return;return Mercury.changes=!0,a.handlePaste(b.originalEvent)}),this.element.on("focus",function(){if(a.previewing)return;return Mercury.region=a,setTimeout(function(){return a.selection().forceSelection(a.element.get(0))},1),Mercury.trigger("region:focused",{region:a})}),this.element.on("blur",function(){if(a.previewing)return;return Mercury.trigger("region:blurred",{region:a}),Mercury.tooltip.hide()}),this.element.on("click",function(b){if(a.previewing)return jQuery(b.target).closest("a").attr("target","_parent")}),this.element.on("dblclick",function(b){var c;if(a.previewing)return;c=jQuery(b.target).closest("img",a.element);if(c.length)return a.selection().selectNode(c.get(0),!0),Mercury.trigger("button",{action:"insertMedia"})}),this.element.on("mouseup",function(){if(a.previewing)return;return a.pushHistory(),Mercury.trigger("region:update",{region:a})}),this.element.on("keydown",function(b){var c;if(a.previewing)return;switch(b.keyCode){case 90:if(!b.metaKey)return;b.preventDefault(),b.shiftKey?a.execCommand("redo"):a.execCommand("undo");return;case 13:if(jQuery.browser.webkit&&a.selection().commonAncestor().closest("li, ul, ol",a.element).length===0)b.preventDefault(),a.document.execCommand("insertParagraph",!1,null);else if(a.specialContainer||jQuery.browser.opera)b.preventDefault(),a.document.execCommand("insertHTML",!1,"<br/>");break;case 9:b.preventDefault(),c=a.selection().commonAncestor(),c.closest("li",a.element).length?b.shiftKey?c.parents("ul, ol").length>1&&a.execCommand("outdent"):a.execCommand("indent"):a.execCommand("insertHTML",{value:"&nbsp;&nbsp;"})}if(b.metaKey)switch(b.keyCode){case 66:a.execCommand("bold"),b.preventDefault();break;case 73:a.execCommand("italic"),b.preventDefault();break;case 85:a.execCommand("underline"),b.preventDefault()}return a.pushHistory(b.keyCode)}),this.element.on("keyup",function(){if(a.previewing)return;return Mercury.trigger("region:update",{region:a}),Mercury.changes=!0})},e.prototype.focus=function(){var a=this;if(Mercury.region!==this){setTimeout(function(){return a.element.focus()},10);try{this.selection().selection.collapseToStart()}catch(b){}}else setTimeout(function(){return a.element.focus()},10);return Mercury.trigger("region:focused",{region:this}),Mercury.trigger("region:update",{region:this})},e.prototype.content=function(a,b,c){var d,e,f,g,h,i,j,k,l,m,n,o;a==null&&(a=null),b==null&&(b=!0),c==null&&(c=!1);if(a!==null){d=jQuery("<div>").appendTo(this.document.createDocumentFragment()),d.html(a),n=d.find("[data-snippet]");for(k=0,l=n.length;k<l;k++){f=n[k],f.contentEditable=!1,f=jQuery(f);if(i=Mercury.Snippet.find(f.data("snippet")))if(!f.data("version"))try{j=parseInt(f.html().match(/\/(\d+)\]/)[1]),j&&(i.setVersion(j),f.attr({"data-version":j}),f.html(i.data))}catch(p){}}return this.element.html(d.html()),this.selection().selectMarker(this.element)}this.element.find("meta").remove(),c&&(h=this.selection(),h.placeMarker()),d=jQuery("<div>").appendTo(this.document.createDocumentFragment()),d.html(this.element.html().replace(/^\s+|\s+$/g,""));if(b){o=d.find("[data-snippet]");for(g=0,m=o.length;g<m;g++){f=o[g],f=jQuery(f);if(i=Mercury.Snippet.find(f.data("snippet")))i.data=f.html();f.html("["+f.data("snippet")+"/"+f.data("version")+"]"),f.attr({contenteditable:null,"data-version":null})}}return e=d.html(),c&&h.removeMarker(),e},e.prototype.togglePreview=function(){return this.previewing?(this.element.get(0).contentEditable=!0,this.element.css({overflow:"auto"})):(this.content(this.content()),this.element.get(0).contentEditable=!1,this.element.css({overflow:this.element.data("originalOverflow")}),this.element.blur()),e.__super__.togglePreview.apply(this,arguments)},e.prototype.execCommand=function(a,b){var c,d;b==null&&(b={}),e.__super__.execCommand.apply(this,arguments);if(c=Mercury.config.behaviors[a]||Mercury.Regions.Full.actions[a])c.call(this,this.selection(),b);else{a==="indent"&&(d=this.element.get(0).previousSibling),a==="insertHTML"&&b.value&&b.value.get&&(b.value=jQuery("<div>").html(b.value).html());try{this.document.execCommand(a,!1,b.value)}catch(f){a==="indent"&&this.element.prev()!==d&&this.element.prev().remove()}}return this.element.find("img").one("error",function(){return jQuery(this).attr({src:"/assets/mercury/missing-image.png",title:"Image not found"})})},e.prototype.pushHistory=function(a){var b,c,d,e=this;return b=[13,46,8],d=2.5,a&&(c=b.indexOf(a)),clearTimeout(this.historyTimeout),c>=0&&c!==this.lastKnownKeyCode?this.history.push(this.content(null,!1,!0)):a?this.historyTimeout=setTimeout(function(){return e.history.push(e.content(null,!1,!0))},d*1e3):this.history.push(this.content(null,!1,!0)),this.lastKnownKeyCode=c},e.prototype.selection=function(){return new Mercury.Regions.Full.Selection(this.window.getSelection(),this.document)},e.prototype.path=function(){var a;return a=this.selection().commonAncestor(),a?a.get(0)===this.element.get(0)?[]:a.parentsUntil(this.element):[]},e.prototype.currentElement=function(){var a,b;return a=[],b=this.selection(),b.range&&(a=b.commonAncestor(),a.get(0).nodeType===3&&(a=a.parent())),a},e.prototype.handlePaste=function(a){var b,c,d=this;if(Mercury.config.pasting.sanitize!=="text"||!a.clipboardData)return c=this.selection(),c.placeMarker(),b=jQuery("#mercury_sanitizer",this.document).focus(),setTimeout(function(){var a;return a=d.sanitize(b),c.selectMarker(d.element),c.removeMarker(),d.element.focus(),d.execCommand("insertHTML",{value:a})},1);this.execCommand("insertHTML",{value:a.clipboardData.getData("text/plain")}),a.preventDefault()},e.prototype.sanitize=function(a){var b,d,e,f,g,h,i,j,k,l,m,n,o,p;a.find("["+Mercury.config.regions.attribute+"]").remove();if(Mercury.config.pasting.sanitize)switch(Mercury.config.pasting.sanitize){case"blacklist":a.find("[style]").removeAttr("style"),a.find('[class="Apple-style-span"]').removeClass("Apple-style-span"),g=a.html();break;case"whitelist":m=a.find("*");for(i=0,k=m.length;i<k;i++){h=m[i],b=!1,n=Mercury.config.pasting.whitelist;for(e in n){d=n[e];if(h.tagName.toLowerCase()===e.toLowerCase()){b=!0,o=jQuery(h.attributes);for(j=0,l=o.length;j<l;j++)f=o[j],(p=f.name,c.call(d,p)<0)&&jQuery(h).removeAttr(f.name);break}}b||jQuery(h).replaceWith(jQuery(h).contents())}g=a.html();break;default:g=a.text()}else{g=a.html();if(g.indexOf("<!--StartFragment-->")>-1||g.indexOf('="mso-')>-1||g.indexOf("<o:")>-1||g.indexOf('="Mso')>-1)g=a.text()}return a.html(""),g},e.actions={insertRowBefore:function(){return Mercury.tableEditor.addRow("before")},insertRowAfter:function(){return Mercury.tableEditor.addRow("after")},insertColumnBefore:function(){return Mercury.tableEditor.addColumn("before")},insertColumnAfter:function(){return Mercury.tableEditor.addColumn("after")},deleteColumn:function(){return Mercury.tableEditor.removeColumn()},deleteRow:function(){return Mercury.tableEditor.removeRow()},increaseColspan:function(){return Mercury.tableEditor.increaseColspan()},decreaseColspan:function(){return Mercury.tableEditor.decreaseColspan()},increaseRowspan:function(){return Mercury.tableEditor.increaseRowspan()},decreaseRowspan:function(){return Mercury.tableEditor.decreaseRowspan()},undo:function(){return this.content(this.history.undo())},redo:function(){return this.content(this.history.redo())},horizontalRule:function(){return this.execCommand("insertHorizontalRule")},removeFormatting:function(a){return a.insertTextNode(a.textContent())},backColor:function(a,b){return a.wrap('<span style="background-color:'+b.value.toHex()+'">',!0)},overline:function(a){return a.wrap('<span style="text-decoration:overline">',!0)},style:function(a,b){return a.wrap('<span class="'+b.value+'">',!0)},replaceHTML:function(a,b){return this.content(b.value)},insertImage:function(a,b){return this.execCommand("insertHTML",{value:jQuery("<img/>",b.value)})},insertTable:function(a,b){return this.execCommand("insertHTML",{value:b.value})},insertLink:function(a,b){var c;return c=jQuery("<"+b.value.tagName+">",this.document).attr(b.value.attrs).html(b.value.content),a.insertNode(c)},replaceLink:function(a,b){var c,d;return c=jQuery("<"+b.value.tagName+">",this.document).attr(b.value.attrs).html(b.value.content),a.selectNode(b.node),d=jQuery("<div>").html(a.content()).find("a").html(),a.replace(jQuery(c,a.context).html(d))},insertSnippet:function(a,b){var c,d;return d=b.value,(c=this.element.find("[data-snippet="+d.identity+"]")).length&&a.selectNode(c.get(0)),a.insertNode(d.getHTML(this.document))},editSnippet:function(){var a;if(!this.snippet)return;return a=Mercury.Snippet.find(this.snippet.data("snippet")),a.displayOptions()},removeSnippet:function(){return this.snippet&&this.snippet.remove(),Mercury.trigger("hide:toolbar",{type:"snippet",immediately:!0})}},e}(Mercury.Region),Mercury.Regions.Full.Selection=function(){function a(a,b){this.selection=a,this.context=b;if(!(this.selection.rangeCount>=1))return;this.range=this.selection.getRangeAt(0),this.fragment=this.range.cloneContents(),this.clone=this.range.cloneRange(),this.collapsed=this.selection.isCollapsed}return a.prototype.commonAncestor=function(a){var b;return a==null&&(a=!1),this.range?(b=this.range.commonAncestorContainer,b.nodeType===3&&a&&(b=b.parentNode),jQuery(b)):null},a.prototype.wrap=function(a,b){return b==null&&(b=!1),a=jQuery(a,this.context).html(this.fragment),b&&this.replace(a),a},a.prototype.textContent=function(){return this.range.cloneContents().textContent},a.prototype.content=function(){return this.range.cloneContents()},a.prototype.is=function(a){var b;return b=this.content(),jQuery(b).length===1&&jQuery(b.firstChild).is(a)?jQuery(b.firstChild):!1},a.prototype.forceSelection=function(a){var b,c;if(!jQuery.browser.webkit)return;c=this.context.createRange(),this.range?this.commonAncestor(!0).closest("[data-snippet]").length&&(b=this.context.createTextNode("\0"),a.appendChild(b)):a.lastChild&&a.lastChild.nodeType===3&&a.lastChild.textContent.replace(/^[\s+|\n+]|[\s+|\n+]$/,"")===""?(b=a.lastChild,a.lastChild.textContent="\0"):(b=this.context.createTextNode("\0"),a.appendChild(b));if(b)return c.setStartBefore(b),c.setEndBefore(b),this.selection.addRange(c)},a.prototype.selectMarker=function(a){var b,c;b=a.find("em.mercury-marker");if(!b.length)return;return c=this.context.createRange(),c.setStartBefore(b.get(0)),b.length>=2&&c.setEndBefore(b.get(1)),b.remove(),this.selection.removeAllRanges(),this.selection.addRange(c)},a.prototype.placeMarker=function(){var a,b;if(!this.range)return;return this.startMarker=jQuery('<em class="mercury-marker"/>',this.context).get(0),this.endMarker=jQuery('<em class="mercury-marker"/>',this.context).get(0),a=this.range.cloneRange(),a.collapse(!1),a.insertNode(this.endMarker),this.range.collapsed||(b=this.range.cloneRange(),b.collapse(!0),b.insertNode(this.startMarker)),this.selection.removeAllRanges(),this.selection.addRange(this.range)},a.prototype.removeMarker=function(){return jQuery(this.startMarker).remove(),jQuery(this.endMarker).remove()},a.prototype.insertTextNode=function(a){var b;return b=this.context.createTextNode(a),this.range.extractContents(),this.range.insertNode(b),this.range.selectNodeContents(b),this.selection.addRange(this.range)},a.prototype.insertNode=function(a){return a.get&&(a=a.get(0)),jQuery.type(a)==="string"&&(a=jQuery(a,this.context).get(0)),this.range.deleteContents(),this.range.insertNode(a),this.range.selectNodeContents(a),this.selection.addRange(this.range)},a.prototype.selectNode=function(a,b){return b==null&&(b=!1),this.range.selectNode(a),b&&this.selection.removeAllRanges(),this.selection.addRange(this.range)},a.prototype.replace=function(a,b){a.get&&(a=a.get(0)),jQuery.type(a)==="string"&&(a=jQuery(a,this.context).get(0)),this.range.deleteContents(),this.range.insertNode(a),this.range.selectNodeContents(a),this.selection.addRange(this.range);if(b)return this.range.collapse(!1)},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b};this.Mercury.Regions.Image=function(a){function d(a,b,c){this.element=a,this.window=b,this.options=c!=null?c:{},d.__super__.constructor.apply(this,arguments)}var c;return b(d,a),d.supported=document.getElementById,d.supportedText="IE 7+, Chrome 10+, Firefox 4+, Safari 5+, Opera 8+",c="image",d.prototype.type=function(){return c},d.prototype.bindEvents=function(){var a=this;return Mercury.on("mode",function(b,c){if(c.mode==="preview")return a.togglePreview()}),Mercury.on("focus:frame",function(){if(a.previewing||Mercury.region!==a)return;return a.focus()}),Mercury.on("action",function(b,c){if(a.previewing||Mercury.region!==a)return;if(c.action)return a.execCommand(c.action,c)}),this.element.on("dragenter",function(b){if(a.previewing)return;return b.preventDefault(),b.originalEvent.dataTransfer.dropEffect="copy"}),this.element.on("dragover",function(b){if(a.previewing)return;return b.preventDefault(),b.originalEvent.dataTransfer.dropEffect="copy"}),this.element.on("drop",function(b){if(a.previewing)return;if(b.originalEvent.dataTransfer.files.length)return b.preventDefault(),a.focus(),Mercury.uploader(b.originalEvent.dataTransfer.files[0])}),this.element.on("focus",function(){return a.focus()})},d.prototype.togglePreview=function(){return this.previewing?(this.previewing=!1,this.element.attr(Mercury.config.regions.attribute,c),this.build()):(this.previewing=!0,this.element.removeAttr(Mercury.config.regions.attribute),Mercury.trigger("region:blurred",{region:this}))},d.prototype.focus=function(){if(this.previewing)return;return Mercury.region=this,Mercury.trigger("region:focused",{region:this}),Mercury.trigger("region:update",{region:this})},d.prototype.execCommand=function(a,b){var c;b==null&&(b={}),d.__super__.execCommand.apply(this,arguments);if(c=Mercury.Regions.Image.actions[a])return c.call(this,b)},d.prototype.pushHistory=function(){return this.history.push({src:this.element.attr("src")})},d.prototype.updateSrc=function(a){return this.element.attr("src",a)},d.prototype.serialize=function(){return{type:c,data:this.dataAttributes(),attributes:{src:this.element.attr("src")}}},d.actions={undo:function(){var a;if(a=this.history.undo())return this.updateSrc(a.src)},redo:function(){var a;if(a=this.history.redo())return this.updateSrc(a.src)},insertImage:function(a){return this.updateSrc(a.value.src)}},d}(Mercury.Region)}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b};this.Mercury.Regions.Markdown=function(a){function d(a,b,c){this.element=a,this.window=b,this.options=c!=null?c:{},d.__super__.constructor.apply(this,arguments),this.converter=new Showdown.converter}var c;return b(d,a),d.supported=document.getElementById,d.supportedText="IE 7+, Chrome 10+, Firefox 4+, Safari 5+, Opera 8+",c="markdown",d.prototype.type=function(){return c},d.prototype.build=function(){var a,b,c;return c="100%",a=this.element.height(),b=this.element.html().replace(/^\s+|\s+$/g,"").replace("&gt;",">"),this.textarea=jQuery("<textarea>",this.document).val(b).addClass("mercury-textarea"),this.textarea.css({border:0,background:"transparent",display:"block","overflow-y":"hidden",width:c,height:a,fontFamily:'"Courier New", Courier, monospace'}),this.element.empty().append(this.textarea),this.previewElement=jQuery("<div>",this.document),this.element.append(this.previewElement),this.container=this.element,this.container.data("region",this),this.element=this.textarea,this.resize()},d.prototype.bindEvents=function(){var a=this;return Mercury.on("mode",function(b,c){if(c.mode==="preview")return a.togglePreview()}),Mercury.on("focus:frame",function(){if(!a.previewing&&Mercury.region===a)return a.focus()}),Mercury.on("action",function(b,c){if(a.previewing||Mercury.region!==a)return;if(c.action)return a.execCommand(c.action,c)}),Mercury.on("unfocus:regions",function(){if(a.previewing||Mercury.region!==a)return;return a.element.blur(),a.container.removeClass("focus"),Mercury.trigger("region:blurred",{region:a})}),this.element.on("dragenter",function(b){if(a.previewing)return;return b.preventDefault(),b.originalEvent.dataTransfer.dropEffect="copy"}),this.element.on("dragover",function(b){if(a.previewing)return;return b.preventDefault(),b.originalEvent.dataTransfer.dropEffect="copy"}),this.element.on("drop",function(b){if(a.previewing)return;Mercury.snippet&&(b.preventDefault(),a.focus(),Mercury.Snippet.displayOptionsFor(Mercury.snippet));if(b.originalEvent.dataTransfer.files.length)return b.preventDefault(),a.focus(),Mercury.uploader(b.originalEvent.dataTransfer.files[0])}),this.element.on("focus",function(){if(a.previewing)return;return Mercury.region=a,a.container.addClass("focus"),Mercury.trigger("region:focused",{region:a})}),this.element.on("keydown",function(b){var c,d,e,f,g,h;if(a.previewing)return;a.resize();switch(b.keyCode){case 90:if(!b.metaKey)return;b.preventDefault(),b.shiftKey?a.execCommand("redo"):a.execCommand("undo");return;case 13:f=a.selection(),h=a.element.val(),g=h.lastIndexOf("\n",f.start),c=h.indexOf("\n",f.end),c<g&&(c=h.length),h[g]==="\n"&&(g=h.lastIndexOf("\n",f.start-1)),h[g+1]==="-"&&(f.replace("\n- ",!1,!0),b.preventDefault()),/\d/.test(h[g+1])&&(d=h.substring(g,c),/(\d+)\./.test(d)&&(e=parseInt(RegExp.$1),f.replace("\n"+(e+=1)+". ",!1,!0),b.preventDefault()));break;case 9:b.preventDefault(),a.execCommand("insertHTML",{value:"  "})}if(b.metaKey)switch(b.keyCode){case 66:a.execCommand("bold"),b.preventDefault();break;case 73:a.execCommand("italic"),b.preventDefault();break;case 85:a.execCommand("underline"),b.preventDefault()}return a.pushHistory(b.keyCode)}),this.element.on("keyup",function(){if(a.previewing)return;return Mercury.changes=!0,a.resize(),Mercury.trigger("region:update",{region:a})}),this.element.on("mouseup",function(){if(a.previewing)return;return a.focus(),Mercury.trigger("region:focused",{region:a})}),this.previewElement.on("click",function(b){if(a.previewing)return $(b.target).closest("a").attr("target","_parent")})},d.prototype.focus=function(){return this.element.focus()},d.prototype.content=function(a,b){return a==null&&(a=null),b==null&&(b=!0),a!==null?jQuery.type(a)==="string"?this.element.val(a):(this.element.val(a.html),this.selection().select(a.selection.start,a.selection.end)):this.element.val()},d.prototype.contentAndSelection=function(){return{html:this.content(null,!1),selection:this.selection().serialize()}},d.prototype.togglePreview=function(){var a;if(!this.previewing)return this.previewing=!0,this.container.removeAttr(Mercury.config.regions.attribute),a=this.converter.makeHtml(this.element.val()),this.previewElement.html(a),this.previewElement.show(),this.element.hide(),Mercury.trigger("region:blurred",{region:this});this.previewing=!1,this.container.attr(Mercury.config.regions.attribute,c),this.previewElement.hide(),this.element.show();if(Mercury.region===this)return this.focus()},d.prototype.execCommand=function(a,b){var c;return b==null&&(b={}),d.__super__.execCommand.apply(this,arguments),(c=Mercury.Regions.Markdown.actions[a])&&c.call(this,this.selection(),b),this.resize()},d.prototype.pushHistory=function(a){var b,c,d,e=this;return b=[13,46,8],d=2.5,a&&(c=b.indexOf(a)),clearTimeout(this.historyTimeout),c>=0&&c!==this.lastKnownKeyCode?this.history.push(this.contentAndSelection()):a?this.historyTimeout=setTimeout(function(){return e.history.push(e.contentAndSelection())},d*1e3):this.history
.push(this.contentAndSelection()),this.lastKnownKeyCode=c},d.prototype.selection=function(){return new Mercury.Regions.Markdown.Selection(this.element)},d.prototype.resize=function(){return this.element.css({height:this.element.get(0).scrollHeight-100}),this.element.css({height:this.element.get(0).scrollHeight})},d.prototype.snippets=function(){},d.actions={undo:function(){return this.content(this.history.undo())},redo:function(){return this.content(this.history.redo())},insertHTML:function(a,b){var c;return b.value.get&&(c=b.value.get(0))&&(b.value=jQuery("<div>").html(c).html()),a.replace(b.value,!1,!0)},insertImage:function(a,b){return a.replace("![add alt text]("+encodeURI(b.value.src)+")",!0)},insertTable:function(a,b){return a.replace(b.value.replace(/<br>|<br\/>/ig,""),!1,!0)},insertLink:function(a,b){return a.replace("["+b.value.content+"]("+b.value.attrs.href+" 'optional title')",!0)},insertUnorderedList:function(a){return a.addList("unordered")},insertOrderedList:function(a){return a.addList("ordered")},style:function(a,b){return a.wrap('<span class="'+b.value+'">',"</span>")},formatblock:function(a,b){var c,d,e;e={h1:["# "," #"],h2:["## "," ##"],h3:["### "," ###"],h4:["#### "," ####"],h5:["##### "," #####"],h6:["###### "," ######"],pre:["    ",""],blockquote:["> ",""],p:["\n","\n"]};for(d in e)c=e[d],a.unWrapLine(""+c[0],""+c[1]);if(b.value==="blockquote"){Mercury.Regions.Markdown.actions.indent.call(this,a,b);return}return a.wrapLine(""+e[b.value][0],""+e[b.value][1])},bold:function(a){return a.wrap("**","**")},italic:function(a){return a.wrap("_","_")},subscript:function(a){return a.wrap("<sub>","</sub>")},superscript:function(a){return a.wrap("<sup>","</sup>")},indent:function(a){return a.wrapLine("> ","",!1,!0)},outdent:function(a){return a.unWrapLine("> ","",!1,!0)},horizontalRule:function(a){return a.replace("\n- - -\n")},insertSnippet:function(a,b){var c;return c=b.value,a.replace(c.getText())}},d}(Mercury.Region),Mercury.Regions.Markdown.Selection=function(){function a(a){this.element=a,this.el=this.element.get(0),this.getDetails()}return a.prototype.serialize=function(){return{start:this.start,end:this.end}},a.prototype.getDetails=function(){return this.length=this.el.selectionEnd-this.el.selectionStart,this.start=this.el.selectionStart,this.end=this.el.selectionEnd,this.text=this.element.val().substr(this.start,this.length)},a.prototype.replace=function(a,b,c){var d,e,f;return b==null&&(b=!1),c==null&&(c=!1),this.getDetails(),f=this.element.val(),e=this.element.val(),this.element.val(f.substr(0,this.start)+a+f.substr(this.end,f.length)),d=this.element.val()!==e,b&&this.select(this.start,this.start+a.length),c&&this.select(this.start+a.length,this.start+a.length),d},a.prototype.select=function(a,b){return this.start=a,this.end=b,this.element.focus(),this.el.selectionStart=this.start,this.el.selectionEnd=this.end,this.getDetails()},a.prototype.wrap=function(a,b){this.getDetails(),this.deselectNewLines(),this.replace(a+this.text+b,this.text!=="");if(this.text==="")return this.select(this.start+a.length,this.start+a.length)},a.prototype.wrapLine=function(a,b,c,d){var e,f,g,h;c==null&&(c=!0),d==null&&(d=!1),this.getDetails(),f=this.serialize(),h=this.element.val(),g=h.lastIndexOf("\n",this.start),e=h.indexOf("\n",this.end),e<g&&(e=h.length),h[g]==="\n"&&(g=h.lastIndexOf("\n",this.start-1)),this.select(g+1,e),this.replace(a+this.text+b,c);if(d)return this.select(f.start+a.length,f.end+a.length)},a.prototype.unWrapLine=function(a,b,c,d){var e,f,g,h,i,j,k;c==null&&(c=!0),d==null&&(d=!1),this.getDetails(),i=this.serialize(),k=this.element.val(),j=k.lastIndexOf("\n",this.start),f=k.indexOf("\n",this.end),f<j&&(f=k.length),k[j]==="\n"&&(j=k.lastIndexOf("\n",this.start-1)),this.select(j+1,f),window.something=this.text,g=new RegExp("^"+a.regExpEscape()),h=new RegExp(""+b.regExpEscape()+"$"),e=this.replace(this.text.replace(g,"").replace(h,""),c);if(d&&e)return this.select(i.start-a.length,i.end-a.length)},a.prototype.addList=function(a){var b,c,d,e,f,g;return g=this.element.val(),f=g.lastIndexOf("\n",this.start),b=g.indexOf("\n",this.end),b<f&&(b=g.length),g[f]==="\n"&&(f=g.lastIndexOf("\n",this.start-1)),this.select(f+1,b),e=this.text.split("\n"),a==="unordered"?this.replace("- "+e.join("\n- "),!0):this.replace(function(){var a,b;b=[];for(c=0,a=e.length;c<a;c++)d=e[c],b.push(""+(c+1)+". "+d);return b}().join("\n"),!0)},a.prototype.deselectNewLines=function(){var a,b;return b=this.text,a=b.replace(/\n+$/g,"").length,this.select(this.start,this.start+a)},a.prototype.placeMarker=function(){return this.wrap("[mercury-marker]","[mercury-marker]")},a.prototype.removeMarker=function(){var a,b,c;c=this.element.val(),b=c.indexOf("[mercury-marker]");if(b>-1)return a=c.indexOf("[mercury-marker]",b+1)-"[mercury-marker]".length,this.element.val(this.element.val().replace(/\[mercury-marker\]/g,"")),this.select(b,a);return},a.prototype.textContent=function(){return this.text},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b};this.Mercury.Regions.Simple=function(a){function d(a,b,e){this.element=a,this.window=b,this.options=e!=null?e:{},Mercury.log("building "+c,this.element,this.options),d.__super__.constructor.apply(this,arguments)}var c;return b(d,a),d.supported=document.getElementById,d.supportedText="IE 7+, Chrome 10+, Firefox 4+, Safari 5+, Opera 8+",c="simple",d.prototype.type=function(){return c},d.prototype.build=function(){var a,b,c;return this.element.css("display")==="block"?(c="100%",a=this.element.height()):(c=this.element.width(),a=this.element.height()),b=this.element.text(),this.textarea=jQuery("<textarea>",this.document).val(b).addClass("mercury-textarea"),this.textarea.css({border:0,background:"transparent","overflow-y":"hidden",width:c,height:a,fontFamily:"inherit",fontSize:"inherit",fontWeight:"inherit",fontStyle:"inherit",color:"inherit","min-height":0,padding:"0",margin:0,"border-radius":0,display:"inherit",lineHeight:"inherit",textAlign:"inherit"}),this.element.empty().append(this.textarea),this.container=this.element,this.container.data("region",this),this.element=this.textarea,this.resize()},d.prototype.bindEvents=function(){var a=this;return Mercury.on("mode",function(b,c){if(c.mode==="preview")return a.togglePreview()}),Mercury.on("focus:frame",function(){if(!a.previewing&&Mercury.region===a)return a.focus()}),Mercury.on("action",function(b,c){if(a.previewing||Mercury.region!==a)return;if(c.action)return a.execCommand(c.action,c)}),Mercury.on("unfocus:regions",function(){if(a.previewing||Mercury.region!==a)return;return a.element.blur(),a.container.removeClass("focus"),Mercury.trigger("region:blurred",{region:a})}),this.bindElementEvents()},d.prototype.bindElementEvents=function(){var a=this;return this.element.on("focus",function(){if(a.previewing)return;return Mercury.region=a,a.container.addClass("focus"),Mercury.trigger("region:focused",{region:a})}),this.element.on("keydown",function(b){var c,d,e,f,g,h;if(a.previewing)return;a.resize();switch(b.keyCode){case 90:if(!b.metaKey)return;b.preventDefault(),b.shiftKey?a.execCommand("redo"):a.execCommand("undo");return;case 13:f=a.selection(),h=a.element.val(),g=h.lastIndexOf("\n",f.start),c=h.indexOf("\n",f.end),c<g&&(c=h.length),h[g]==="\n"&&(g=h.lastIndexOf("\n",f.start-1)),h[g+1]==="-"&&f.replace("\n- ",!1,!0),/\d/.test(h[g+1])&&(d=h.substring(g,c),/(\d+)\./.test(d)&&(e=parseInt(RegExp.$1),f.replace("\n"+(e+=1)+". ",!1,!0))),b.preventDefault();break;case 9:b.preventDefault(),a.execCommand("insertHTML",{value:"  "})}return a.pushHistory(b.keyCode)}),this.element.on("keyup",function(){if(a.previewing)return;return Mercury.changes=!0,a.resize(),Mercury.trigger("region:update",{region:a})}),this.element.on("mouseup",function(){if(a.previewing)return;return a.focus(),Mercury.trigger("region:focused",{region:a})}),this.element.on("paste",function(b){if(a.previewing||Mercury.region!==a)return;if(a.specialContainer){b.preventDefault();return}if(a.pasting)return;return Mercury.changes=!0,a.handlePaste(b.originalEvent)})},d.prototype.handlePaste=function(a){this.execCommand("insertHTML",{value:a.clipboardData.getData("text/plain").replace(/\n/g," ")}),a.preventDefault()},d.prototype.path=function(){return[this.container.get(0)]},d.prototype.focus=function(){return this.element.focus()},d.prototype.content=function(a,b){return a==null&&(a=null),b==null&&(b=!0),a!==null?jQuery.type(a)==="string"?this.element.val(a):(this.element.val(a.html),this.selection().select(a.selection.start,a.selection.end)):this.element.val()},d.prototype.contentAndSelection=function(){return{html:this.content(null,!1),selection:this.selection().serialize()}},d.prototype.togglePreview=function(){var a;if(!this.previewing)return this.previewing=!0,a=jQuery("<div></div>").text(this.element.val()).html(),this.container.removeAttr(Mercury.config.regions.attribute),this.container.html(a),Mercury.trigger("region:blurred",{region:this});this.previewing=!1,this.element=this.container,this.container.attr(Mercury.config.regions.attribute,c),this.build(),this.bindElementEvents();if(Mercury.region===this)return this.focus()},d.prototype.execCommand=function(a,b){var c;return b==null&&(b={}),d.__super__.execCommand.apply(this,arguments),(c=Mercury.Regions.Simple.actions[a])&&c.call(this,this.selection(),b),this.resize()},d.prototype.pushHistory=function(a){var b,c,d,e=this;return b=[13,46,8],d=2.5,a&&(c=b.indexOf(a)),clearTimeout(this.historyTimeout),c>=0&&c!==this.lastKnownKeyCode?this.history.push(this.contentAndSelection()):a?this.historyTimeout=setTimeout(function(){return e.history.push(e.contentAndSelection())},d*1e3):this.history.push(this.contentAndSelection()),this.lastKnownKeyCode=c},d.prototype.selection=function(){return new Mercury.Regions.Simple.Selection(this.element)},d.prototype.resize=function(){return this.element.css({height:this.element.get(0).scrollHeight-100}),this.element.css({height:this.element.get(0).scrollHeight})},d.prototype.snippets=function(){},d.actions={undo:function(){return this.content(this.history.undo())},redo:function(){return this.content(this.history.redo())},insertHTML:function(a,b){var c;return b.value.get&&(c=b.value.get(0))&&(b.value=jQuery("<div>").html(c).html()),a.replace(b.value,!1,!0)}},d}(Mercury.Region),Mercury.Regions.Simple.Selection=function(){function a(a){this.element=a,this.el=this.element.get(0),this.getDetails()}return a.prototype.serialize=function(){return{start:this.start,end:this.end}},a.prototype.getDetails=function(){return this.length=this.el.selectionEnd-this.el.selectionStart,this.start=this.el.selectionStart,this.end=this.el.selectionEnd,this.text=this.element.val().substr(this.start,this.length)},a.prototype.replace=function(a,b,c){var d,e,f;return b==null&&(b=!1),c==null&&(c=!1),this.getDetails(),f=this.element.val(),e=this.element.val(),this.element.val(f.substr(0,this.start)+a+f.substr(this.end,f.length)),d=this.element.val()!==e,b&&this.select(this.start,this.start+a.length),c&&this.select(this.start+a.length,this.start+a.length),d},a.prototype.select=function(a,b){return this.start=a,this.end=b,this.element.focus(),this.el.selectionStart=this.start,this.el.selectionEnd=this.end,this.getDetails()},a.prototype.wrap=function(a,b){this.getDetails(),this.deselectNewLines(),this.replace(a+this.text+b,this.text!=="");if(this.text==="")return this.select(this.start+a.length,this.start+a.length)},a.prototype.deselectNewLines=function(){var a,b;return b=this.text,a=b.replace(/\n+$/g,"").length,this.select(this.start,this.start+a)},a.prototype.placeMarker=function(){return this.wrap("[mercury-marker]","[mercury-marker]")},a.prototype.removeMarker=function(){var a,b,c;c=this.element.val(),b=c.indexOf("[mercury-marker]");if(b>-1)return a=c.indexOf("[mercury-marker]",b+1)-"[mercury-marker]".length,this.element.val(this.element.val().replace(/\[mercury-marker\]/g,"")),this.select(b,a);return},a.prototype.textContent=function(){return this.text},a}()}.call(this),function(){var a=Object.prototype.hasOwnProperty,b=function(b,c){function e(){this.constructor=b}for(var d in c)a.call(c,d)&&(b[d]=c[d]);return e.prototype=c.prototype,b.prototype=new e,b.__super__=c.prototype,b};this.Mercury.Regions.Snippets=function(a){function d(a,b,e){this.element=a,this.window=b,this.options=e!=null?e:{},Mercury.log("building "+c,this.element,this.options),d.__super__.constructor.apply(this,arguments),this.makeSortable()}var c;return b(d,a),d.supported=document.getElementById,d.supportedText="IE 7+, Chrome 10+, Firefox 4+, Safari 5+, Opera 8+",c="snippets",d.prototype.type=function(){return c},d.prototype.build=function(){var a,b,c,d;d=this.element.find("[data-snippet]");for(b=0,c=d.length;b<c;b++)a=d[b],jQuery(a).attr("data-version",0);if(this.element.css("minHeight")==="0px")return this.element.css({minHeight:20})},d.prototype.bindEvents=function(){var a=this;return d.__super__.bindEvents.apply(this,arguments),Mercury.on("unfocus:regions",function(b){if(a.previewing)return;if(Mercury.region===a)return a.element.removeClass("focus"),a.element.sortable("destroy"),Mercury.trigger("region:blurred",{region:a})}),Mercury.on("focus:window",function(b){if(a.previewing)return;if(Mercury.region===a)return a.element.removeClass("focus"),a.element.sortable("destroy"),Mercury.trigger("region:blurred",{region:a})}),this.element.on("mouseup",function(){if(a.previewing)return;return a.focus(),Mercury.trigger("region:focused",{region:a})}),this.element.on("dragover",function(b){if(a.previewing)return;return b.preventDefault(),b.originalEvent.dataTransfer.dropEffect="copy"}),this.element.on("drop",function(b){if(a.previewing||!Mercury.snippet)return;return a.focus(),b.preventDefault(),Mercury.Snippet.displayOptionsFor(Mercury.snippet)}),jQuery(this.document).on("keydown",function(b){if(a.previewing||Mercury.region!==a)return;switch(b.keyCode){case 90:if(!b.metaKey)return;return b.preventDefault(),b.shiftKey?a.execCommand("redo"):a.execCommand("undo")}}),jQuery(this.document).on("keyup",function(){if(a.previewing||Mercury.region!==a)return;return Mercury.changes=!0})},d.prototype.focus=function(){return Mercury.region=this,this.makeSortable(),this.element.addClass("focus")},d.prototype.togglePreview=function(){return this.previewing?this.makeSortable():(this.element.sortable("destroy"),this.element.removeClass("focus")),d.__super__.togglePreview.apply(this,arguments)},d.prototype.execCommand=function(a,b){var c;b==null&&(b={}),d.__super__.execCommand.apply(this,arguments);if(c=Mercury.Regions.Snippets.actions[a])return c.call(this,b)},d.prototype.makeSortable=function(){var a=this;return this.element.sortable("destroy").sortable({document:this.document,scroll:!1,containment:"parent",items:"[data-snippet]",opacity:.4,revert:100,tolerance:"pointer",beforeStop:function(){return Mercury.trigger("hide:toolbar",{type:"snippet",immediately:!0}),!0},stop:function(){return setTimeout(function(){return a.pushHistory()},100),!0}})},d.actions={undo:function(){return this.content(this.history.undo())},redo:function(){return this.content(this.history.redo())},insertSnippet:function(a){var b,c,d=this;return c=a.value,(b=this.element.find("[data-snippet="+c.identity+"]")).length?b.replaceWith(c.getHTML(this.document,function(){return d.pushHistory()})):this.element.append(c.getHTML(this.document,function(){return d.pushHistory()}))},editSnippet:function(){var a;if(!this.snippet)return;return a=Mercury.Snippet.find(this.snippet.data("snippet")),a.displayOptions()},removeSnippet:function(){return this.snippet&&this.snippet.remove(),Mercury.trigger("hide:toolbar",{type:"snippet",immediately:!0})}},d}(Mercury.Region)}.call(this),function(){this.Mercury.dialogHandlers.backColor=function(){var a=this;return this.element.find(".picker, .last-picked").on("click",function(b){var c;return c=jQuery(b.target).css("background-color"),a.element.find(".last-picked").css({background:c}),a.button.css({backgroundColor:c}),Mercury.trigger("action",{action:"backColor",value:c})})}}.call(this),function(){this.Mercury.dialogHandlers.foreColor=function(){var a=this;return this.element.find(".picker, .last-picked").on("click",function(b){var c;return c=jQuery(b.target).css("background-color"),a.element.find(".last-picked").css({background:c}),a.button.css({backgroundColor:c}),Mercury.trigger("action",{action:"foreColor",value:c})})}}.call(this),function(){this.Mercury.dialogHandlers.formatblock=function(){var a=this;return this.element.find("[data-tag]").on("click",function(a){var b;return b=jQuery(a.target).data("tag"),Mercury.trigger("action",{action:"formatblock",value:b})})}}.call(this),function(){this.Mercury.dialogHandlers.snippetPanel=function(){var a=this;return this.element.find("input.filter").on("keyup",function(){var b,c,d,e,f,g;c=a.element.find("input.filter").val(),f=a.element.find("li[data-filter]"),g=[];for(d=0,e=f.length;d<e;d++)b=f[d],LiquidMetal.score(jQuery(b).data("filter"),c)===0?g.push(jQuery(b).hide()):g.push(jQuery(b).show());return g}),this.element.find("img[data-snippet]").on("dragstart",function(){return Mercury.snippet=jQuery(this).data("snippet")})}}.call(this),function(){this.Mercury.dialogHandlers.style=function(){var a=this;return this.element.find("[data-class]").on("click",function(a){var b;return b=jQuery(a.target).data("class"),Mercury.trigger("action",{action:"style",value:b})})}}.call(this),function(){this.Mercury.modalHandlers.htmlEditor=function(){var a,b=this;return a=Mercury.region.content(null,!0,!1),this.element.find("textarea").val(a),this.element.find("form").on("submit",function(a){var c;return a.preventDefault(),c=b.element.find("textarea").val().replace(/\n/g,""),Mercury.trigger("action",{action:"replaceHTML",value:c}),b.hide()})}}.call(this),function(){this.Mercury.modalHandlers.insertCharacter=function(){var a=this;return this.element.find(".character").on("click",function(b){return Mercury.trigger("action",{action:"insertHTML",value:"&"+jQuery(b.target).attr("data-entity")+";"}),a.hide()})}}.call(this),function(){this.Mercury.modalHandlers.insertLink=function(){var a,b,c,d,e,f,g,h,i,j,k=this;this.element.find("label input").on("click",function(){return jQuery(this).closest("label").next(".selectable").focus()}),this.element.find(".selectable").on("focus",function(){return jQuery(this).prev("label").find("input[type=radio]").prop("checked",!0)}),this.element.find("#link_target").on("change",function(){return k.element.find(".link-target-options").hide(),k.element.find("#"+k.element.find("#link_target").val()+"_options").show(),k.resize(!0)}),a=this.element.find("#link_existing_bookmark"),j=jQuery("a[name]",window.mercuryInstance.document);for(h=0,i=j.length;h<i;h++)e=j[h],a.append(jQuery("<option>",{value:jQuery(e).attr("name")}).text(jQuery(e).text()));return Mercury.region&&Mercury.region.selection&&(g=Mercury.region.selection(),g&&g.commonAncestor&&(b=g.commonAncestor(!0).closest("a")),b&&b.length&&(c=b,this.element.find("#link_text_container").hide(),b.attr("href")&&b.attr("href").indexOf("#")===0?(a.val(b.attr("href").replace(/[^#]*#/,"")),a.prev("label").find("input[type=radio]").prop("checked",!0)):this.element.find("#link_external_url").val(b.attr("href")),b.attr("name")&&(f=this.element.find("#link_new_bookmark"),f.val(b.attr("name")),f.prev("label").find("input[type=radio]").prop("checked",!0)),b.attr("target")&&this.element.find("#link_target").val(b.attr("target")),b.attr("href")&&b.attr("href").indexOf("javascript:void")===0&&(d=b.attr("href"),this.element.find("#link_external_url").val(d.match(/window.open\('([^']+)',/)[1]),this.element.find("#link_target").val("popup"),this.element.find("#link_popup_width").val(d.match(/width=(\d+),/)[1]),this.element.find("#link_popup_height").val(d.match(/height=(\d+),/)[1]),this.element.find("#popup_options").show())),g.textContent&&this.element.find("#link_text").val(g.textContent())),this.element.find("form").on("submit",function(a){var b,d,e,f,g,h;a.preventDefault(),e=k.element.find("#link_text").val(),f=k.element.find("#link_target").val(),g=k.element.find("input[name=link_type]:checked").val();switch(g){case"existing_bookmark":d={href:"#"+k.element.find("#link_existing_bookmark").val()};break;case"new_bookmark":d={name:""+k.element.find("#link_new_bookmark").val()};break;default:d={href:k.element.find("#link_"+g).val()}}switch(f){case"popup":b={width:parseInt(k.element.find("#link_popup_width").val())||500,height:parseInt(k.element.find("#link_popup_height").val())||500,menubar:"no",toolbar:"no"},d.href="javascript:void(window.open('"+d.href+"', 'popup_window', '"+jQuery.param(b).replace(/&/g,",")+"'))";break;default:f&&(d.target=f)}return h={tagName:"a",attrs:d,content:e},c?Mercury.trigger("action",{action:"replaceLink",value:h,node:c.get(0)}):Mercury.trigger("action",{action:"insertLink",value:h}),k.hide()})}}.call(this),function(){this.Mercury.modalHandlers.insertMedia=function(){var a,b,c,d,e=this;return this.element.find("label input").on("click",function(){return jQuery(this).closest("label").next(".selectable").focus()}),this.element.find(".selectable").on("focus",function(a){var b;return b=jQuery(a.target),b.prev("label").find("input[type=radio]").prop("checked",!0),e.element.find(".media-options").hide(),e.element.find("#"+b.attr("id").replace("media_","")).show(),e.resize(!0)}),Mercury.region&&Mercury.region.selection&&(c=Mercury.region.selection(),c.is&&(b=c.is("img"))&&(this.element.find("#media_image_url").val(b.attr("src")),this.element.find("#media_image_alignment").val(b.attr("align")),setTimeout(function(){return e.element.find("#media_image_url").focus()},300)),c.is&&(a=c.is("iframe"))&&(d=a.attr("src"),d.indexOf("http://www.youtube.com")>-1?(this.element.find("#media_youtube_url").val("http://youtu.be/"+d.match(/\/embed\/(\w+)/)[1]),this.element.find("#media_youtube_width").val(a.width()),this.element.find("#media_youtube_height").val(a.height()),setTimeout(function(){return e.element.find("#media_youtube_url").focus()},300)):d.indexOf("http://player.vimeo.com")>-1&&(this.element.find("#media_vimeo_url").val("http://vimeo.com/"+d.match(/\/video\/(\w+)/)[1]),this.element.find("#media_vimeo_width").val(a.width()),this.element.find("#media_vimeo_height").val(a.height()),setTimeout(function(){return e.element.find("#media_vimeo_url").focus()},300)))),this.element.find("form").on("submit",function(a){var b,c,d,f,g,h,i;a.preventDefault(),g=e.element.find("input[name=media_type]:checked").val();switch(g){case"image_url":c={src:e.element.find("#media_image_url").val()};if(b=e.element.find("#media_image_alignment").val())c.align=b;Mercury.trigger("action",{action:"insertImage",value:c});break;case"youtube_url":h=e.element.find("#media_youtube_url").val();if(!/^https?:\/\/youtu.be\//.test(h)){Mercury.notify("Error: The provided youtube share url was invalid.");return}d=h.replace(/https?:\/\/youtu.be\//,""),f="http",/^https:/.test(h)&&(f="https"),i=jQuery("<iframe>",{width:e.element.find("#media_youtube_width").val()||560,height:e.element.find("#media_youtube_height").val()||349,src:""+f+"://www.youtube.com/embed/"+d+"?wmode=transparent",frameborder:0,allowfullscreen:"true"}),Mercury.trigger("action",{action:"insertHTML",value:i});break;case"vimeo_url":h=e.element.find("#media_vimeo_url").val();if(!/^https?:\/\/vimeo.com\//.test(h)){Mercury.notify("Error: The provided vimeo url was invalid.");return}d=h.replace(/^https?:\/\/vimeo.com\//,""),f="http",/^https:/.test(h)&&(f="https"),i=jQuery("<iframe>",{width:e.element.find("#media_vimeo_width").val()||400,height:e.element.find("#media_vimeo_height").val()||225,src:""+f+"://player.vimeo.com/video/"+d+"?title=1&byline=1&portrait=0&color=ffffff",frameborder:0}),Mercury.trigger("action",{action:"insertHTML",value:i})}return e.hide()})}}.call(this),function(){this.Mercury.modalHandlers.insertSnippet=function(){var a=this;return this.element.find("form").on("submit",function(b){var c,d;return b.preventDefault(),c=a.element.find("form").serializeObject(),Mercury.snippet?(d=Mercury.snippet,d.setOptions(c),Mercury.snippet=null):d=Mercury.Snippet.create(a.options.snippetName,c),Mercury.trigger("action",{action:"insertSnippet",value:d}),a.hide()})}}.call(this),function(){this.Mercury.modalHandlers.insertTable=function(){var a,b,c=this;return b=this.element.find("#table_display table"),b.on("click",function(a){var c;return c=jQuery(a.target),b=c.closest("table"),b.find(".selected").removeAttr("class"),c.addClass("selected"),Mercury.tableEditor(b,c,"&nbsp;")}),a=b.find("td, th").first(),a.addClass("selected"),Mercury.tableEditor(b,a,"&nbsp;"),this.element.find("input.action").on("click",function(a){var b;b=jQuery(a.target).attr("name");switch(b){case"insertRowBefore":return Mercury.tableEditor.addRow("before");case"insertRowAfter":return Mercury.tableEditor.addRow("after");case"deleteRow":return Mercury.tableEditor.removeRow();case"insertColumnBefore":return Mercury.tableEditor.addColumn("before");case"insertColumnAfter":return Mercury.tableEditor.addColumn("after");case"deleteColumn":return Mercury.tableEditor.removeColumn();case"increaseColspan":return Mercury.tableEditor.increaseColspan();case"decreaseColspan":return Mercury.tableEditor.decreaseColspan();case"increaseRowspan":return Mercury.tableEditor.increaseRowspan();case"decreaseRowspan":return Mercury.tableEditor.decreaseRowspan()}}),this.element.find("#table_alignment").on("change",function(){return b.attr({align:c.element.find("#table_alignment").val()})}),this.element.find("#table_border").on("keyup",function(){return b.attr({border:parseInt(c.element.find("#table_border").val())})}),this.element.find("#table_spacing").on("keyup",function(){return b.attr({cellspacing:parseInt(c.element.find("#table_spacing").val())})}),this.element.find("form").on("submit",function(a){var d,e;return a.preventDefault(),b.find(".selected").removeAttr("class"),b.find("td, th").html("<br/>"),d=jQuery("<div>").html(b).html(),e=d.replace(/^\s+|\n/gm,"").replace(/(<\/.*?>|<table.*?>|<tbody>|<tr>)/g,"$1\n"),Mercury.trigger("action",{action:"insertTable",value:e}),c.hide()})}}.call(this),function(){Mercury.onload&&Mercury.onload(),jQuery(window).trigger("mercury:loaded")}.call(this);